import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * The ACM certificate resource allows requesting and management of certificates
 * from the Amazon Certificate Manager.
 *
 * It deals with requesting certificates and managing their attributes and life-cycle.
 * This resource does not deal with validation of a certificate but can provide inputs
 * for other resources implementing the validation. It does not wait for a certificate to be issued.
 * Use a `aws.acm.CertificateValidation` resource for this.
 *
 * Most commonly, this resource is used together with `aws.route53.Record` and
 * `aws.acm.CertificateValidation` to request a DNS validated certificate,
 * deploy the required validation records and wait for validation to complete.
 *
 * Domain validation through E-Mail is also supported but should be avoided as it requires a manual step outside
 * of this provider.
 *
 * ## Example Usage
 * ### Create Certificate
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const cert = new aws.acm.Certificate("cert", {
 *     domainName: "example.com",
 *     tags: {
 *         Environment: "test",
 *     },
 *     validationMethod: "DNS",
 * });
 * ```
 * ### Existing Certificate Body Import
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * import * as tls from "@pulumi/tls";
 *
 * const examplePrivateKey = new tls.PrivateKey("examplePrivateKey", {algorithm: "RSA"});
 * const exampleSelfSignedCert = new tls.SelfSignedCert("exampleSelfSignedCert", {
 *     keyAlgorithm: "RSA",
 *     privateKeyPem: examplePrivateKey.privateKeyPem,
 *     subjects: [{
 *         commonName: "example.com",
 *         organization: "ACME Examples, Inc",
 *     }],
 *     validityPeriodHours: 12,
 *     allowedUses: [
 *         "key_encipherment",
 *         "digital_signature",
 *         "server_auth",
 *     ],
 * });
 * const cert = new aws.acm.Certificate("cert", {
 *     privateKey: examplePrivateKey.privateKeyPem,
 *     certificateBody: exampleSelfSignedCert.certPem,
 * });
 * ```
 * ### Referencing domainValidationOptions With forEach Based Resources
 *
 * See the `aws.acm.CertificateValidation` resource for a full example of performing DNS validation.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example: aws.route53.Record[];
 * for (const range of Object.entries(.reduce((__obj, dvo) => { ...__obj, [dvo.domainName]: {
 *     name: dvo.resourceRecordName,
 *     record: dvo.resourceRecordValue,
 *     type: dvo.resourceRecordType,
 * } })).map(([k, v]) => {key: k, value: v})) {
 *     example.push(new aws.route53.Record(`example-${range.key}`, {
 *         allowOverwrite: true,
 *         name: range.value.name,
 *         records: [range.value.record],
 *         ttl: 60,
 *         type: range.value.type,
 *         zoneId: aws_route53_zone.example.zone_id,
 *     }));
 * }
 * ```
 *
 * ## Import
 *
 * Certificates can be imported using their ARN, e.g.
 *
 * ```sh
 *  $ pulumi import aws:acm/certificate:Certificate cert arn:aws:acm:eu-central-1:123456789012:certificate/7e7a28d2-163f-4b8f-b9cd-822f96c08d6a
 * ```
 */
export declare class Certificate extends pulumi.CustomResource {
    /**
     * Get an existing Certificate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CertificateState, opts?: pulumi.CustomResourceOptions): Certificate;
    /**
     * Returns true if the given object is an instance of Certificate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Certificate;
    /**
     * The ARN of the certificate
     */
    readonly arn: pulumi.Output<string>;
    /**
     * ARN of an ACMPCA
     */
    readonly certificateAuthorityArn: pulumi.Output<string | undefined>;
    /**
     * The certificate's PEM-formatted public key
     */
    readonly certificateBody: pulumi.Output<string | undefined>;
    /**
     * The certificate's PEM-formatted chain
     * * Creating a private CA issued certificate
     */
    readonly certificateChain: pulumi.Output<string | undefined>;
    /**
     * A domain name for which the certificate should be issued
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * Set of domain validation objects which can be used to complete certificate validation. Can have more than one element, e.g. if SANs are defined. Only set if `DNS`-validation was used.
     */
    readonly domainValidationOptions: pulumi.Output<outputs.acm.CertificateDomainValidationOption[]>;
    /**
     * Configuration block used to set certificate options. Detailed below.
     * * Importing an existing certificate
     */
    readonly options: pulumi.Output<outputs.acm.CertificateOptions | undefined>;
    /**
     * The certificate's PEM-formatted private key
     */
    readonly privateKey: pulumi.Output<string | undefined>;
    /**
     * Status of the certificate.
     */
    readonly status: pulumi.Output<string>;
    /**
     * Set of domains that should be SANs in the issued certificate. To remove all elements of a previously configured list, set this value equal to an empty list (`[]`) to trigger recreation.
     */
    readonly subjectAlternativeNames: pulumi.Output<string[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A list of addresses that received a validation E-Mail. Only set if `EMAIL`-validation was used.
     */
    readonly validationEmails: pulumi.Output<string[]>;
    /**
     * Which method to use for validation. `DNS` or `EMAIL` are valid, `NONE` can be used for certificates that were imported into ACM and then into the provider.
     */
    readonly validationMethod: pulumi.Output<string>;
    /**
     * Create a Certificate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: CertificateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Certificate resources.
 */
export interface CertificateState {
    /**
     * The ARN of the certificate
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * ARN of an ACMPCA
     */
    readonly certificateAuthorityArn?: pulumi.Input<string>;
    /**
     * The certificate's PEM-formatted public key
     */
    readonly certificateBody?: pulumi.Input<string>;
    /**
     * The certificate's PEM-formatted chain
     * * Creating a private CA issued certificate
     */
    readonly certificateChain?: pulumi.Input<string>;
    /**
     * A domain name for which the certificate should be issued
     */
    readonly domainName?: pulumi.Input<string>;
    /**
     * Set of domain validation objects which can be used to complete certificate validation. Can have more than one element, e.g. if SANs are defined. Only set if `DNS`-validation was used.
     */
    readonly domainValidationOptions?: pulumi.Input<pulumi.Input<inputs.acm.CertificateDomainValidationOption>[]>;
    /**
     * Configuration block used to set certificate options. Detailed below.
     * * Importing an existing certificate
     */
    readonly options?: pulumi.Input<inputs.acm.CertificateOptions>;
    /**
     * The certificate's PEM-formatted private key
     */
    readonly privateKey?: pulumi.Input<string>;
    /**
     * Status of the certificate.
     */
    readonly status?: pulumi.Input<string>;
    /**
     * Set of domains that should be SANs in the issued certificate. To remove all elements of a previously configured list, set this value equal to an empty list (`[]`) to trigger recreation.
     */
    readonly subjectAlternativeNames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A list of addresses that received a validation E-Mail. Only set if `EMAIL`-validation was used.
     */
    readonly validationEmails?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Which method to use for validation. `DNS` or `EMAIL` are valid, `NONE` can be used for certificates that were imported into ACM and then into the provider.
     */
    readonly validationMethod?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Certificate resource.
 */
export interface CertificateArgs {
    /**
     * ARN of an ACMPCA
     */
    readonly certificateAuthorityArn?: pulumi.Input<string>;
    /**
     * The certificate's PEM-formatted public key
     */
    readonly certificateBody?: pulumi.Input<string>;
    /**
     * The certificate's PEM-formatted chain
     * * Creating a private CA issued certificate
     */
    readonly certificateChain?: pulumi.Input<string>;
    /**
     * A domain name for which the certificate should be issued
     */
    readonly domainName?: pulumi.Input<string>;
    /**
     * Configuration block used to set certificate options. Detailed below.
     * * Importing an existing certificate
     */
    readonly options?: pulumi.Input<inputs.acm.CertificateOptions>;
    /**
     * The certificate's PEM-formatted private key
     */
    readonly privateKey?: pulumi.Input<string>;
    /**
     * Set of domains that should be SANs in the issued certificate. To remove all elements of a previously configured list, set this value equal to an empty list (`[]`) to trigger recreation.
     */
    readonly subjectAlternativeNames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Which method to use for validation. `DNS` or `EMAIL` are valid, `NONE` can be used for certificates that were imported into ACM and then into the provider.
     */
    readonly validationMethod?: pulumi.Input<string>;
}
