import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get the ARN of a certificate in AWS Certificate
 * Manager (ACM), you can reference
 * it by domain without having to hard code the ARNs as input.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // Find a certificate that is issued
 * const issued = pulumi.output(aws.acm.getCertificate({
 *     domain: "tf.example.com",
 *     statuses: ["ISSUED"],
 * }, { async: true }));
 * // Find a certificate issued by (not imported into) ACM
 * const amazonIssued = pulumi.output(aws.acm.getCertificate({
 *     domain: "tf.example.com",
 *     mostRecent: true,
 *     types: ["AMAZON_ISSUED"],
 * }, { async: true }));
 * // Find a RSA 4096 bit certificate
 * const rsa4096 = pulumi.output(aws.acm.getCertificate({
 *     domain: "tf.example.com",
 *     keyTypes: ["RSA_4096"],
 * }, { async: true }));
 * ```
 */
export declare function getCertificate(args: GetCertificateArgs, opts?: pulumi.InvokeOptions): Promise<GetCertificateResult>;
/**
 * A collection of arguments for invoking getCertificate.
 */
export interface GetCertificateArgs {
    /**
     * The domain of the certificate to look up. If no certificate is found with this name, an error will be returned.
     */
    readonly domain: string;
    /**
     * A list of key algorithms to filter certificates. By default, ACM does not return all certificate types when searching. Valid values are `RSA_1024`, `RSA_2048`, `RSA_4096`, `EC_prime256v1`, `EC_secp384r1`, and `EC_secp521r1`.
     */
    readonly keyTypes?: string[];
    /**
     * If set to true, it sorts the certificates matched by previous criteria by the NotBefore field, returning only the most recent one. If set to false, it returns an error if more than one certificate is found. Defaults to false.
     */
    readonly mostRecent?: boolean;
    /**
     * A list of statuses on which to filter the returned list. Valid values are `PENDING_VALIDATION`, `ISSUED`,
     * `INACTIVE`, `EXPIRED`, `VALIDATION_TIMED_OUT`, `REVOKED` and `FAILED`. If no value is specified, only certificates in the `ISSUED` state
     * are returned.
     */
    readonly statuses?: string[];
    /**
     * A mapping of tags for the resource.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * A list of types on which to filter the returned list. Valid values are `AMAZON_ISSUED` and `IMPORTED`.
     */
    readonly types?: string[];
}
/**
 * A collection of values returned by getCertificate.
 */
export interface GetCertificateResult {
    /**
     * Amazon Resource Name (ARN) of the found certificate, suitable for referencing in other resources that support ACM certificates.
     */
    readonly arn: string;
    readonly domain: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly keyTypes?: string[];
    readonly mostRecent?: boolean;
    readonly statuses?: string[];
    /**
     * A mapping of tags for the resource.
     */
    readonly tags: {
        [key: string]: string;
    };
    readonly types?: string[];
}
