import * as pulumi from "@pulumi/pulumi";
import { RestApi } from "./index";
/**
 * Connects a custom domain name registered via `aws.apigateway.DomainName`
 * with a deployed API so that its methods can be called via the
 * custom domain name.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * import * from "fs";
 *
 * const exampleStage = new aws.apigateway.Stage("exampleStage", {
 *     deployment: aws_api_gateway_deployment.example.id,
 *     restApi: aws_api_gateway_rest_api.example.id,
 *     stageName: "example",
 * });
 * const exampleDomainName = new aws.apigateway.DomainName("exampleDomainName", {
 *     domainName: "example.com",
 *     certificateName: "example-api",
 *     certificateBody: fs.readFileSync(`${path.module}/example.com/example.crt`),
 *     certificateChain: fs.readFileSync(`${path.module}/example.com/ca.crt`),
 *     certificatePrivateKey: fs.readFileSync(`${path.module}/example.com/example.key`),
 * });
 * const exampleBasePathMapping = new aws.apigateway.BasePathMapping("exampleBasePathMapping", {
 *     restApi: aws_api_gateway_rest_api.example.id,
 *     stageName: exampleStage.stageName,
 *     domainName: exampleDomainName.domainName,
 * });
 * ```
 *
 * ## Import
 *
 * `aws_api_gateway_base_path_mapping` can be imported by using the domain name and base path, e.g. For empty `base_path` (e.g. root path (`/`))
 *
 * ```sh
 *  $ pulumi import aws:apigateway/basePathMapping:BasePathMapping example example.com/
 * ```
 *
 *  Otherwise
 *
 * ```sh
 *  $ pulumi import aws:apigateway/basePathMapping:BasePathMapping example example.com/base-path
 * ```
 */
export declare class BasePathMapping extends pulumi.CustomResource {
    /**
     * Get an existing BasePathMapping resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: BasePathMappingState, opts?: pulumi.CustomResourceOptions): BasePathMapping;
    /**
     * Returns true if the given object is an instance of BasePathMapping.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BasePathMapping;
    /**
     * Path segment that must be prepended to the path when accessing the API via this mapping. If omitted, the API is exposed at the root of the given domain.
     */
    readonly basePath: pulumi.Output<string | undefined>;
    /**
     * The already-registered domain name to connect the API to.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * The id of the API to connect.
     */
    readonly restApi: pulumi.Output<string>;
    /**
     * The name of a specific deployment stage to expose at the given path. If omitted, callers may select any stage by including its name as a path element after the base path.
     */
    readonly stageName: pulumi.Output<string | undefined>;
    /**
     * Create a BasePathMapping resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BasePathMappingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering BasePathMapping resources.
 */
export interface BasePathMappingState {
    /**
     * Path segment that must be prepended to the path when accessing the API via this mapping. If omitted, the API is exposed at the root of the given domain.
     */
    readonly basePath?: pulumi.Input<string>;
    /**
     * The already-registered domain name to connect the API to.
     */
    readonly domainName?: pulumi.Input<string>;
    /**
     * The id of the API to connect.
     */
    readonly restApi?: pulumi.Input<string | RestApi>;
    /**
     * The name of a specific deployment stage to expose at the given path. If omitted, callers may select any stage by including its name as a path element after the base path.
     */
    readonly stageName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a BasePathMapping resource.
 */
export interface BasePathMappingArgs {
    /**
     * Path segment that must be prepended to the path when accessing the API via this mapping. If omitted, the API is exposed at the root of the given domain.
     */
    readonly basePath?: pulumi.Input<string>;
    /**
     * The already-registered domain name to connect the API to.
     */
    readonly domainName: pulumi.Input<string>;
    /**
     * The id of the API to connect.
     */
    readonly restApi: pulumi.Input<string | RestApi>;
    /**
     * The name of a specific deployment stage to expose at the given path. If omitted, callers may select any stage by including its name as a path element after the base path.
     */
    readonly stageName?: pulumi.Input<string>;
}
