import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Provides details about a specific Amazon API Gateway Version 2 API.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.apigatewayv2.getApi({
 *     apiId: "aabbccddee",
 * }, { async: true }));
 * ```
 */
export declare function getApi(args: GetApiArgs, opts?: pulumi.InvokeOptions): Promise<GetApiResult>;
/**
 * A collection of arguments for invoking getApi.
 */
export interface GetApiArgs {
    /**
     * The API identifier.
     */
    readonly apiId: string;
    /**
     * A map of resource tags.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getApi.
 */
export interface GetApiResult {
    /**
     * The URI of the API, of the form `https://{api-id}.execute-api.{region}.amazonaws.com` for HTTP APIs and `wss://{api-id}.execute-api.{region}.amazonaws.com` for WebSocket APIs.
     */
    readonly apiEndpoint: string;
    readonly apiId: string;
    /**
     * An [API key selection expression](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions).
     * Applicable for WebSocket APIs.
     */
    readonly apiKeySelectionExpression: string;
    /**
     * The ARN of the API.
     */
    readonly arn: string;
    /**
     * The cross-origin resource sharing (CORS) [configuration](https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-cors.html).
     * Applicable for HTTP APIs.
     */
    readonly corsConfigurations: outputs.apigatewayv2.GetApiCorsConfiguration[];
    /**
     * The description of the API.
     */
    readonly description: string;
    /**
     * Whether clients can invoke the API by using the default `execute-api` endpoint.
     */
    readonly disableExecuteApiEndpoint: boolean;
    /**
     * The ARN prefix to be used in an `aws.lambda.Permission`'s `sourceArn` attribute
     * or in an `aws.iam.Policy` to authorize access to the [`@connections` API](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-how-to-call-websocket-api-connections.html).
     * See the [Amazon API Gateway Developer Guide](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-control-access-iam.html) for details.
     */
    readonly executionArn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The name of the API.
     */
    readonly name: string;
    /**
     * The API protocol.
     */
    readonly protocolType: string;
    /**
     * The [route selection expression](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-route-selection-expressions) for the API.
     */
    readonly routeSelectionExpression: string;
    /**
     * A map of resource tags.
     */
    readonly tags: {
        [key: string]: string;
    };
    /**
     * A version identifier for the API.
     */
    readonly version: string;
}
