import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an Auto Scaling Attachment resource.
 *
 * > **NOTE on Auto Scaling Groups and ASG Attachments:** This provider currently provides
 * both a standalone `aws.autoscaling.Attachment` resource
 * (describing an ASG attached to an ELB or ALB), and an `aws.autoscaling.Group`
 * with `loadBalancers` and `targetGroupArns` defined in-line. These two methods are not
 * mutually-exclusive. If `aws.autoscaling.Attachment` resources are used, either alone or with inline
 * `loadBalancers` or `targetGroupArns`, the `aws.autoscaling.Group` resource must be configured
 * to [ignore changes](https://www.pulumi.com/docs/intro/concepts/programming-model/#ignorechanges) to the `loadBalancers` and `targetGroupArns` arguments.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // Create a new load balancer attachment
 * const asgAttachmentBar = new aws.autoscaling.Attachment("asgAttachmentBar", {
 *     autoscalingGroupName: aws_autoscaling_group.asg.id,
 *     elb: aws_elb.bar.id,
 * });
 * ```
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // Create a new ALB Target Group attachment
 * const asgAttachmentBar = new aws.autoscaling.Attachment("asgAttachmentBar", {
 *     autoscalingGroupName: aws_autoscaling_group.asg.id,
 *     albTargetGroupArn: aws_alb_target_group.test.arn,
 * });
 * ```
 * ## With An AutoScaling Group Resource
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // ... other configuration ...
 * const asg = new aws.autoscaling.Group("asg", {});
 * const asgAttachmentBar = new aws.autoscaling.Attachment("asgAttachmentBar", {
 *     autoscalingGroupName: asg.id,
 *     elb: aws_elb.test.id,
 * });
 * ```
 */
export declare class Attachment extends pulumi.CustomResource {
    /**
     * Get an existing Attachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AttachmentState, opts?: pulumi.CustomResourceOptions): Attachment;
    /**
     * Returns true if the given object is an instance of Attachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Attachment;
    /**
     * The ARN of an ALB Target Group.
     */
    readonly albTargetGroupArn: pulumi.Output<string | undefined>;
    /**
     * Name of ASG to associate with the ELB.
     */
    readonly autoscalingGroupName: pulumi.Output<string>;
    /**
     * The name of the ELB.
     */
    readonly elb: pulumi.Output<string | undefined>;
    /**
     * Create a Attachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Attachment resources.
 */
export interface AttachmentState {
    /**
     * The ARN of an ALB Target Group.
     */
    readonly albTargetGroupArn?: pulumi.Input<string>;
    /**
     * Name of ASG to associate with the ELB.
     */
    readonly autoscalingGroupName?: pulumi.Input<string>;
    /**
     * The name of the ELB.
     */
    readonly elb?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Attachment resource.
 */
export interface AttachmentArgs {
    /**
     * The ARN of an ALB Target Group.
     */
    readonly albTargetGroupArn?: pulumi.Input<string>;
    /**
     * Name of ASG to associate with the ELB.
     */
    readonly autoscalingGroupName: pulumi.Input<string>;
    /**
     * The name of the ELB.
     */
    readonly elb?: pulumi.Input<string>;
}
