import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an AWS Config Remediation Configuration.
 *
 * > **Note:** Config Remediation Configuration requires an existing Config Rule to be present.
 *
 * ## Example Usage
 *
 * AWS managed rules can be used by setting the source owner to `AWS` and the source identifier to the name of the managed rule. More information about AWS managed rules can be found in the [AWS Config Developer Guide](https://docs.aws.amazon.com/config/latest/developerguide/evaluate-config_use-managed-rules.html).
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const thisRule = new aws.cfg.Rule("thisRule", {source: {
 *     owner: "AWS",
 *     sourceIdentifier: "S3_BUCKET_VERSIONING_ENABLED",
 * }});
 * const thisRemediationConfiguration = new aws.cfg.RemediationConfiguration("thisRemediationConfiguration", {
 *     configRuleName: thisRule.name,
 *     resourceType: "AWS::S3::Bucket",
 *     targetType: "SSM_DOCUMENT",
 *     targetId: "AWS-EnableS3BucketEncryption",
 *     targetVersion: "1",
 *     parameters: [
 *         {
 *             name: "AutomationAssumeRole",
 *             staticValue: "arn:aws:iam::875924563244:role/security_config",
 *         },
 *         {
 *             name: "BucketName",
 *             resourceValue: "RESOURCE_ID",
 *         },
 *         {
 *             name: "SSEAlgorithm",
 *             staticValue: "AES256",
 *         },
 *     ],
 * });
 * ```
 *
 * ## Import
 *
 * Remediation Configurations can be imported using the name config_rule_name, e.g.
 *
 * ```sh
 *  $ pulumi import aws:cfg/remediationConfiguration:RemediationConfiguration this example
 * ```
 */
export declare class RemediationConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing RemediationConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RemediationConfigurationState, opts?: pulumi.CustomResourceOptions): RemediationConfiguration;
    /**
     * Returns true if the given object is an instance of RemediationConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RemediationConfiguration;
    /**
     * Amazon Resource Name (ARN) of the Config Remediation Configuration.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the AWS Config rule
     */
    readonly configRuleName: pulumi.Output<string>;
    /**
     * Can be specified multiple times for each
     * parameter. Each parameter block supports fields documented below.
     */
    readonly parameters: pulumi.Output<outputs.cfg.RemediationConfigurationParameter[] | undefined>;
    /**
     * The type of a resource
     */
    readonly resourceType: pulumi.Output<string | undefined>;
    /**
     * Target ID is the name of the public document
     */
    readonly targetId: pulumi.Output<string>;
    /**
     * The type of the target. Target executes remediation. For example, SSM document
     */
    readonly targetType: pulumi.Output<string>;
    /**
     * Version of the target. For example, version of the SSM document
     */
    readonly targetVersion: pulumi.Output<string | undefined>;
    /**
     * Create a RemediationConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RemediationConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RemediationConfiguration resources.
 */
export interface RemediationConfigurationState {
    /**
     * Amazon Resource Name (ARN) of the Config Remediation Configuration.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The name of the AWS Config rule
     */
    readonly configRuleName?: pulumi.Input<string>;
    /**
     * Can be specified multiple times for each
     * parameter. Each parameter block supports fields documented below.
     */
    readonly parameters?: pulumi.Input<pulumi.Input<inputs.cfg.RemediationConfigurationParameter>[]>;
    /**
     * The type of a resource
     */
    readonly resourceType?: pulumi.Input<string>;
    /**
     * Target ID is the name of the public document
     */
    readonly targetId?: pulumi.Input<string>;
    /**
     * The type of the target. Target executes remediation. For example, SSM document
     */
    readonly targetType?: pulumi.Input<string>;
    /**
     * Version of the target. For example, version of the SSM document
     */
    readonly targetVersion?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a RemediationConfiguration resource.
 */
export interface RemediationConfigurationArgs {
    /**
     * The name of the AWS Config rule
     */
    readonly configRuleName: pulumi.Input<string>;
    /**
     * Can be specified multiple times for each
     * parameter. Each parameter block supports fields documented below.
     */
    readonly parameters?: pulumi.Input<pulumi.Input<inputs.cfg.RemediationConfigurationParameter>[]>;
    /**
     * The type of a resource
     */
    readonly resourceType?: pulumi.Input<string>;
    /**
     * Target ID is the name of the public document
     */
    readonly targetId: pulumi.Input<string>;
    /**
     * The type of the target. Target executes remediation. For example, SSM document
     */
    readonly targetType: pulumi.Input<string>;
    /**
     * Version of the target. For example, version of the SSM document
     */
    readonly targetVersion?: pulumi.Input<string>;
}
