import * as pulumi from "@pulumi/pulumi";
/**
 * The CloudFormation Export data source allows access to stack
 * exports specified in the [Output](http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/outputs-section-structure.html) section of the Cloudformation Template using the optional Export Property.
 *
 *  > Note: If you are trying to use a value from a Cloudformation Stack in the same deployment please use normal interpolation or Cloudformation Outputs.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const subnetId = aws.cloudformation.getExport({
 *     name: "mySubnetIdExportName",
 * });
 * const web = new aws.ec2.Instance("web", {
 *     ami: "ami-abb07bcb",
 *     instanceType: "t2.micro",
 *     subnetId: subnetId.then(subnetId => subnetId.value),
 * });
 * ```
 */
export declare function getExport(args: GetExportArgs, opts?: pulumi.InvokeOptions): Promise<GetExportResult>;
/**
 * A collection of arguments for invoking getExport.
 */
export interface GetExportArgs {
    /**
     * The name of the export as it appears in the console or from [list-exports](http://docs.aws.amazon.com/cli/latest/reference/cloudformation/list-exports.html)
     */
    readonly name: string;
}
/**
 * A collection of values returned by getExport.
 */
export interface GetExportResult {
    /**
     * The exportingStackId (AWS ARNs) equivalent `ExportingStackId` from [list-exports](http://docs.aws.amazon.com/cli/latest/reference/cloudformation/list-exports.html)
     */
    readonly exportingStackId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
    /**
     * The value from Cloudformation export identified by the export name found from [list-exports](http://docs.aws.amazon.com/cli/latest/reference/cloudformation/list-exports.html)
     */
    readonly value: string;
}
