import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an EventBridge event archive resource.
 *
 * > **Note:** EventBridge was formerly known as CloudWatch Events. The functionality is identical.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const orderEventBus = new aws.cloudwatch.EventBus("orderEventBus", {});
 * const orderEventArchive = new aws.cloudwatch.EventArchive("orderEventArchive", {eventSourceArn: orderEventBus.arn});
 * ```
 * ## Example all optional arguments
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const orderEventBus = new aws.cloudwatch.EventBus("orderEventBus", {});
 * const orderEventArchive = new aws.cloudwatch.EventArchive("orderEventArchive", {
 *     description: "Archived events from order service",
 *     eventSourceArn: orderEventBus.arn,
 *     retentionDays: 7,
 *     eventPattern: `{
 *   "source": ["company.team.order"]
 * }
 * `,
 * });
 * ```
 *
 * ## Import
 *
 * Event Archive can be imported using their name, for example bash
 *
 * ```sh
 *  $ pulumi import aws:cloudwatch/eventArchive:EventArchive imported_event_archive order-archive
 * ```
 */
export declare class EventArchive extends pulumi.CustomResource {
    /**
     * Get an existing EventArchive resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EventArchiveState, opts?: pulumi.CustomResourceOptions): EventArchive;
    /**
     * Returns true if the given object is an instance of EventArchive.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EventArchive;
    /**
     * The Amazon Resource Name (ARN) of the event archive.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description of the new event archive.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Instructs the new event archive to only capture events matched by this pattern. By default, it attempts to archive every event received in the `eventSourceArn`.
     */
    readonly eventPattern: pulumi.Output<string | undefined>;
    /**
     * Event bus source ARN from where these events should be archived.
     */
    readonly eventSourceArn: pulumi.Output<string>;
    /**
     * The name of the new event archive. The archive name cannot exceed 48 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The maximum number of days to retain events in the new event archive. By default, it archives indefinitely.
     */
    readonly retentionDays: pulumi.Output<number | undefined>;
    /**
     * Create a EventArchive resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EventArchiveArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EventArchive resources.
 */
export interface EventArchiveState {
    /**
     * The Amazon Resource Name (ARN) of the event archive.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The description of the new event archive.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Instructs the new event archive to only capture events matched by this pattern. By default, it attempts to archive every event received in the `eventSourceArn`.
     */
    readonly eventPattern?: pulumi.Input<string>;
    /**
     * Event bus source ARN from where these events should be archived.
     */
    readonly eventSourceArn?: pulumi.Input<string>;
    /**
     * The name of the new event archive. The archive name cannot exceed 48 characters.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The maximum number of days to retain events in the new event archive. By default, it archives indefinitely.
     */
    readonly retentionDays?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a EventArchive resource.
 */
export interface EventArchiveArgs {
    /**
     * The description of the new event archive.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Instructs the new event archive to only capture events matched by this pattern. By default, it attempts to archive every event received in the `eventSourceArn`.
     */
    readonly eventPattern?: pulumi.Input<string>;
    /**
     * Event bus source ARN from where these events should be archived.
     */
    readonly eventSourceArn: pulumi.Input<string>;
    /**
     * The name of the new event archive. The archive name cannot exceed 48 characters.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The maximum number of days to retain events in the new event archive. By default, it archives indefinitely.
     */
    readonly retentionDays?: pulumi.Input<number>;
}
