import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a CodeBuild Project resource. See also the `aws.codebuild.Webhook` resource, which manages the webhook to the source (e.g. the "rebuild every time a code change is pushed" option in the CodeBuild web console).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleBucket = new aws.s3.Bucket("exampleBucket", {acl: "private"});
 * const exampleRole = new aws.iam.Role("exampleRole", {assumeRolePolicy: `{
 *   "Version": "2012-10-17",
 *   "Statement": [
 *     {
 *       "Effect": "Allow",
 *       "Principal": {
 *         "Service": "codebuild.amazonaws.com"
 *       },
 *       "Action": "sts:AssumeRole"
 *     }
 *   ]
 * }
 * `});
 * const exampleRolePolicy = new aws.iam.RolePolicy("exampleRolePolicy", {
 *     role: exampleRole.name,
 *     policy: pulumi.interpolate`{
 *   "Version": "2012-10-17",
 *   "Statement": [
 *     {
 *       "Effect": "Allow",
 *       "Resource": [
 *         "*"
 *       ],
 *       "Action": [
 *         "logs:CreateLogGroup",
 *         "logs:CreateLogStream",
 *         "logs:PutLogEvents"
 *       ]
 *     },
 *     {
 *       "Effect": "Allow",
 *       "Action": [
 *         "ec2:CreateNetworkInterface",
 *         "ec2:DescribeDhcpOptions",
 *         "ec2:DescribeNetworkInterfaces",
 *         "ec2:DeleteNetworkInterface",
 *         "ec2:DescribeSubnets",
 *         "ec2:DescribeSecurityGroups",
 *         "ec2:DescribeVpcs"
 *       ],
 *       "Resource": "*"
 *     },
 *     {
 *       "Effect": "Allow",
 *       "Action": [
 *         "ec2:CreateNetworkInterfacePermission"
 *       ],
 *       "Resource": [
 *         "arn:aws:ec2:us-east-1:123456789012:network-interface/*"
 *       ],
 *       "Condition": {
 *         "StringEquals": {
 *           "ec2:Subnet": [
 *             "${aws_subnet.example1.arn}",
 *             "${aws_subnet.example2.arn}"
 *           ],
 *           "ec2:AuthorizedService": "codebuild.amazonaws.com"
 *         }
 *       }
 *     },
 *     {
 *       "Effect": "Allow",
 *       "Action": [
 *         "s3:*"
 *       ],
 *       "Resource": [
 *         "${exampleBucket.arn}",
 *         "${exampleBucket.arn}/*"
 *       ]
 *     }
 *   ]
 * }
 * `,
 * });
 * const exampleProject = new aws.codebuild.Project("exampleProject", {
 *     description: "test_codebuild_project",
 *     buildTimeout: "5",
 *     serviceRole: exampleRole.arn,
 *     artifacts: {
 *         type: "NO_ARTIFACTS",
 *     },
 *     cache: {
 *         type: "S3",
 *         location: exampleBucket.bucket,
 *     },
 *     environment: {
 *         computeType: "BUILD_GENERAL1_SMALL",
 *         image: "aws/codebuild/standard:1.0",
 *         type: "LINUX_CONTAINER",
 *         imagePullCredentialsType: "CODEBUILD",
 *         environmentVariables: [
 *             {
 *                 name: "SOME_KEY1",
 *                 value: "SOME_VALUE1",
 *             },
 *             {
 *                 name: "SOME_KEY2",
 *                 value: "SOME_VALUE2",
 *                 type: "PARAMETER_STORE",
 *             },
 *         ],
 *     },
 *     logsConfig: {
 *         cloudwatchLogs: {
 *             groupName: "log-group",
 *             streamName: "log-stream",
 *         },
 *         s3Logs: {
 *             status: "ENABLED",
 *             location: pulumi.interpolate`${exampleBucket.id}/build-log`,
 *         },
 *     },
 *     source: {
 *         type: "GITHUB",
 *         location: "https://github.com/mitchellh/packer.git",
 *         gitCloneDepth: 1,
 *         gitSubmodulesConfig: {
 *             fetchSubmodules: true,
 *         },
 *     },
 *     sourceVersion: "master",
 *     vpcConfig: {
 *         vpcId: aws_vpc.example.id,
 *         subnets: [
 *             aws_subnet.example1.id,
 *             aws_subnet.example2.id,
 *         ],
 *         securityGroupIds: [
 *             aws_security_group.example1.id,
 *             aws_security_group.example2.id,
 *         ],
 *     },
 *     tags: {
 *         Environment: "Test",
 *     },
 * });
 * const project_with_cache = new aws.codebuild.Project("project-with-cache", {
 *     description: "test_codebuild_project_cache",
 *     buildTimeout: "5",
 *     queuedTimeout: "5",
 *     serviceRole: exampleRole.arn,
 *     artifacts: {
 *         type: "NO_ARTIFACTS",
 *     },
 *     cache: {
 *         type: "LOCAL",
 *         modes: [
 *             "LOCAL_DOCKER_LAYER_CACHE",
 *             "LOCAL_SOURCE_CACHE",
 *         ],
 *     },
 *     environment: {
 *         computeType: "BUILD_GENERAL1_SMALL",
 *         image: "aws/codebuild/standard:1.0",
 *         type: "LINUX_CONTAINER",
 *         imagePullCredentialsType: "CODEBUILD",
 *         environmentVariables: [{
 *             name: "SOME_KEY1",
 *             value: "SOME_VALUE1",
 *         }],
 *     },
 *     source: {
 *         type: "GITHUB",
 *         location: "https://github.com/mitchellh/packer.git",
 *         gitCloneDepth: 1,
 *     },
 *     tags: {
 *         Environment: "Test",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * CodeBuild Project can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:codebuild/project:Project name project-name
 * ```
 */
export declare class Project extends pulumi.CustomResource {
    /**
     * Get an existing Project resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ProjectState, opts?: pulumi.CustomResourceOptions): Project;
    /**
     * Returns true if the given object is an instance of Project.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Project;
    /**
     * ARN of the CodeBuild project.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly artifacts: pulumi.Output<outputs.codebuild.ProjectArtifacts>;
    /**
     * Generates a publicly-accessible URL for the projects build badge. Available as `badgeUrl` attribute when enabled.
     */
    readonly badgeEnabled: pulumi.Output<boolean | undefined>;
    /**
     * URL of the build badge when `badgeEnabled` is enabled.
     */
    readonly badgeUrl: pulumi.Output<string>;
    /**
     * Number of minutes, from 5 to 480 (8 hours), for AWS CodeBuild to wait until timing out any related build that does not get marked as completed. The default is 60 minutes.
     */
    readonly buildTimeout: pulumi.Output<number | undefined>;
    /**
     * Configuration block. Detailed below.
     */
    readonly cache: pulumi.Output<outputs.codebuild.ProjectCache | undefined>;
    /**
     * Short description of the project.
     */
    readonly description: pulumi.Output<string>;
    /**
     * AWS Key Management Service (AWS KMS) customer master key (CMK) to be used for encrypting the build project's build output artifacts.
     */
    readonly encryptionKey: pulumi.Output<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly environment: pulumi.Output<outputs.codebuild.ProjectEnvironment>;
    /**
     * Configuration block. Detailed below.
     */
    readonly logsConfig: pulumi.Output<outputs.codebuild.ProjectLogsConfig | undefined>;
    /**
     * Name of the project. If `type` is set to `S3`, this is the name of the output artifact object
     */
    readonly name: pulumi.Output<string>;
    /**
     * Number of minutes, from 5 to 480 (8 hours), a build is allowed to be queued before it times out. The default is 8 hours.
     */
    readonly queuedTimeout: pulumi.Output<number | undefined>;
    /**
     * Configuration block. Detailed below.
     */
    readonly secondaryArtifacts: pulumi.Output<outputs.codebuild.ProjectSecondaryArtifact[] | undefined>;
    /**
     * Configuration block. Detailed below.
     */
    readonly secondarySources: pulumi.Output<outputs.codebuild.ProjectSecondarySource[] | undefined>;
    /**
     * Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account.
     */
    readonly serviceRole: pulumi.Output<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly source: pulumi.Output<outputs.codebuild.ProjectSource>;
    /**
     * Version of the build input to be built for this project. If not specified, the latest version is used.
     */
    readonly sourceVersion: pulumi.Output<string | undefined>;
    /**
     * Map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Configuration block. Detailed below.
     */
    readonly vpcConfig: pulumi.Output<outputs.codebuild.ProjectVpcConfig | undefined>;
    /**
     * Create a Project resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Project resources.
 */
export interface ProjectState {
    /**
     * ARN of the CodeBuild project.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly artifacts?: pulumi.Input<inputs.codebuild.ProjectArtifacts>;
    /**
     * Generates a publicly-accessible URL for the projects build badge. Available as `badgeUrl` attribute when enabled.
     */
    readonly badgeEnabled?: pulumi.Input<boolean>;
    /**
     * URL of the build badge when `badgeEnabled` is enabled.
     */
    readonly badgeUrl?: pulumi.Input<string>;
    /**
     * Number of minutes, from 5 to 480 (8 hours), for AWS CodeBuild to wait until timing out any related build that does not get marked as completed. The default is 60 minutes.
     */
    readonly buildTimeout?: pulumi.Input<number>;
    /**
     * Configuration block. Detailed below.
     */
    readonly cache?: pulumi.Input<inputs.codebuild.ProjectCache>;
    /**
     * Short description of the project.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * AWS Key Management Service (AWS KMS) customer master key (CMK) to be used for encrypting the build project's build output artifacts.
     */
    readonly encryptionKey?: pulumi.Input<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly environment?: pulumi.Input<inputs.codebuild.ProjectEnvironment>;
    /**
     * Configuration block. Detailed below.
     */
    readonly logsConfig?: pulumi.Input<inputs.codebuild.ProjectLogsConfig>;
    /**
     * Name of the project. If `type` is set to `S3`, this is the name of the output artifact object
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Number of minutes, from 5 to 480 (8 hours), a build is allowed to be queued before it times out. The default is 8 hours.
     */
    readonly queuedTimeout?: pulumi.Input<number>;
    /**
     * Configuration block. Detailed below.
     */
    readonly secondaryArtifacts?: pulumi.Input<pulumi.Input<inputs.codebuild.ProjectSecondaryArtifact>[]>;
    /**
     * Configuration block. Detailed below.
     */
    readonly secondarySources?: pulumi.Input<pulumi.Input<inputs.codebuild.ProjectSecondarySource>[]>;
    /**
     * Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account.
     */
    readonly serviceRole?: pulumi.Input<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly source?: pulumi.Input<inputs.codebuild.ProjectSource>;
    /**
     * Version of the build input to be built for this project. If not specified, the latest version is used.
     */
    readonly sourceVersion?: pulumi.Input<string>;
    /**
     * Map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Configuration block. Detailed below.
     */
    readonly vpcConfig?: pulumi.Input<inputs.codebuild.ProjectVpcConfig>;
}
/**
 * The set of arguments for constructing a Project resource.
 */
export interface ProjectArgs {
    /**
     * Configuration block. Detailed below.
     */
    readonly artifacts: pulumi.Input<inputs.codebuild.ProjectArtifacts>;
    /**
     * Generates a publicly-accessible URL for the projects build badge. Available as `badgeUrl` attribute when enabled.
     */
    readonly badgeEnabled?: pulumi.Input<boolean>;
    /**
     * Number of minutes, from 5 to 480 (8 hours), for AWS CodeBuild to wait until timing out any related build that does not get marked as completed. The default is 60 minutes.
     */
    readonly buildTimeout?: pulumi.Input<number>;
    /**
     * Configuration block. Detailed below.
     */
    readonly cache?: pulumi.Input<inputs.codebuild.ProjectCache>;
    /**
     * Short description of the project.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * AWS Key Management Service (AWS KMS) customer master key (CMK) to be used for encrypting the build project's build output artifacts.
     */
    readonly encryptionKey?: pulumi.Input<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly environment: pulumi.Input<inputs.codebuild.ProjectEnvironment>;
    /**
     * Configuration block. Detailed below.
     */
    readonly logsConfig?: pulumi.Input<inputs.codebuild.ProjectLogsConfig>;
    /**
     * Name of the project. If `type` is set to `S3`, this is the name of the output artifact object
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Number of minutes, from 5 to 480 (8 hours), a build is allowed to be queued before it times out. The default is 8 hours.
     */
    readonly queuedTimeout?: pulumi.Input<number>;
    /**
     * Configuration block. Detailed below.
     */
    readonly secondaryArtifacts?: pulumi.Input<pulumi.Input<inputs.codebuild.ProjectSecondaryArtifact>[]>;
    /**
     * Configuration block. Detailed below.
     */
    readonly secondarySources?: pulumi.Input<pulumi.Input<inputs.codebuild.ProjectSecondarySource>[]>;
    /**
     * Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account.
     */
    readonly serviceRole: pulumi.Input<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly source: pulumi.Input<inputs.codebuild.ProjectSource>;
    /**
     * Version of the build input to be built for this project. If not specified, the latest version is used.
     */
    readonly sourceVersion?: pulumi.Input<string>;
    /**
     * Map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Configuration block. Detailed below.
     */
    readonly vpcConfig?: pulumi.Input<inputs.codebuild.ProjectVpcConfig>;
}
