import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a CodeBuild Report Groups Resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleKey = new aws.kms.Key("exampleKey", {
 *     description: "my test kms key",
 *     deletionWindowInDays: 7,
 *     policy: `{
 *   "Version": "2012-10-17",
 *   "Id": "kms-tf-1",
 *   "Statement": [
 *     {
 *       "Sid": "Enable IAM User Permissions",
 *       "Effect": "Allow",
 *       "Principal": {
 *         "AWS": "*"
 *       },
 *       "Action": "kms:*",
 *       "Resource": "*"
 *     }
 *   ]
 * }
 * `,
 * });
 * const exampleBucket = new aws.s3.Bucket("exampleBucket", {});
 * const exampleReportGroup = new aws.codebuild.ReportGroup("exampleReportGroup", {
 *     type: "TEST",
 *     exportConfig: {
 *         type: "S3",
 *         s3Destination: {
 *             bucket: exampleBucket.id,
 *             encryptionDisabled: false,
 *             encryptionKey: exampleKey.arn,
 *             packaging: "NONE",
 *             path: "/some",
 *         },
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * CodeBuild Report Group can be imported using the CodeBuild Report Group arn, e.g.
 *
 * ```sh
 *  $ pulumi import aws:codebuild/reportGroup:ReportGroup example arn:aws:codebuild:us-west-2:123456789:report-group/report-group-name
 * ```
 */
export declare class ReportGroup extends pulumi.CustomResource {
    /**
     * Get an existing ReportGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ReportGroupState, opts?: pulumi.CustomResourceOptions): ReportGroup;
    /**
     * Returns true if the given object is an instance of ReportGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ReportGroup;
    /**
     * The ARN of Report Group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The date and time this Report Group was created.
     */
    readonly created: pulumi.Output<string>;
    /**
     * If `true`, deletes any reports that belong to a report group before deleting the report group. If `false`, you must delete any reports in the report group before deleting it. Default value is `false`.
     */
    readonly deleteReports: pulumi.Output<boolean | undefined>;
    /**
     * Information about the destination where the raw data of this Report Group is exported. see Export Config documented below.
     */
    readonly exportConfig: pulumi.Output<outputs.codebuild.ReportGroupExportConfig>;
    /**
     * The name of a Report Group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Key-value mapping of resource tags
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The export configuration type. Valid values are `S3` and `NO_EXPORT`.
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a ReportGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ReportGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ReportGroup resources.
 */
export interface ReportGroupState {
    /**
     * The ARN of Report Group.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The date and time this Report Group was created.
     */
    readonly created?: pulumi.Input<string>;
    /**
     * If `true`, deletes any reports that belong to a report group before deleting the report group. If `false`, you must delete any reports in the report group before deleting it. Default value is `false`.
     */
    readonly deleteReports?: pulumi.Input<boolean>;
    /**
     * Information about the destination where the raw data of this Report Group is exported. see Export Config documented below.
     */
    readonly exportConfig?: pulumi.Input<inputs.codebuild.ReportGroupExportConfig>;
    /**
     * The name of a Report Group.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Key-value mapping of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The export configuration type. Valid values are `S3` and `NO_EXPORT`.
     */
    readonly type?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ReportGroup resource.
 */
export interface ReportGroupArgs {
    /**
     * If `true`, deletes any reports that belong to a report group before deleting the report group. If `false`, you must delete any reports in the report group before deleting it. Default value is `false`.
     */
    readonly deleteReports?: pulumi.Input<boolean>;
    /**
     * Information about the destination where the raw data of this Report Group is exported. see Export Config documented below.
     */
    readonly exportConfig: pulumi.Input<inputs.codebuild.ReportGroupExportConfig>;
    /**
     * The name of a Report Group.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Key-value mapping of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The export configuration type. Valid values are `S3` and `NO_EXPORT`.
     */
    readonly type: pulumi.Input<string>;
}
