import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an AWS Cognito Identity Pool Roles Attachment.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const mainIdentityPool = new aws.cognito.IdentityPool("mainIdentityPool", {
 *     identityPoolName: "identity pool",
 *     allowUnauthenticatedIdentities: false,
 *     supportedLoginProviders: {
 *         "graph.facebook.com": "7346241598935555",
 *     },
 * });
 * const authenticatedRole = new aws.iam.Role("authenticatedRole", {assumeRolePolicy: pulumi.interpolate`{
 *   "Version": "2012-10-17",
 *   "Statement": [
 *     {
 *       "Effect": "Allow",
 *       "Principal": {
 *         "Federated": "cognito-identity.amazonaws.com"
 *       },
 *       "Action": "sts:AssumeRoleWithWebIdentity",
 *       "Condition": {
 *         "StringEquals": {
 *           "cognito-identity.amazonaws.com:aud": "${mainIdentityPool.id}"
 *         },
 *         "ForAnyValue:StringLike": {
 *           "cognito-identity.amazonaws.com:amr": "authenticated"
 *         }
 *       }
 *     }
 *   ]
 * }
 * `});
 * const authenticatedRolePolicy = new aws.iam.RolePolicy("authenticatedRolePolicy", {
 *     role: authenticatedRole.id,
 *     policy: `{
 *   "Version": "2012-10-17",
 *   "Statement": [
 *     {
 *       "Effect": "Allow",
 *       "Action": [
 *         "mobileanalytics:PutEvents",
 *         "cognito-sync:*",
 *         "cognito-identity:*"
 *       ],
 *       "Resource": [
 *         "*"
 *       ]
 *     }
 *   ]
 * }
 * `,
 * });
 * const mainIdentityPoolRoleAttachment = new aws.cognito.IdentityPoolRoleAttachment("mainIdentityPoolRoleAttachment", {
 *     identityPoolId: mainIdentityPool.id,
 *     roleMappings: [{
 *         identityProvider: "graph.facebook.com",
 *         ambiguousRoleResolution: "AuthenticatedRole",
 *         type: "Rules",
 *         mappingRules: [{
 *             claim: "isAdmin",
 *             matchType: "Equals",
 *             roleArn: authenticatedRole.arn,
 *             value: "paid",
 *         }],
 *     }],
 *     roles: {
 *         authenticated: authenticatedRole.arn,
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Cognito Identity Pool Roles Attachment can be imported using the Identity Pool id, e.g.
 *
 * ```sh
 *  $ pulumi import aws:cognito/identityPoolRoleAttachment:IdentityPoolRoleAttachment example <identity-pool-id>
 * ```
 */
export declare class IdentityPoolRoleAttachment extends pulumi.CustomResource {
    /**
     * Get an existing IdentityPoolRoleAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IdentityPoolRoleAttachmentState, opts?: pulumi.CustomResourceOptions): IdentityPoolRoleAttachment;
    /**
     * Returns true if the given object is an instance of IdentityPoolRoleAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IdentityPoolRoleAttachment;
    /**
     * An identity pool ID in the format REGION:GUID.
     */
    readonly identityPoolId: pulumi.Output<string>;
    /**
     * A List of Role Mapping.
     */
    readonly roleMappings: pulumi.Output<outputs.cognito.IdentityPoolRoleAttachmentRoleMapping[] | undefined>;
    /**
     * The map of roles associated with this pool. For a given role, the key will be either "authenticated" or "unauthenticated" and the value will be the Role ARN.
     */
    readonly roles: pulumi.Output<{
        [key: string]: string;
    }>;
    /**
     * Create a IdentityPoolRoleAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IdentityPoolRoleAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IdentityPoolRoleAttachment resources.
 */
export interface IdentityPoolRoleAttachmentState {
    /**
     * An identity pool ID in the format REGION:GUID.
     */
    readonly identityPoolId?: pulumi.Input<string>;
    /**
     * A List of Role Mapping.
     */
    readonly roleMappings?: pulumi.Input<pulumi.Input<inputs.cognito.IdentityPoolRoleAttachmentRoleMapping>[]>;
    /**
     * The map of roles associated with this pool. For a given role, the key will be either "authenticated" or "unauthenticated" and the value will be the Role ARN.
     */
    readonly roles?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a IdentityPoolRoleAttachment resource.
 */
export interface IdentityPoolRoleAttachmentArgs {
    /**
     * An identity pool ID in the format REGION:GUID.
     */
    readonly identityPoolId: pulumi.Input<string>;
    /**
     * A List of Role Mapping.
     */
    readonly roleMappings?: pulumi.Input<pulumi.Input<inputs.cognito.IdentityPoolRoleAttachmentRoleMapping>[]>;
    /**
     * The map of roles associated with this pool. For a given role, the key will be either "authenticated" or "unauthenticated" and the value will be the Role ARN.
     */
    readonly roles: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
