import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a Cognito User Pool resource.
 *
 * ## Example Usage
 * ### Basic configuration
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const pool = new aws.cognito.UserPool("pool", {});
 * ```
 * ### Enabling SMS and Software Token Multi-Factor Authentication
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // ... other configuration ...
 * const example = new aws.cognito.UserPool("example", {
 *     mfaConfiguration: "ON",
 *     smsAuthenticationMessage: "Your code is {####}",
 *     smsConfiguration: {
 *         externalId: "example",
 *         snsCallerArn: aws_iam_role.example.arn,
 *     },
 *     softwareTokenMfaConfiguration: {
 *         enabled: true,
 *     },
 * });
 * ```
 * ### Using Account Recovery Setting
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.cognito.UserPool("test", {
 *     accountRecoverySetting: {
 *         recoveryMechanisms: [
 *             {
 *                 name: "verified_email",
 *                 priority: 1,
 *             },
 *             {
 *                 name: "verified_phone_number",
 *                 priority: 2,
 *             },
 *         ],
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Cognito User Pools can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:cognito/userPool:UserPool pool <id>
 * ```
 */
export declare class UserPool extends pulumi.CustomResource {
    /**
     * Get an existing UserPool resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UserPoolState, opts?: pulumi.CustomResourceOptions): UserPool;
    /**
     * Returns true if the given object is an instance of UserPool.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UserPool;
    /**
     * Configuration block to define which verified available method a user can use to recover their forgotten password. Detailed below.
     */
    readonly accountRecoverySetting: pulumi.Output<outputs.cognito.UserPoolAccountRecoverySetting | undefined>;
    /**
     * Configuration block for creating a new user profile. Detailed below.
     */
    readonly adminCreateUserConfig: pulumi.Output<outputs.cognito.UserPoolAdminCreateUserConfig>;
    /**
     * Attributes supported as an alias for this user pool. Valid values: `phoneNumber`, `email`, or `preferredUsername`. Conflicts with `usernameAttributes`.
     */
    readonly aliasAttributes: pulumi.Output<string[] | undefined>;
    /**
     * ARN of the user pool.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Attributes to be auto-verified. Valid values: `email`, `phoneNumber`.
     */
    readonly autoVerifiedAttributes: pulumi.Output<string[] | undefined>;
    /**
     * Date the user pool was created.
     */
    readonly creationDate: pulumi.Output<string>;
    /**
     * Configuration block for the user pool's device tracking. Detailed below.
     */
    readonly deviceConfiguration: pulumi.Output<outputs.cognito.UserPoolDeviceConfiguration | undefined>;
    /**
     * Configuration block for configuring email. Detailed below.
     */
    readonly emailConfiguration: pulumi.Output<outputs.cognito.UserPoolEmailConfiguration | undefined>;
    /**
     * String representing the email verification message. Conflicts with `verificationMessageTemplate` configuration block `emailMessage` argument.
     */
    readonly emailVerificationMessage: pulumi.Output<string>;
    /**
     * String representing the email verification subject. Conflicts with `verificationMessageTemplate` configuration block `emailSubject` argument.
     */
    readonly emailVerificationSubject: pulumi.Output<string>;
    /**
     * Endpoint name of the user pool. Example format: `cognito-idp.REGION.amazonaws.com/xxxx_yyyyy`
     */
    readonly endpoint: pulumi.Output<string>;
    /**
     * Configuration block for the AWS Lambda triggers associated with the user pool. Detailed below.
     */
    readonly lambdaConfig: pulumi.Output<outputs.cognito.UserPoolLambdaConfig>;
    /**
     * Date the user pool was last modified.
     */
    readonly lastModifiedDate: pulumi.Output<string>;
    /**
     * Multi-Factor Authentication (MFA) configuration for the User Pool. Defaults of `OFF`. Valid values are `OFF` (MFA Tokens are not required), `ON` (MFA is required for all users to sign in; requires at least one of `smsConfiguration` or `softwareTokenMfaConfiguration` to be configured), or `OPTIONAL` (MFA Will be required only for individual users who have MFA Enabled; requires at least one of `smsConfiguration` or `softwareTokenMfaConfiguration` to be configured).
     */
    readonly mfaConfiguration: pulumi.Output<string | undefined>;
    /**
     * Name of the attribute.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Configuration blocked for information about the user pool password policy. Detailed below.
     */
    readonly passwordPolicy: pulumi.Output<outputs.cognito.UserPoolPasswordPolicy>;
    /**
     * Configuration block for the schema attributes of a user pool. Detailed below. Schema attributes from the [standard attribute set](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html#cognito-user-pools-standard-attributes) only need to be specified if they are different from the default configuration. Maximum of 50 attributes.
     */
    readonly schemas: pulumi.Output<outputs.cognito.UserPoolSchema[] | undefined>;
    /**
     * String representing the SMS authentication message. The Message must contain the `{####}` placeholder, which will be replaced with the code.
     */
    readonly smsAuthenticationMessage: pulumi.Output<string | undefined>;
    /**
     * Configuration block for Short Message Service (SMS) settings. Detailed below. These settings apply to SMS user verification and SMS Multi-Factor Authentication (MFA). Due to Cognito API restrictions, the SMS configuration cannot be removed without recreating the Cognito User Pool. For user data safety, this resource will ignore the removal of this configuration by disabling drift detection.
     */
    readonly smsConfiguration: pulumi.Output<outputs.cognito.UserPoolSmsConfiguration>;
    /**
     * String representing the SMS verification message. Conflicts with `verificationMessageTemplate` configuration block `smsMessage` argument.
     */
    readonly smsVerificationMessage: pulumi.Output<string>;
    /**
     * Configuration block for software token Mult-Factor Authentication (MFA) settings. Detailed below.
     */
    readonly softwareTokenMfaConfiguration: pulumi.Output<outputs.cognito.UserPoolSoftwareTokenMfaConfiguration | undefined>;
    /**
     * Map of tags to assign to the User Pool.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Configuration block for user pool add-ons to enable user pool advanced security mode features. Detailed below.
     */
    readonly userPoolAddOns: pulumi.Output<outputs.cognito.UserPoolUserPoolAddOns | undefined>;
    /**
     * Whether email addresses or phone numbers can be specified as usernames when a user signs up. Conflicts with `aliasAttributes`.
     */
    readonly usernameAttributes: pulumi.Output<string[] | undefined>;
    /**
     * Configuration block for username configuration. Detailed below.
     */
    readonly usernameConfiguration: pulumi.Output<outputs.cognito.UserPoolUsernameConfiguration | undefined>;
    /**
     * Configuration block for verification message templates. Detailed below.
     */
    readonly verificationMessageTemplate: pulumi.Output<outputs.cognito.UserPoolVerificationMessageTemplate>;
    /**
     * Create a UserPool resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: UserPoolArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UserPool resources.
 */
export interface UserPoolState {
    /**
     * Configuration block to define which verified available method a user can use to recover their forgotten password. Detailed below.
     */
    readonly accountRecoverySetting?: pulumi.Input<inputs.cognito.UserPoolAccountRecoverySetting>;
    /**
     * Configuration block for creating a new user profile. Detailed below.
     */
    readonly adminCreateUserConfig?: pulumi.Input<inputs.cognito.UserPoolAdminCreateUserConfig>;
    /**
     * Attributes supported as an alias for this user pool. Valid values: `phoneNumber`, `email`, or `preferredUsername`. Conflicts with `usernameAttributes`.
     */
    readonly aliasAttributes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * ARN of the user pool.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Attributes to be auto-verified. Valid values: `email`, `phoneNumber`.
     */
    readonly autoVerifiedAttributes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Date the user pool was created.
     */
    readonly creationDate?: pulumi.Input<string>;
    /**
     * Configuration block for the user pool's device tracking. Detailed below.
     */
    readonly deviceConfiguration?: pulumi.Input<inputs.cognito.UserPoolDeviceConfiguration>;
    /**
     * Configuration block for configuring email. Detailed below.
     */
    readonly emailConfiguration?: pulumi.Input<inputs.cognito.UserPoolEmailConfiguration>;
    /**
     * String representing the email verification message. Conflicts with `verificationMessageTemplate` configuration block `emailMessage` argument.
     */
    readonly emailVerificationMessage?: pulumi.Input<string>;
    /**
     * String representing the email verification subject. Conflicts with `verificationMessageTemplate` configuration block `emailSubject` argument.
     */
    readonly emailVerificationSubject?: pulumi.Input<string>;
    /**
     * Endpoint name of the user pool. Example format: `cognito-idp.REGION.amazonaws.com/xxxx_yyyyy`
     */
    readonly endpoint?: pulumi.Input<string>;
    /**
     * Configuration block for the AWS Lambda triggers associated with the user pool. Detailed below.
     */
    readonly lambdaConfig?: pulumi.Input<inputs.cognito.UserPoolLambdaConfig>;
    /**
     * Date the user pool was last modified.
     */
    readonly lastModifiedDate?: pulumi.Input<string>;
    /**
     * Multi-Factor Authentication (MFA) configuration for the User Pool. Defaults of `OFF`. Valid values are `OFF` (MFA Tokens are not required), `ON` (MFA is required for all users to sign in; requires at least one of `smsConfiguration` or `softwareTokenMfaConfiguration` to be configured), or `OPTIONAL` (MFA Will be required only for individual users who have MFA Enabled; requires at least one of `smsConfiguration` or `softwareTokenMfaConfiguration` to be configured).
     */
    readonly mfaConfiguration?: pulumi.Input<string>;
    /**
     * Name of the attribute.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Configuration blocked for information about the user pool password policy. Detailed below.
     */
    readonly passwordPolicy?: pulumi.Input<inputs.cognito.UserPoolPasswordPolicy>;
    /**
     * Configuration block for the schema attributes of a user pool. Detailed below. Schema attributes from the [standard attribute set](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html#cognito-user-pools-standard-attributes) only need to be specified if they are different from the default configuration. Maximum of 50 attributes.
     */
    readonly schemas?: pulumi.Input<pulumi.Input<inputs.cognito.UserPoolSchema>[]>;
    /**
     * String representing the SMS authentication message. The Message must contain the `{####}` placeholder, which will be replaced with the code.
     */
    readonly smsAuthenticationMessage?: pulumi.Input<string>;
    /**
     * Configuration block for Short Message Service (SMS) settings. Detailed below. These settings apply to SMS user verification and SMS Multi-Factor Authentication (MFA). Due to Cognito API restrictions, the SMS configuration cannot be removed without recreating the Cognito User Pool. For user data safety, this resource will ignore the removal of this configuration by disabling drift detection.
     */
    readonly smsConfiguration?: pulumi.Input<inputs.cognito.UserPoolSmsConfiguration>;
    /**
     * String representing the SMS verification message. Conflicts with `verificationMessageTemplate` configuration block `smsMessage` argument.
     */
    readonly smsVerificationMessage?: pulumi.Input<string>;
    /**
     * Configuration block for software token Mult-Factor Authentication (MFA) settings. Detailed below.
     */
    readonly softwareTokenMfaConfiguration?: pulumi.Input<inputs.cognito.UserPoolSoftwareTokenMfaConfiguration>;
    /**
     * Map of tags to assign to the User Pool.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Configuration block for user pool add-ons to enable user pool advanced security mode features. Detailed below.
     */
    readonly userPoolAddOns?: pulumi.Input<inputs.cognito.UserPoolUserPoolAddOns>;
    /**
     * Whether email addresses or phone numbers can be specified as usernames when a user signs up. Conflicts with `aliasAttributes`.
     */
    readonly usernameAttributes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Configuration block for username configuration. Detailed below.
     */
    readonly usernameConfiguration?: pulumi.Input<inputs.cognito.UserPoolUsernameConfiguration>;
    /**
     * Configuration block for verification message templates. Detailed below.
     */
    readonly verificationMessageTemplate?: pulumi.Input<inputs.cognito.UserPoolVerificationMessageTemplate>;
}
/**
 * The set of arguments for constructing a UserPool resource.
 */
export interface UserPoolArgs {
    /**
     * Configuration block to define which verified available method a user can use to recover their forgotten password. Detailed below.
     */
    readonly accountRecoverySetting?: pulumi.Input<inputs.cognito.UserPoolAccountRecoverySetting>;
    /**
     * Configuration block for creating a new user profile. Detailed below.
     */
    readonly adminCreateUserConfig?: pulumi.Input<inputs.cognito.UserPoolAdminCreateUserConfig>;
    /**
     * Attributes supported as an alias for this user pool. Valid values: `phoneNumber`, `email`, or `preferredUsername`. Conflicts with `usernameAttributes`.
     */
    readonly aliasAttributes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Attributes to be auto-verified. Valid values: `email`, `phoneNumber`.
     */
    readonly autoVerifiedAttributes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Configuration block for the user pool's device tracking. Detailed below.
     */
    readonly deviceConfiguration?: pulumi.Input<inputs.cognito.UserPoolDeviceConfiguration>;
    /**
     * Configuration block for configuring email. Detailed below.
     */
    readonly emailConfiguration?: pulumi.Input<inputs.cognito.UserPoolEmailConfiguration>;
    /**
     * String representing the email verification message. Conflicts with `verificationMessageTemplate` configuration block `emailMessage` argument.
     */
    readonly emailVerificationMessage?: pulumi.Input<string>;
    /**
     * String representing the email verification subject. Conflicts with `verificationMessageTemplate` configuration block `emailSubject` argument.
     */
    readonly emailVerificationSubject?: pulumi.Input<string>;
    /**
     * Configuration block for the AWS Lambda triggers associated with the user pool. Detailed below.
     */
    readonly lambdaConfig?: pulumi.Input<inputs.cognito.UserPoolLambdaConfig>;
    /**
     * Multi-Factor Authentication (MFA) configuration for the User Pool. Defaults of `OFF`. Valid values are `OFF` (MFA Tokens are not required), `ON` (MFA is required for all users to sign in; requires at least one of `smsConfiguration` or `softwareTokenMfaConfiguration` to be configured), or `OPTIONAL` (MFA Will be required only for individual users who have MFA Enabled; requires at least one of `smsConfiguration` or `softwareTokenMfaConfiguration` to be configured).
     */
    readonly mfaConfiguration?: pulumi.Input<string>;
    /**
     * Name of the attribute.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Configuration blocked for information about the user pool password policy. Detailed below.
     */
    readonly passwordPolicy?: pulumi.Input<inputs.cognito.UserPoolPasswordPolicy>;
    /**
     * Configuration block for the schema attributes of a user pool. Detailed below. Schema attributes from the [standard attribute set](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html#cognito-user-pools-standard-attributes) only need to be specified if they are different from the default configuration. Maximum of 50 attributes.
     */
    readonly schemas?: pulumi.Input<pulumi.Input<inputs.cognito.UserPoolSchema>[]>;
    /**
     * String representing the SMS authentication message. The Message must contain the `{####}` placeholder, which will be replaced with the code.
     */
    readonly smsAuthenticationMessage?: pulumi.Input<string>;
    /**
     * Configuration block for Short Message Service (SMS) settings. Detailed below. These settings apply to SMS user verification and SMS Multi-Factor Authentication (MFA). Due to Cognito API restrictions, the SMS configuration cannot be removed without recreating the Cognito User Pool. For user data safety, this resource will ignore the removal of this configuration by disabling drift detection.
     */
    readonly smsConfiguration?: pulumi.Input<inputs.cognito.UserPoolSmsConfiguration>;
    /**
     * String representing the SMS verification message. Conflicts with `verificationMessageTemplate` configuration block `smsMessage` argument.
     */
    readonly smsVerificationMessage?: pulumi.Input<string>;
    /**
     * Configuration block for software token Mult-Factor Authentication (MFA) settings. Detailed below.
     */
    readonly softwareTokenMfaConfiguration?: pulumi.Input<inputs.cognito.UserPoolSoftwareTokenMfaConfiguration>;
    /**
     * Map of tags to assign to the User Pool.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Configuration block for user pool add-ons to enable user pool advanced security mode features. Detailed below.
     */
    readonly userPoolAddOns?: pulumi.Input<inputs.cognito.UserPoolUserPoolAddOns>;
    /**
     * Whether email addresses or phone numbers can be specified as usernames when a user signs up. Conflicts with `aliasAttributes`.
     */
    readonly usernameAttributes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Configuration block for username configuration. Detailed below.
     */
    readonly usernameConfiguration?: pulumi.Input<inputs.cognito.UserPoolUsernameConfiguration>;
    /**
     * Configuration block for verification message templates. Detailed below.
     */
    readonly verificationMessageTemplate?: pulumi.Input<inputs.cognito.UserPoolVerificationMessageTemplate>;
}
