import * as pulumi from "@pulumi/pulumi";
/**
 * Manages an AWS DataSync FSx Windows Location.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.datasync.LocationFsxWindows("example", {
 *     fsxFilesystemArn: aws_fsx_windows_file_system.example.arn,
 *     user: "SomeUser",
 *     password: "SuperSecretPassw0rd",
 *     securityGroupArns: [aws_security_group.example.arn],
 * });
 * ```
 *
 * ## Import
 *
 * `aws_datasync_location_fsx_windows_file_system` can be imported by using the `DataSync-ARN#FSx-Windows-ARN`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:datasync/locationFsxWindows:LocationFsxWindows example arn:aws:datasync:us-west-2:123456789012:location/loc-12345678901234567#arn:aws:fsx:us-west-2:476956259333:file-system/fs-08e04cd442c1bb94a
 * ```
 */
export declare class LocationFsxWindows extends pulumi.CustomResource {
    /**
     * Get an existing LocationFsxWindows resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LocationFsxWindowsState, opts?: pulumi.CustomResourceOptions): LocationFsxWindows;
    /**
     * Returns true if the given object is an instance of LocationFsxWindows.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocationFsxWindows;
    /**
     * Amazon Resource Name (ARN) of the DataSync Location.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The time that the FSx for Windows location was created.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * The name of the Windows domain that the FSx for Windows server belongs to.
     */
    readonly domain: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) for the FSx for Windows file system.
     */
    readonly fsxFilesystemArn: pulumi.Output<string>;
    /**
     * The password of the user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    readonly password: pulumi.Output<string>;
    /**
     * The Amazon Resource Names (ARNs) of the security groups that are to use to configure the FSx for Windows file system.
     */
    readonly securityGroupArns: pulumi.Output<string[]>;
    /**
     * Subdirectory to perform actions as source or destination.
     */
    readonly subdirectory: pulumi.Output<string>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Location.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The URL of the FSx for Windows location that was described.
     */
    readonly uri: pulumi.Output<string>;
    /**
     * The user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    readonly user: pulumi.Output<string>;
    /**
     * Create a LocationFsxWindows resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocationFsxWindowsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LocationFsxWindows resources.
 */
export interface LocationFsxWindowsState {
    /**
     * Amazon Resource Name (ARN) of the DataSync Location.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The time that the FSx for Windows location was created.
     */
    readonly creationTime?: pulumi.Input<string>;
    /**
     * The name of the Windows domain that the FSx for Windows server belongs to.
     */
    readonly domain?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) for the FSx for Windows file system.
     */
    readonly fsxFilesystemArn?: pulumi.Input<string>;
    /**
     * The password of the user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    readonly password?: pulumi.Input<string>;
    /**
     * The Amazon Resource Names (ARNs) of the security groups that are to use to configure the FSx for Windows file system.
     */
    readonly securityGroupArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Subdirectory to perform actions as source or destination.
     */
    readonly subdirectory?: pulumi.Input<string>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Location.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The URL of the FSx for Windows location that was described.
     */
    readonly uri?: pulumi.Input<string>;
    /**
     * The user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    readonly user?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LocationFsxWindows resource.
 */
export interface LocationFsxWindowsArgs {
    /**
     * The name of the Windows domain that the FSx for Windows server belongs to.
     */
    readonly domain?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) for the FSx for Windows file system.
     */
    readonly fsxFilesystemArn: pulumi.Input<string>;
    /**
     * The password of the user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    readonly password: pulumi.Input<string>;
    /**
     * The Amazon Resource Names (ARNs) of the security groups that are to use to configure the FSx for Windows file system.
     */
    readonly securityGroupArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Subdirectory to perform actions as source or destination.
     */
    readonly subdirectory?: pulumi.Input<string>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Location.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    readonly user: pulumi.Input<string>;
}
