import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
import { ARN } from "..";
/**
 * Manages an S3 Location within AWS DataSync.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.datasync.S3Location("example", {
 *     s3BucketArn: aws_s3_bucket.example.arn,
 *     subdirectory: "/example/prefix",
 *     s3Config: {
 *         bucketAccessRoleArn: aws_iam_role.example.arn,
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * `aws_datasync_location_s3` can be imported by using the DataSync Task Amazon Resource Name (ARN), e.g.
 *
 * ```sh
 *  $ pulumi import aws:datasync/s3Location:S3Location example arn:aws:datasync:us-east-1:123456789012:location/loc-12345678901234567
 * ```
 */
export declare class S3Location extends pulumi.CustomResource {
    /**
     * Get an existing S3Location resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: S3LocationState, opts?: pulumi.CustomResourceOptions): S3Location;
    /**
     * Returns true if the given object is an instance of S3Location.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is S3Location;
    /**
     * Amazon Resource Name (ARN) of the DataSync Location.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Amazon Resource Name (ARN) of the S3 Bucket.
     */
    readonly s3BucketArn: pulumi.Output<ARN>;
    /**
     * Configuration block containing information for connecting to S3.
     */
    readonly s3Config: pulumi.Output<outputs.datasync.S3LocationS3Config>;
    /**
     * Prefix to perform actions as source or destination.
     */
    readonly subdirectory: pulumi.Output<string>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Location.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    readonly uri: pulumi.Output<string>;
    /**
     * Create a S3Location resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: S3LocationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering S3Location resources.
 */
export interface S3LocationState {
    /**
     * Amazon Resource Name (ARN) of the DataSync Location.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Amazon Resource Name (ARN) of the S3 Bucket.
     */
    readonly s3BucketArn?: pulumi.Input<ARN>;
    /**
     * Configuration block containing information for connecting to S3.
     */
    readonly s3Config?: pulumi.Input<inputs.datasync.S3LocationS3Config>;
    /**
     * Prefix to perform actions as source or destination.
     */
    readonly subdirectory?: pulumi.Input<string>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Location.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    readonly uri?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a S3Location resource.
 */
export interface S3LocationArgs {
    /**
     * Amazon Resource Name (ARN) of the S3 Bucket.
     */
    readonly s3BucketArn: pulumi.Input<ARN>;
    /**
     * Configuration block containing information for connecting to S3.
     */
    readonly s3Config: pulumi.Input<inputs.datasync.S3LocationS3Config>;
    /**
     * Prefix to perform actions as source or destination.
     */
    readonly subdirectory: pulumi.Input<string>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Location.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
