import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
import { ARN } from "..";
/**
 * Manages an AWS DataSync Task, which represents a configuration for synchronization. Starting an execution of these DataSync Tasks (actually synchronizing files) is performed outside of this resource.
 *
 * ## Import
 *
 * `aws_datasync_task` can be imported by using the DataSync Task Amazon Resource Name (ARN), e.g.
 *
 * ```sh
 *  $ pulumi import aws:datasync/task:Task example arn:aws:datasync:us-east-1:123456789012:task/task-12345678901234567
 * ```
 */
export declare class Task extends pulumi.CustomResource {
    /**
     * Get an existing Task resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: TaskState, opts?: pulumi.CustomResourceOptions): Task;
    /**
     * Returns true if the given object is an instance of Task.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Task;
    /**
     * Amazon Resource Name (ARN) of the DataSync Task.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Amazon Resource Name (ARN) of the CloudWatch Log Group that is used to monitor and log events in the sync task.
     */
    readonly cloudwatchLogGroupArn: pulumi.Output<ARN | undefined>;
    /**
     * Amazon Resource Name (ARN) of destination DataSync Location.
     */
    readonly destinationLocationArn: pulumi.Output<ARN>;
    /**
     * Name of the DataSync Task.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Configuration block containing option that controls the default behavior when you start an execution of this DataSync Task. For each individual task execution, you can override these options by specifying an overriding configuration in those executions.
     */
    readonly options: pulumi.Output<outputs.datasync.TaskOptions | undefined>;
    /**
     * Amazon Resource Name (ARN) of source DataSync Location.
     */
    readonly sourceLocationArn: pulumi.Output<ARN>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Task.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Task resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TaskArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Task resources.
 */
export interface TaskState {
    /**
     * Amazon Resource Name (ARN) of the DataSync Task.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Amazon Resource Name (ARN) of the CloudWatch Log Group that is used to monitor and log events in the sync task.
     */
    readonly cloudwatchLogGroupArn?: pulumi.Input<ARN>;
    /**
     * Amazon Resource Name (ARN) of destination DataSync Location.
     */
    readonly destinationLocationArn?: pulumi.Input<ARN>;
    /**
     * Name of the DataSync Task.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Configuration block containing option that controls the default behavior when you start an execution of this DataSync Task. For each individual task execution, you can override these options by specifying an overriding configuration in those executions.
     */
    readonly options?: pulumi.Input<inputs.datasync.TaskOptions>;
    /**
     * Amazon Resource Name (ARN) of source DataSync Location.
     */
    readonly sourceLocationArn?: pulumi.Input<ARN>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Task.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a Task resource.
 */
export interface TaskArgs {
    /**
     * Amazon Resource Name (ARN) of the CloudWatch Log Group that is used to monitor and log events in the sync task.
     */
    readonly cloudwatchLogGroupArn?: pulumi.Input<ARN>;
    /**
     * Amazon Resource Name (ARN) of destination DataSync Location.
     */
    readonly destinationLocationArn: pulumi.Input<ARN>;
    /**
     * Name of the DataSync Task.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Configuration block containing option that controls the default behavior when you start an execution of this DataSync Task. For each individual task execution, you can override these options by specifying an overriding configuration in those executions.
     */
    readonly options?: pulumi.Input<inputs.datasync.TaskOptions>;
    /**
     * Amazon Resource Name (ARN) of source DataSync Location.
     */
    readonly sourceLocationArn: pulumi.Input<ARN>;
    /**
     * Key-value pairs of resource tags to assign to the DataSync Task.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
