import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a DMS (Data Migration Service) replication task resource. DMS replication tasks can be created, updated, deleted, and imported.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // Create a new replication task
 * const test = new aws.dms.ReplicationTask("test", {
 *     cdcStartTime: 1484346880,
 *     migrationType: "full-load",
 *     replicationInstanceArn: aws_dms_replication_instance["test-dms-replication-instance-tf"].replication_instance_arn,
 *     replicationTaskId: "test-dms-replication-task-tf",
 *     replicationTaskSettings: "...",
 *     sourceEndpointArn: aws_dms_endpoint["test-dms-source-endpoint-tf"].endpoint_arn,
 *     tableMappings: `{"rules":[{"rule-type":"selection","rule-id":"1","rule-name":"1","object-locator":{"schema-name":"%","table-name":"%"},"rule-action":"include"}]}`,
 *     tags: {
 *         Name: "test",
 *     },
 *     targetEndpointArn: aws_dms_endpoint["test-dms-target-endpoint-tf"].endpoint_arn,
 * });
 * ```
 *
 * ## Import
 *
 * Replication tasks can be imported using the `replication_task_id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:dms/replicationTask:ReplicationTask test test-dms-replication-task-tf
 * ```
 */
export declare class ReplicationTask extends pulumi.CustomResource {
    /**
     * Get an existing ReplicationTask resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ReplicationTaskState, opts?: pulumi.CustomResourceOptions): ReplicationTask;
    /**
     * Returns true if the given object is an instance of ReplicationTask.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ReplicationTask;
    /**
     * The Unix timestamp integer for the start of the Change Data Capture (CDC) operation.
     */
    readonly cdcStartTime: pulumi.Output<string | undefined>;
    /**
     * The migration type. Can be one of `full-load | cdc | full-load-and-cdc`.
     */
    readonly migrationType: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the replication instance.
     */
    readonly replicationInstanceArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) for the replication task.
     */
    readonly replicationTaskArn: pulumi.Output<string>;
    /**
     * The replication task identifier.
     */
    readonly replicationTaskId: pulumi.Output<string>;
    /**
     * An escaped JSON string that contains the task settings. For a complete list of task settings, see [Task Settings for AWS Database Migration Service Tasks](http://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.CustomizingTasks.TaskSettings.html).
     */
    readonly replicationTaskSettings: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) string that uniquely identifies the source endpoint.
     */
    readonly sourceEndpointArn: pulumi.Output<string>;
    /**
     * An escaped JSON string that contains the table mappings. For information on table mapping see [Using Table Mapping with an AWS Database Migration Service Task to Select and Filter Data](http://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.CustomizingTasks.TableMapping.html)
     */
    readonly tableMappings: pulumi.Output<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The Amazon Resource Name (ARN) string that uniquely identifies the target endpoint.
     */
    readonly targetEndpointArn: pulumi.Output<string>;
    /**
     * Create a ReplicationTask resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ReplicationTaskArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ReplicationTask resources.
 */
export interface ReplicationTaskState {
    /**
     * The Unix timestamp integer for the start of the Change Data Capture (CDC) operation.
     */
    readonly cdcStartTime?: pulumi.Input<string>;
    /**
     * The migration type. Can be one of `full-load | cdc | full-load-and-cdc`.
     */
    readonly migrationType?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the replication instance.
     */
    readonly replicationInstanceArn?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) for the replication task.
     */
    readonly replicationTaskArn?: pulumi.Input<string>;
    /**
     * The replication task identifier.
     */
    readonly replicationTaskId?: pulumi.Input<string>;
    /**
     * An escaped JSON string that contains the task settings. For a complete list of task settings, see [Task Settings for AWS Database Migration Service Tasks](http://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.CustomizingTasks.TaskSettings.html).
     */
    readonly replicationTaskSettings?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) string that uniquely identifies the source endpoint.
     */
    readonly sourceEndpointArn?: pulumi.Input<string>;
    /**
     * An escaped JSON string that contains the table mappings. For information on table mapping see [Using Table Mapping with an AWS Database Migration Service Task to Select and Filter Data](http://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.CustomizingTasks.TableMapping.html)
     */
    readonly tableMappings?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Amazon Resource Name (ARN) string that uniquely identifies the target endpoint.
     */
    readonly targetEndpointArn?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ReplicationTask resource.
 */
export interface ReplicationTaskArgs {
    /**
     * The Unix timestamp integer for the start of the Change Data Capture (CDC) operation.
     */
    readonly cdcStartTime?: pulumi.Input<string>;
    /**
     * The migration type. Can be one of `full-load | cdc | full-load-and-cdc`.
     */
    readonly migrationType: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the replication instance.
     */
    readonly replicationInstanceArn: pulumi.Input<string>;
    /**
     * The replication task identifier.
     */
    readonly replicationTaskId: pulumi.Input<string>;
    /**
     * An escaped JSON string that contains the task settings. For a complete list of task settings, see [Task Settings for AWS Database Migration Service Tasks](http://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.CustomizingTasks.TaskSettings.html).
     */
    readonly replicationTaskSettings?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) string that uniquely identifies the source endpoint.
     */
    readonly sourceEndpointArn: pulumi.Input<string>;
    /**
     * An escaped JSON string that contains the table mappings. For information on table mapping see [Using Table Mapping with an AWS Database Migration Service Task to Select and Filter Data](http://docs.aws.amazon.com/dms/latest/userguide/CHAP_Tasks.CustomizingTasks.TableMapping.html)
     */
    readonly tableMappings: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Amazon Resource Name (ARN) string that uniquely identifies the target endpoint.
     */
    readonly targetEndpointArn: pulumi.Input<string>;
}
