import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a customer gateway inside a VPC. These objects can be connected to VPN gateways via VPN connections, and allow you to establish tunnels between your network and the VPC.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const main = new aws.ec2.CustomerGateway("main", {
 *     bgpAsn: "65000",
 *     ipAddress: "172.83.124.10",
 *     tags: {
 *         Name: "main-customer-gateway",
 *     },
 *     type: "ipsec.1",
 * });
 * ```
 *
 * ## Import
 *
 * Customer Gateways can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/customerGateway:CustomerGateway main cgw-b4dc3961
 * ```
 */
export declare class CustomerGateway extends pulumi.CustomResource {
    /**
     * Get an existing CustomerGateway resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CustomerGatewayState, opts?: pulumi.CustomResourceOptions): CustomerGateway;
    /**
     * Returns true if the given object is an instance of CustomerGateway.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CustomerGateway;
    /**
     * The ARN of the customer gateway.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).
     */
    readonly bgpAsn: pulumi.Output<string>;
    /**
     * A name for the customer gateway device.
     */
    readonly deviceName: pulumi.Output<string | undefined>;
    /**
     * The IP address of the gateway's Internet-routable external interface.
     */
    readonly ipAddress: pulumi.Output<string>;
    /**
     * Tags to apply to the gateway.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The type of customer gateway. The only type AWS
     * supports at this time is "ipsec.1".
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a CustomerGateway resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CustomerGatewayArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CustomerGateway resources.
 */
export interface CustomerGatewayState {
    /**
     * The ARN of the customer gateway.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).
     */
    readonly bgpAsn?: pulumi.Input<string>;
    /**
     * A name for the customer gateway device.
     */
    readonly deviceName?: pulumi.Input<string>;
    /**
     * The IP address of the gateway's Internet-routable external interface.
     */
    readonly ipAddress?: pulumi.Input<string>;
    /**
     * Tags to apply to the gateway.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The type of customer gateway. The only type AWS
     * supports at this time is "ipsec.1".
     */
    readonly type?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CustomerGateway resource.
 */
export interface CustomerGatewayArgs {
    /**
     * The gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).
     */
    readonly bgpAsn: pulumi.Input<string>;
    /**
     * A name for the customer gateway device.
     */
    readonly deviceName?: pulumi.Input<string>;
    /**
     * The IP address of the gateway's Internet-routable external interface.
     */
    readonly ipAddress: pulumi.Input<string>;
    /**
     * Tags to apply to the gateway.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The type of customer gateway. The only type AWS
     * supports at this time is "ipsec.1".
     */
    readonly type: pulumi.Input<string>;
}
