import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a resource to manage a [default AWS VPC subnet](http://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/default-vpc.html#default-vpc-basics) in the current region.
 *
 * The `aws.ec2.DefaultSubnet` behaves differently from normal resources, in that this provider does not _create_ this resource but instead "adopts" it into management.
 *
 * The `aws.ec2.DefaultSubnet` resource allows you to manage a region's default VPC subnet but this provider cannot destroy it. Removing this resource from your configuration will remove it from your statefile and the provider management.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const defaultAz1 = new aws.ec2.DefaultSubnet("default_az1", {
 *     availabilityZone: "us-west-2a",
 *     tags: {
 *         Name: "Default subnet for us-west-2a",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Subnets can be imported using the `subnet id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/defaultSubnet:DefaultSubnet public_subnet subnet-9d4a7b6c
 * ```
 */
export declare class DefaultSubnet extends pulumi.CustomResource {
    /**
     * Get an existing DefaultSubnet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DefaultSubnetState, opts?: pulumi.CustomResourceOptions): DefaultSubnet;
    /**
     * Returns true if the given object is an instance of DefaultSubnet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DefaultSubnet;
    /**
     * ARN for the subnet.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Whether IPv6 addresses are assigned on creation.
     * * `availabilityZoneId`- AZ ID of the subnet.
     */
    readonly assignIpv6AddressOnCreation: pulumi.Output<boolean>;
    /**
     * AZ for the subnet.
     */
    readonly availabilityZone: pulumi.Output<string>;
    readonly availabilityZoneId: pulumi.Output<string>;
    /**
     * CIDR block for the subnet.
     */
    readonly cidrBlock: pulumi.Output<string>;
    readonly customerOwnedIpv4Pool: pulumi.Output<string | undefined>;
    /**
     * IPv6 CIDR block.
     */
    readonly ipv6CidrBlock: pulumi.Output<string>;
    readonly ipv6CidrBlockAssociationId: pulumi.Output<string>;
    readonly mapCustomerOwnedIpOnLaunch: pulumi.Output<boolean | undefined>;
    /**
     * Whether instances launched into the subnet should be assigned a public IP address.
     */
    readonly mapPublicIpOnLaunch: pulumi.Output<boolean>;
    readonly outpostArn: pulumi.Output<string | undefined>;
    /**
     * ID of the AWS account that owns the subnet.
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * Map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    readonly tagsAll: pulumi.Output<{
        [key: string]: string;
    }>;
    /**
     * VPC ID.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a DefaultSubnet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DefaultSubnetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DefaultSubnet resources.
 */
export interface DefaultSubnetState {
    /**
     * ARN for the subnet.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Whether IPv6 addresses are assigned on creation.
     * * `availabilityZoneId`- AZ ID of the subnet.
     */
    readonly assignIpv6AddressOnCreation?: pulumi.Input<boolean>;
    /**
     * AZ for the subnet.
     */
    readonly availabilityZone?: pulumi.Input<string>;
    readonly availabilityZoneId?: pulumi.Input<string>;
    /**
     * CIDR block for the subnet.
     */
    readonly cidrBlock?: pulumi.Input<string>;
    readonly customerOwnedIpv4Pool?: pulumi.Input<string>;
    /**
     * IPv6 CIDR block.
     */
    readonly ipv6CidrBlock?: pulumi.Input<string>;
    readonly ipv6CidrBlockAssociationId?: pulumi.Input<string>;
    readonly mapCustomerOwnedIpOnLaunch?: pulumi.Input<boolean>;
    /**
     * Whether instances launched into the subnet should be assigned a public IP address.
     */
    readonly mapPublicIpOnLaunch?: pulumi.Input<boolean>;
    readonly outpostArn?: pulumi.Input<string>;
    /**
     * ID of the AWS account that owns the subnet.
     */
    readonly ownerId?: pulumi.Input<string>;
    /**
     * Map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    readonly tagsAll?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * VPC ID.
     */
    readonly vpcId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a DefaultSubnet resource.
 */
export interface DefaultSubnetArgs {
    /**
     * AZ for the subnet.
     */
    readonly availabilityZone: pulumi.Input<string>;
    readonly customerOwnedIpv4Pool?: pulumi.Input<string>;
    readonly mapCustomerOwnedIpOnLaunch?: pulumi.Input<boolean>;
    /**
     * Whether instances launched into the subnet should be assigned a public IP address.
     */
    readonly mapPublicIpOnLaunch?: pulumi.Input<boolean>;
    readonly outpostArn?: pulumi.Input<string>;
    /**
     * Map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    readonly tagsAll?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
