import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * `aws.ec2.ManagedPrefixList` provides details about a specific AWS prefix list or
 * customer-managed prefix list in the current region.
 *
 * ## Example Usage
 * ### Find the regional DynamoDB prefix list
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const current = pulumi.output(aws.getRegion({ async: true }));
 * const example = current.apply(current => aws.ec2.getManagedPrefixList({
 *     name: `com.amazonaws.${current.name!}.dynamodb`,
 * }, { async: true }));
 * ```
 * ### Find a managed prefix list using filters
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.ec2.getManagedPrefixList({
 *     filters: [{
 *         name: "prefix-list-name",
 *         values: ["my-prefix-list"],
 *     }],
 * }, { async: true }));
 * ```
 */
export declare function getManagedPrefixList(args?: GetManagedPrefixListArgs, opts?: pulumi.InvokeOptions): Promise<GetManagedPrefixListResult>;
/**
 * A collection of arguments for invoking getManagedPrefixList.
 */
export interface GetManagedPrefixListArgs {
    /**
     * Configuration block(s) for filtering. Detailed below.
     */
    readonly filters?: inputs.ec2.GetManagedPrefixListFilter[];
    /**
     * The ID of the prefix list to select.
     */
    readonly id?: string;
    /**
     * The name of the filter field. Valid values can be found in the EC2 [DescribeManagedPrefixLists](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeManagedPrefixLists.html) API Reference.
     */
    readonly name?: string;
    /**
     * A map of tags assigned to the resource.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getManagedPrefixList.
 */
export interface GetManagedPrefixListResult {
    /**
     * The address family of the prefix list. Valid values are `IPv4` and `IPv6`.
     */
    readonly addressFamily: string;
    /**
     * The ARN of the selected prefix list.
     */
    readonly arn: string;
    /**
     * The set of entries in this prefix list. Each entry is an object with `cidr` and `description`.
     */
    readonly entries: outputs.ec2.GetManagedPrefixListEntry[];
    readonly filters?: outputs.ec2.GetManagedPrefixListFilter[];
    /**
     * The ID of the selected prefix list.
     */
    readonly id: string;
    /**
     * When then prefix list is managed, the maximum number of entries it supports, or null otherwise.
     */
    readonly maxEntries: number;
    /**
     * The name of the selected prefix list.
     */
    readonly name: string;
    /**
     * The Account ID of the owner of a customer-managed prefix list, or `AWS` otherwise.
     */
    readonly ownerId: string;
    /**
     * A map of tags assigned to the resource.
     */
    readonly tags: {
        [key: string]: string;
    };
    readonly version: number;
}
