import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * `aws.ec2.SecurityGroup` provides details about a specific Security Group.
 *
 * This resource can prove useful when a module accepts a Security Group id as
 * an input variable and needs to, for example, determine the id of the
 * VPC that the security group belongs to.
 *
 * ## Example Usage
 *
 * The following example shows how one might accept a Security Group id as a variable
 * and use this data source to obtain the data necessary to create a subnet.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const config = new pulumi.Config();
 * const securityGroupId = config.requireObject("securityGroupId");
 * const selected = aws.ec2.getSecurityGroup({
 *     id: securityGroupId,
 * });
 * const subnet = new aws.ec2.Subnet("subnet", {
 *     vpcId: selected.then(selected => selected.vpcId),
 *     cidrBlock: "10.0.1.0/24",
 * });
 * ```
 */
export declare function getSecurityGroup(args?: GetSecurityGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetSecurityGroupResult>;
/**
 * A collection of arguments for invoking getSecurityGroup.
 */
export interface GetSecurityGroupArgs {
    /**
     * Custom filter block as described below.
     */
    readonly filters?: inputs.ec2.GetSecurityGroupFilter[];
    /**
     * The id of the specific security group to retrieve.
     */
    readonly id?: string;
    /**
     * The name of the field to filter by, as defined by
     * [the underlying AWS API](http://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroups.html).
     */
    readonly name?: string;
    /**
     * A map of tags, each pair of which must exactly match
     * a pair on the desired security group.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The id of the VPC that the desired security group belongs to.
     */
    readonly vpcId?: string;
}
/**
 * A collection of values returned by getSecurityGroup.
 */
export interface GetSecurityGroupResult {
    /**
     * The computed ARN of the security group.
     */
    readonly arn: string;
    /**
     * The description of the security group.
     */
    readonly description: string;
    readonly filters?: outputs.ec2.GetSecurityGroupFilter[];
    readonly id: string;
    readonly name: string;
    readonly tags: {
        [key: string]: string;
    };
    readonly vpcId: string;
}
