import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Information about most recent Spot Price for a given EC2 instance.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.ec2.getSpotPrice({
 *     availabilityZone: "us-west-2a",
 *     filters: [{
 *         name: "product-description",
 *         values: ["Linux/UNIX"],
 *     }],
 *     instanceType: "t3.medium",
 * }, { async: true }));
 * ```
 */
export declare function getSpotPrice(args?: GetSpotPriceArgs, opts?: pulumi.InvokeOptions): Promise<GetSpotPriceResult>;
/**
 * A collection of arguments for invoking getSpotPrice.
 */
export interface GetSpotPriceArgs {
    /**
     * The availability zone in which to query Spot price information.
     */
    readonly availabilityZone?: string;
    /**
     * One or more configuration blocks containing name-values filters. See the [EC2 API Reference](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotPriceHistory.html) for supported filters. Detailed below.
     */
    readonly filters?: inputs.ec2.GetSpotPriceFilter[];
    /**
     * The type of instance for which to query Spot Price information.
     */
    readonly instanceType?: string;
}
/**
 * A collection of values returned by getSpotPrice.
 */
export interface GetSpotPriceResult {
    readonly availabilityZone?: string;
    readonly filters?: outputs.ec2.GetSpotPriceFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly instanceType?: string;
    /**
     * The most recent Spot Price value for the given instance type and AZ.
     */
    readonly spotPrice: string;
    /**
     * The timestamp at which the Spot Price value was published.
     */
    readonly spotPriceTimestamp: string;
}
