import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * `aws.ec2.Subnet` provides details about a specific VPC subnet.
 *
 * This resource can prove useful when a module accepts a subnet ID as an input variable and needs to, for example, determine the ID of the VPC that the subnet belongs to.
 *
 * ## Example Usage
 *
 * The following example shows how one might accept a subnet ID as a variable and use this data source to obtain the data necessary to create a security group that allows connections from hosts in that subnet.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const config = new pulumi.Config();
 * const subnetId = config.requireObject("subnetId");
 * const selected = aws.ec2.getSubnet({
 *     id: subnetId,
 * });
 * const subnet = new aws.ec2.SecurityGroup("subnet", {
 *     vpcId: selected.then(selected => selected.vpcId),
 *     ingress: [{
 *         cidrBlocks: [selected.then(selected => selected.cidrBlock)],
 *         fromPort: 80,
 *         toPort: 80,
 *         protocol: "tcp",
 *     }],
 * });
 * ```
 * ### Filter Example
 *
 * If you want to match against tag `Name`, use:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const selected = pulumi.output(aws.ec2.getSubnet({
 *     filters: [{
 *         name: "tag:Name",
 *         values: ["yakdriver"],
 *     }],
 * }, { async: true }));
 * ```
 */
export declare function getSubnet(args?: GetSubnetArgs, opts?: pulumi.InvokeOptions): Promise<GetSubnetResult>;
/**
 * A collection of arguments for invoking getSubnet.
 */
export interface GetSubnetArgs {
    /**
     * Availability zone where the subnet must reside.
     */
    readonly availabilityZone?: string;
    /**
     * ID of the Availability Zone for the subnet.
     */
    readonly availabilityZoneId?: string;
    /**
     * CIDR block of the desired subnet.
     */
    readonly cidrBlock?: string;
    /**
     * Whether the desired subnet must be the default subnet for its associated availability zone.
     */
    readonly defaultForAz?: boolean;
    /**
     * Configuration block. Detailed below.
     */
    readonly filters?: inputs.ec2.GetSubnetFilter[];
    /**
     * ID of the specific subnet to retrieve.
     */
    readonly id?: string;
    /**
     * IPv6 CIDR block of the desired subnet.
     */
    readonly ipv6CidrBlock?: string;
    /**
     * State that the desired subnet must have.
     */
    readonly state?: string;
    /**
     * Map of tags, each pair of which must exactly match a pair on the desired subnet.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * ID of the VPC that the desired subnet belongs to.
     */
    readonly vpcId?: string;
}
/**
 * A collection of values returned by getSubnet.
 */
export interface GetSubnetResult {
    /**
     * ARN of the subnet.
     */
    readonly arn: string;
    /**
     * Whether an IPv6 address is assigned on creation.
     */
    readonly assignIpv6AddressOnCreation: boolean;
    readonly availabilityZone: string;
    readonly availabilityZoneId: string;
    /**
     * Available IP addresses of the subnet.
     */
    readonly availableIpAddressCount: number;
    readonly cidrBlock: string;
    /**
     * Identifier of customer owned IPv4 address pool.
     */
    readonly customerOwnedIpv4Pool: string;
    readonly defaultForAz: boolean;
    readonly filters?: outputs.ec2.GetSubnetFilter[];
    readonly id: string;
    readonly ipv6CidrBlock: string;
    /**
     * Association ID of the IPv6 CIDR block.
     */
    readonly ipv6CidrBlockAssociationId: string;
    /**
     * Whether customer owned IP addresses are assigned on network interface creation.
     */
    readonly mapCustomerOwnedIpOnLaunch: boolean;
    /**
     * Whether public IP addresses are assigned on instance launch.
     */
    readonly mapPublicIpOnLaunch: boolean;
    /**
     * ARN of the Outpost.
     */
    readonly outpostArn: string;
    /**
     * ID of the AWS account that owns the subnet.
     */
    readonly ownerId: string;
    readonly state: string;
    readonly tags: {
        [key: string]: string;
    };
    readonly vpcId: string;
}
