import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * `aws.ec2.getSubnetIds` provides a set of ids for a vpcId
 *
 * This resource can be useful for getting back a set of subnet ids for a vpc.
 *
 * ## Example Usage
 *
 * The following shows outputing all cidr blocks for every subnet id in a vpc.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleSubnetIds = aws.ec2.getSubnetIds({
 *     vpcId: _var.vpc_id,
 * });
 * const exampleSubnet = exampleSubnetIds.then(exampleSubnetIds => exampleSubnetIds.ids.map((v, k) => [k, v]).map(([, ]) => aws.ec2.getSubnet({
 *     id: __value,
 * })));
 * export const subnetCidrBlocks = exampleSubnet.map(s => s.cidrBlock);
 * ```
 *
 * The following example retrieves a set of all subnets in a VPC with a custom
 * tag of `Tier` set to a value of "Private" so that the `aws.ec2.Instance` resource
 * can loop through the subnets, putting instances across availability zones.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const private = aws.ec2.getSubnetIds({
 *     vpcId: _var.vpc_id,
 *     tags: {
 *         Tier: "Private",
 *     },
 * });
 * const app: aws.ec2.Instance[];
 * for (const range = {value: 0}; range.value < data.aws_subnet_ids.example.ids; range.value++) {
 *     app.push(new aws.ec2.Instance(`app-${range.value}`, {
 *         ami: _var.ami,
 *         instanceType: "t2.micro",
 *         subnetId: range.value,
 *     }));
 * }
 * ```
 */
export declare function getSubnetIds(args: GetSubnetIdsArgs, opts?: pulumi.InvokeOptions): Promise<GetSubnetIdsResult>;
/**
 * A collection of arguments for invoking getSubnetIds.
 */
export interface GetSubnetIdsArgs {
    /**
     * Custom filter block as described below.
     */
    readonly filters?: inputs.ec2.GetSubnetIdsFilter[];
    /**
     * A map of tags, each pair of which must exactly match
     * a pair on the desired subnets.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The VPC ID that you want to filter from.
     */
    readonly vpcId: string;
}
/**
 * A collection of values returned by getSubnetIds.
 */
export interface GetSubnetIdsResult {
    readonly filters?: outputs.ec2.GetSubnetIdsFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A set of all the subnet ids found. This data source will fail if none are found.
     */
    readonly ids: string[];
    readonly tags: {
        [key: string]: string;
    };
    readonly vpcId: string;
}
