import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * The VPC Peering Connection data source provides details about
 * a specific VPC peering connection.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const pc = aws.ec2.getVpcPeeringConnection({
 *     vpcId: aws_vpc.foo.id,
 *     peerCidrBlock: "10.0.1.0/22",
 * });
 * // Create a route table
 * const rt = new aws.ec2.RouteTable("rt", {vpcId: aws_vpc.foo.id});
 * // Create a route
 * const route = new aws.ec2.Route("route", {
 *     routeTableId: rt.id,
 *     destinationCidrBlock: pc.then(pc => pc.peerCidrBlock),
 *     vpcPeeringConnectionId: pc.then(pc => pc.id),
 * });
 * ```
 */
export declare function getVpcPeeringConnection(args?: GetVpcPeeringConnectionArgs, opts?: pulumi.InvokeOptions): Promise<GetVpcPeeringConnectionResult>;
/**
 * A collection of arguments for invoking getVpcPeeringConnection.
 */
export interface GetVpcPeeringConnectionArgs {
    /**
     * The primary CIDR block of the requester VPC of the specific VPC Peering Connection to retrieve.
     */
    readonly cidrBlock?: string;
    /**
     * Custom filter block as described below.
     */
    readonly filters?: inputs.ec2.GetVpcPeeringConnectionFilter[];
    /**
     * The ID of the specific VPC Peering Connection to retrieve.
     */
    readonly id?: string;
    /**
     * The AWS account ID of the owner of the requester VPC of the specific VPC Peering Connection to retrieve.
     */
    readonly ownerId?: string;
    /**
     * The primary CIDR block of the accepter VPC of the specific VPC Peering Connection to retrieve.
     */
    readonly peerCidrBlock?: string;
    /**
     * The AWS account ID of the owner of the accepter VPC of the specific VPC Peering Connection to retrieve.
     */
    readonly peerOwnerId?: string;
    /**
     * The region of the accepter VPC of the specific VPC Peering Connection to retrieve.
     */
    readonly peerRegion?: string;
    /**
     * The ID of the accepter VPC of the specific VPC Peering Connection to retrieve.
     */
    readonly peerVpcId?: string;
    /**
     * The region of the requester VPC of the specific VPC Peering Connection to retrieve.
     */
    readonly region?: string;
    /**
     * The status of the specific VPC Peering Connection to retrieve.
     */
    readonly status?: string;
    /**
     * A map of tags, each pair of which must exactly match
     * a pair on the desired VPC Peering Connection.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The ID of the requester VPC of the specific VPC Peering Connection to retrieve.
     */
    readonly vpcId?: string;
}
/**
 * A collection of values returned by getVpcPeeringConnection.
 */
export interface GetVpcPeeringConnectionResult {
    /**
     * A configuration block that describes [VPC Peering Connection]
     * (https://docs.aws.amazon.com/vpc/latest/peering/what-is-vpc-peering.html) options set for the accepter VPC.
     */
    readonly accepter: {
        [key: string]: boolean;
    };
    /**
     * A CIDR block associated to the VPC of the specific VPC Peering Connection.
     */
    readonly cidrBlock: string;
    /**
     * List of objects with CIDR blocks of the requester VPC.
     */
    readonly cidrBlockSets: outputs.ec2.GetVpcPeeringConnectionCidrBlockSet[];
    readonly filters?: outputs.ec2.GetVpcPeeringConnectionFilter[];
    readonly id: string;
    readonly ownerId: string;
    readonly peerCidrBlock: string;
    /**
     * List of objects with CIDR blocks of the accepter VPC.
     */
    readonly peerCidrBlockSets: outputs.ec2.GetVpcPeeringConnectionPeerCidrBlockSet[];
    readonly peerOwnerId: string;
    readonly peerRegion: string;
    readonly peerVpcId: string;
    readonly region: string;
    /**
     * A configuration block that describes [VPC Peering Connection]
     * (https://docs.aws.amazon.com/vpc/latest/peering/what-is-vpc-peering.html) options set for the requester VPC.
     */
    readonly requester: {
        [key: string]: boolean;
    };
    readonly status: string;
    readonly tags: {
        [key: string]: string;
    };
    readonly vpcId: string;
}
