import * as pulumi from "@pulumi/pulumi";
/**
 * Manages an EC2 Local Gateway Route. More information can be found in the [Outposts User Guide](https://docs.aws.amazon.com/outposts/latest/userguide/outposts-networking-components.html#routing).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2.LocalGatewayRoute("example", {
 *     destinationCidrBlock: "172.16.0.0/16",
 *     localGatewayRouteTableId: data.aws_ec2_local_gateway_route_table.example.id,
 *     localGatewayVirtualInterfaceGroupId: data.aws_ec2_local_gateway_virtual_interface_group.example.id,
 * });
 * ```
 *
 * ## Import
 *
 * `aws_ec2_local_gateway_route` can be imported by using the EC2 Local Gateway Route Table identifier and destination CIDR block separated by underscores (`_`), e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/localGatewayRoute:LocalGatewayRoute example lgw-rtb-12345678_172.16.0.0/16
 * ```
 */
export declare class LocalGatewayRoute extends pulumi.CustomResource {
    /**
     * Get an existing LocalGatewayRoute resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LocalGatewayRouteState, opts?: pulumi.CustomResourceOptions): LocalGatewayRoute;
    /**
     * Returns true if the given object is an instance of LocalGatewayRoute.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocalGatewayRoute;
    /**
     * IPv4 CIDR range used for destination matches. Routing decisions are based on the most specific match.
     */
    readonly destinationCidrBlock: pulumi.Output<string>;
    /**
     * Identifier of EC2 Local Gateway Route Table.
     */
    readonly localGatewayRouteTableId: pulumi.Output<string>;
    /**
     * Identifier of EC2 Local Gateway Virtual Interface Group.
     */
    readonly localGatewayVirtualInterfaceGroupId: pulumi.Output<string>;
    /**
     * Create a LocalGatewayRoute resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocalGatewayRouteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LocalGatewayRoute resources.
 */
export interface LocalGatewayRouteState {
    /**
     * IPv4 CIDR range used for destination matches. Routing decisions are based on the most specific match.
     */
    readonly destinationCidrBlock?: pulumi.Input<string>;
    /**
     * Identifier of EC2 Local Gateway Route Table.
     */
    readonly localGatewayRouteTableId?: pulumi.Input<string>;
    /**
     * Identifier of EC2 Local Gateway Virtual Interface Group.
     */
    readonly localGatewayVirtualInterfaceGroupId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LocalGatewayRoute resource.
 */
export interface LocalGatewayRouteArgs {
    /**
     * IPv4 CIDR range used for destination matches. Routing decisions are based on the most specific match.
     */
    readonly destinationCidrBlock: pulumi.Input<string>;
    /**
     * Identifier of EC2 Local Gateway Route Table.
     */
    readonly localGatewayRouteTableId: pulumi.Input<string>;
    /**
     * Identifier of EC2 Local Gateway Virtual Interface Group.
     */
    readonly localGatewayVirtualInterfaceGroupId: pulumi.Input<string>;
}
