import * as pulumi from "@pulumi/pulumi";
import { enums } from "../types";
/**
 * Provides an EC2 placement group. Read more about placement groups
 * in [AWS Docs](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const web = new aws.ec2.PlacementGroup("web", {
 *     strategy: "cluster",
 * });
 * ```
 *
 * ## Import
 *
 * Placement groups can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/placementGroup:PlacementGroup prod_pg production-placement-group
 * ```
 */
export declare class PlacementGroup extends pulumi.CustomResource {
    /**
     * Get an existing PlacementGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: PlacementGroupState, opts?: pulumi.CustomResourceOptions): PlacementGroup;
    /**
     * Returns true if the given object is an instance of PlacementGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PlacementGroup;
    /**
     * Amazon Resource Name (ARN) of the placement group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the placement group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ID of the placement group.
     */
    readonly placementGroupId: pulumi.Output<string>;
    /**
     * The placement strategy. Can be `"cluster"`, `"partition"` or `"spread"`.
     */
    readonly strategy: pulumi.Output<string>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a PlacementGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PlacementGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering PlacementGroup resources.
 */
export interface PlacementGroupState {
    /**
     * Amazon Resource Name (ARN) of the placement group.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The name of the placement group.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The ID of the placement group.
     */
    readonly placementGroupId?: pulumi.Input<string>;
    /**
     * The placement strategy. Can be `"cluster"`, `"partition"` or `"spread"`.
     */
    readonly strategy?: pulumi.Input<string | enums.ec2.PlacementStrategy>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a PlacementGroup resource.
 */
export interface PlacementGroupArgs {
    /**
     * The name of the placement group.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The placement strategy. Can be `"cluster"`, `"partition"` or `"spread"`.
     */
    readonly strategy: pulumi.Input<string | enums.ec2.PlacementStrategy>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
