import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an EC2 Spot Instance Request resource. This allows instances to be
 * requested on the spot market.
 *
 * By default this provider creates Spot Instance Requests with a `persistent` type,
 * which means that for the duration of their lifetime, AWS will launch an
 * instance with the configured details if and when the spot market will accept
 * the requested price.
 *
 * On destruction, this provider will make an attempt to terminate the associated Spot
 * Instance if there is one present.
 *
 * Spot Instances requests with a `one-time` type will close the spot request
 * when the instance is terminated either by the request being below the current spot
 * price availability or by a user.
 *
 * > **NOTE:** Because their behavior depends on the live status of the spot
 * market, Spot Instance Requests have a unique lifecycle that makes them behave
 * differently than other resources. Most importantly: there is __no
 * guarantee__ that a Spot Instance exists to fulfill the request at any given
 * point in time. See the [AWS Spot Instance
 * documentation](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-spot-instances.html)
 * for more information.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // Request a spot instance at $0.03
 * const cheapWorker = new aws.ec2.SpotInstanceRequest("cheap_worker", {
 *     ami: "ami-1234",
 *     instanceType: "c4.xlarge",
 *     spotPrice: "0.03",
 *     tags: {
 *         Name: "CheapWorker",
 *     },
 * });
 * ```
 */
export declare class SpotInstanceRequest extends pulumi.CustomResource {
    /**
     * Get an existing SpotInstanceRequest resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SpotInstanceRequestState, opts?: pulumi.CustomResourceOptions): SpotInstanceRequest;
    /**
     * Returns true if the given object is an instance of SpotInstanceRequest.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SpotInstanceRequest;
    /**
     * AMI to use for the instance.
     */
    readonly ami: pulumi.Output<string>;
    readonly arn: pulumi.Output<string>;
    /**
     * Whether to associate a public IP address with an instance in a VPC.
     */
    readonly associatePublicIpAddress: pulumi.Output<boolean>;
    /**
     * AZ to start the instance in.
     */
    readonly availabilityZone: pulumi.Output<string>;
    /**
     * The required duration for the Spot instances, in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
     * The duration period starts as soon as your Spot instance receives its instance ID. At the end of the duration period, Amazon EC2 marks the Spot instance for termination and provides a Spot instance termination notice, which gives the instance a two-minute warning before it terminates.
     * Note that you can't specify an Availability Zone group or a launch group if you specify a duration.
     */
    readonly blockDurationMinutes: pulumi.Output<number | undefined>;
    /**
     * Sets the number of CPU cores for an instance. This option is only supported on creation of instance type that support CPU Options [CPU Cores and Threads Per CPU Core Per Instance Type](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html#cpu-options-supported-instances-values) - specifying this option for unsupported instance types will return an error from the EC2 API.
     */
    readonly cpuCoreCount: pulumi.Output<number>;
    /**
     * If set to to 1, hyperthreading is disabled on the launched instance. Defaults to 2 if not set. See [Optimizing CPU Options](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html) for more information.
     */
    readonly cpuThreadsPerCore: pulumi.Output<number>;
    /**
     * Configuration block for customizing the credit specification of the instance. See Credit Specification below for more details. the provider will only perform drift detection of its value when present in a configuration. Removing this configuration on existing instances will only stop managing it. It will not change the configuration back to the default for the instance type.
     */
    readonly creditSpecification: pulumi.Output<outputs.ec2.SpotInstanceRequestCreditSpecification | undefined>;
    /**
     * If true, enables [EC2 Instance Termination Protection](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#Using_ChangingDisableAPITermination).
     */
    readonly disableApiTermination: pulumi.Output<boolean | undefined>;
    /**
     * One or more configuration blocks with additional EBS block devices to attach to the instance. Block device configurations only apply on resource creation. See Block Devices below for details on attributes and drift detection. When accessing this as an attribute reference, it is a set of objects.
     */
    readonly ebsBlockDevices: pulumi.Output<outputs.ec2.SpotInstanceRequestEbsBlockDevice[]>;
    /**
     * If true, the launched EC2 instance will be EBS-optimized. Note that if this is not set on an instance type that is optimized by default then this will show as disabled but if the instance type is optimized by default then there is no need to set this and there is no effect to disabling it. See the [EBS Optimized section](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSOptimized.html) of the AWS User Guide for more information.
     */
    readonly ebsOptimized: pulumi.Output<boolean | undefined>;
    /**
     * Enable Nitro Enclaves on launched instances. See Enclave Options below for more details.
     */
    readonly enclaveOptions: pulumi.Output<outputs.ec2.SpotInstanceRequestEnclaveOptions>;
    /**
     * One or more configuration blocks to customize Ephemeral (also known as "Instance Store") volumes on the instance. See Block Devices below for details. When accessing this as an attribute reference, it is a set of objects.
     */
    readonly ephemeralBlockDevices: pulumi.Output<outputs.ec2.SpotInstanceRequestEphemeralBlockDevice[]>;
    /**
     * If true, wait for password data to become available and retrieve it. Useful for getting the administrator password for instances running Microsoft Windows. The password data is exported to the `passwordData` attribute. See [GetPasswordData](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetPasswordData.html) for more information.
     */
    readonly getPasswordData: pulumi.Output<boolean | undefined>;
    /**
     * If true, the launched EC2 instance will support hibernation.
     */
    readonly hibernation: pulumi.Output<boolean | undefined>;
    /**
     * ID of a dedicated host that the instance will be assigned to. Use when an instance is to be launched on a specific dedicated host.
     */
    readonly hostId: pulumi.Output<string>;
    /**
     * IAM Instance Profile to launch the instance with. Specified as the name of the Instance Profile. Ensure your credentials have the correct permission to assign the instance profile according to the [EC2 documentation](http://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2.html#roles-usingrole-ec2instance-permissions), notably `iam:PassRole`.
     */
    readonly iamInstanceProfile: pulumi.Output<string | undefined>;
    /**
     * Shutdown behavior for the instance. Amazon defaults this to `stop` for EBS-backed instances and `terminate` for instance-store instances. Cannot be set on instance-store instances. See [Shutdown Behavior](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#Using_ChangingInstanceInitiatedShutdownBehavior) for more information.
     */
    readonly instanceInitiatedShutdownBehavior: pulumi.Output<string | undefined>;
    /**
     * Indicates whether a Spot instance stops or terminates when it is interrupted. Default is `terminate` as this is the current AWS behaviour.
     */
    readonly instanceInterruptionBehaviour: pulumi.Output<string | undefined>;
    readonly instanceState: pulumi.Output<string>;
    /**
     * Type of instance to start. Updates to this field will trigger a stop/start of the EC2 instance.
     */
    readonly instanceType: pulumi.Output<string>;
    /**
     * A number of IPv6 addresses to associate with the primary network interface. Amazon EC2 chooses the IPv6 addresses from the range of your subnet.
     */
    readonly ipv6AddressCount: pulumi.Output<number>;
    /**
     * Specify one or more IPv6 addresses from the range of the subnet to associate with the primary network interface
     */
    readonly ipv6Addresses: pulumi.Output<string[]>;
    /**
     * Key name of the Key Pair to use for the instance; which can be managed using the `aws.ec2.KeyPair` resource.
     */
    readonly keyName: pulumi.Output<string>;
    /**
     * A launch group is a group of spot instances that launch together and terminate together.
     * If left empty instances are launched and terminated individually.
     */
    readonly launchGroup: pulumi.Output<string | undefined>;
    /**
     * Customize the metadata options of the instance. See Metadata Options below for more details.
     */
    readonly metadataOptions: pulumi.Output<outputs.ec2.SpotInstanceRequestMetadataOptions>;
    /**
     * If true, the launched EC2 instance will have detailed monitoring enabled. (Available since v0.6.0)
     */
    readonly monitoring: pulumi.Output<boolean | undefined>;
    /**
     * Customize network interfaces to be attached at instance boot time. See Network Interfaces below for more details.
     */
    readonly networkInterfaces: pulumi.Output<outputs.ec2.SpotInstanceRequestNetworkInterface[]>;
    readonly outpostArn: pulumi.Output<string>;
    readonly passwordData: pulumi.Output<string>;
    /**
     * Placement Group to start the instance in.
     */
    readonly placementGroup: pulumi.Output<string>;
    readonly primaryNetworkInterfaceId: pulumi.Output<string>;
    /**
     * The private DNS name assigned to the instance. Can only be
     * used inside the Amazon EC2, and only available if you've enabled DNS hostnames
     * for your VPC
     */
    readonly privateDns: pulumi.Output<string>;
    /**
     * Private IP address to associate with the instance in a VPC.
     */
    readonly privateIp: pulumi.Output<string>;
    /**
     * The public DNS name assigned to the instance. For EC2-VPC, this
     * is only available if you've enabled DNS hostnames for your VPC
     */
    readonly publicDns: pulumi.Output<string>;
    /**
     * The public IP address assigned to the instance, if applicable.
     */
    readonly publicIp: pulumi.Output<string>;
    /**
     * Configuration block to customize details about the root block device of the instance. See Block Devices below for details. When accessing this as an attribute reference, it is a list containing one object.
     */
    readonly rootBlockDevice: pulumi.Output<outputs.ec2.SpotInstanceRequestRootBlockDevice>;
    /**
     * A list of secondary private IPv4 addresses to assign to the instance's primary network interface (eth0) in a VPC. Can only be assigned to the primary network interface (eth0) attached at instance creation, not a pre-existing network interface i.e. referenced in a `networkInterface` block. Refer to the [Elastic network interfaces documentation](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI) to see the maximum number of private IP addresses allowed per instance type.
     */
    readonly secondaryPrivateIps: pulumi.Output<string[]>;
    /**
     * A list of security group names (EC2-Classic) or IDs (default VPC) to associate with.
     */
    readonly securityGroups: pulumi.Output<string[]>;
    /**
     * Controls if traffic is routed to the instance when the destination address does not match the instance. Used for NAT or VPNs. Defaults true.
     */
    readonly sourceDestCheck: pulumi.Output<boolean | undefined>;
    /**
     * The current [bid
     * status](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-bid-status.html)
     * of the Spot Instance Request.
     * * `spotRequestState` The current [request
     * state](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-requests.html#creating-spot-request-status)
     * of the Spot Instance Request.
     */
    readonly spotBidStatus: pulumi.Output<string>;
    /**
     * The Instance ID (if any) that is currently fulfilling
     * the Spot Instance request.
     */
    readonly spotInstanceId: pulumi.Output<string>;
    /**
     * The maximum price to request on the spot market.
     */
    readonly spotPrice: pulumi.Output<string>;
    readonly spotRequestState: pulumi.Output<string>;
    /**
     * If set to `one-time`, after
     * the instance is terminated, the spot request will be closed.
     */
    readonly spotType: pulumi.Output<string | undefined>;
    /**
     * VPC Subnet ID to launch in.
     */
    readonly subnetId: pulumi.Output<string>;
    /**
     * A map of tags to assign to the resource. Note that these tags apply to the instance and not block storage devices.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware. The host tenancy is not supported for the import-instance command.
     */
    readonly tenancy: pulumi.Output<string>;
    /**
     * User data to provide when launching the instance. Do not pass gzip-compressed data via this argument; see `userDataBase64` instead.
     */
    readonly userData: pulumi.Output<string | undefined>;
    /**
     * Can be used instead of `userData` to pass base64-encoded binary data directly. Use this instead of `userData` whenever the value is not a valid UTF-8 string. For example, gzip-encoded user data must be base64-encoded and passed via this argument to avoid corruption.
     */
    readonly userDataBase64: pulumi.Output<string | undefined>;
    /**
     * The start date and time of the request, in UTC [RFC3339](https://tools.ietf.org/html/rfc3339#section-5.8) format(for example, YYYY-MM-DDTHH:MM:SSZ). The default is to start fulfilling the request immediately.
     */
    readonly validFrom: pulumi.Output<string>;
    /**
     * The end date and time of the request, in UTC [RFC3339](https://tools.ietf.org/html/rfc3339#section-5.8) format(for example, YYYY-MM-DDTHH:MM:SSZ). At this point, no new Spot instance requests are placed or enabled to fulfill the request. The default end date is 7 days from the current date.
     */
    readonly validUntil: pulumi.Output<string>;
    /**
     * A map of tags to assign, at instance-creation time, to root and EBS volumes.
     */
    readonly volumeTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A list of security group IDs to associate with.
     */
    readonly vpcSecurityGroupIds: pulumi.Output<string[]>;
    /**
     * If set, this provider will
     * wait for the Spot Request to be fulfilled, and will throw an error if the
     * timeout of 10m is reached.
     */
    readonly waitForFulfillment: pulumi.Output<boolean | undefined>;
    /**
     * Create a SpotInstanceRequest resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SpotInstanceRequestArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SpotInstanceRequest resources.
 */
export interface SpotInstanceRequestState {
    /**
     * AMI to use for the instance.
     */
    readonly ami?: pulumi.Input<string>;
    readonly arn?: pulumi.Input<string>;
    /**
     * Whether to associate a public IP address with an instance in a VPC.
     */
    readonly associatePublicIpAddress?: pulumi.Input<boolean>;
    /**
     * AZ to start the instance in.
     */
    readonly availabilityZone?: pulumi.Input<string>;
    /**
     * The required duration for the Spot instances, in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
     * The duration period starts as soon as your Spot instance receives its instance ID. At the end of the duration period, Amazon EC2 marks the Spot instance for termination and provides a Spot instance termination notice, which gives the instance a two-minute warning before it terminates.
     * Note that you can't specify an Availability Zone group or a launch group if you specify a duration.
     */
    readonly blockDurationMinutes?: pulumi.Input<number>;
    /**
     * Sets the number of CPU cores for an instance. This option is only supported on creation of instance type that support CPU Options [CPU Cores and Threads Per CPU Core Per Instance Type](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html#cpu-options-supported-instances-values) - specifying this option for unsupported instance types will return an error from the EC2 API.
     */
    readonly cpuCoreCount?: pulumi.Input<number>;
    /**
     * If set to to 1, hyperthreading is disabled on the launched instance. Defaults to 2 if not set. See [Optimizing CPU Options](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html) for more information.
     */
    readonly cpuThreadsPerCore?: pulumi.Input<number>;
    /**
     * Configuration block for customizing the credit specification of the instance. See Credit Specification below for more details. the provider will only perform drift detection of its value when present in a configuration. Removing this configuration on existing instances will only stop managing it. It will not change the configuration back to the default for the instance type.
     */
    readonly creditSpecification?: pulumi.Input<inputs.ec2.SpotInstanceRequestCreditSpecification>;
    /**
     * If true, enables [EC2 Instance Termination Protection](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#Using_ChangingDisableAPITermination).
     */
    readonly disableApiTermination?: pulumi.Input<boolean>;
    /**
     * One or more configuration blocks with additional EBS block devices to attach to the instance. Block device configurations only apply on resource creation. See Block Devices below for details on attributes and drift detection. When accessing this as an attribute reference, it is a set of objects.
     */
    readonly ebsBlockDevices?: pulumi.Input<pulumi.Input<inputs.ec2.SpotInstanceRequestEbsBlockDevice>[]>;
    /**
     * If true, the launched EC2 instance will be EBS-optimized. Note that if this is not set on an instance type that is optimized by default then this will show as disabled but if the instance type is optimized by default then there is no need to set this and there is no effect to disabling it. See the [EBS Optimized section](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSOptimized.html) of the AWS User Guide for more information.
     */
    readonly ebsOptimized?: pulumi.Input<boolean>;
    /**
     * Enable Nitro Enclaves on launched instances. See Enclave Options below for more details.
     */
    readonly enclaveOptions?: pulumi.Input<inputs.ec2.SpotInstanceRequestEnclaveOptions>;
    /**
     * One or more configuration blocks to customize Ephemeral (also known as "Instance Store") volumes on the instance. See Block Devices below for details. When accessing this as an attribute reference, it is a set of objects.
     */
    readonly ephemeralBlockDevices?: pulumi.Input<pulumi.Input<inputs.ec2.SpotInstanceRequestEphemeralBlockDevice>[]>;
    /**
     * If true, wait for password data to become available and retrieve it. Useful for getting the administrator password for instances running Microsoft Windows. The password data is exported to the `passwordData` attribute. See [GetPasswordData](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetPasswordData.html) for more information.
     */
    readonly getPasswordData?: pulumi.Input<boolean>;
    /**
     * If true, the launched EC2 instance will support hibernation.
     */
    readonly hibernation?: pulumi.Input<boolean>;
    /**
     * ID of a dedicated host that the instance will be assigned to. Use when an instance is to be launched on a specific dedicated host.
     */
    readonly hostId?: pulumi.Input<string>;
    /**
     * IAM Instance Profile to launch the instance with. Specified as the name of the Instance Profile. Ensure your credentials have the correct permission to assign the instance profile according to the [EC2 documentation](http://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2.html#roles-usingrole-ec2instance-permissions), notably `iam:PassRole`.
     */
    readonly iamInstanceProfile?: pulumi.Input<string>;
    /**
     * Shutdown behavior for the instance. Amazon defaults this to `stop` for EBS-backed instances and `terminate` for instance-store instances. Cannot be set on instance-store instances. See [Shutdown Behavior](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#Using_ChangingInstanceInitiatedShutdownBehavior) for more information.
     */
    readonly instanceInitiatedShutdownBehavior?: pulumi.Input<string>;
    /**
     * Indicates whether a Spot instance stops or terminates when it is interrupted. Default is `terminate` as this is the current AWS behaviour.
     */
    readonly instanceInterruptionBehaviour?: pulumi.Input<string>;
    readonly instanceState?: pulumi.Input<string>;
    /**
     * Type of instance to start. Updates to this field will trigger a stop/start of the EC2 instance.
     */
    readonly instanceType?: pulumi.Input<string>;
    /**
     * A number of IPv6 addresses to associate with the primary network interface. Amazon EC2 chooses the IPv6 addresses from the range of your subnet.
     */
    readonly ipv6AddressCount?: pulumi.Input<number>;
    /**
     * Specify one or more IPv6 addresses from the range of the subnet to associate with the primary network interface
     */
    readonly ipv6Addresses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Key name of the Key Pair to use for the instance; which can be managed using the `aws.ec2.KeyPair` resource.
     */
    readonly keyName?: pulumi.Input<string>;
    /**
     * A launch group is a group of spot instances that launch together and terminate together.
     * If left empty instances are launched and terminated individually.
     */
    readonly launchGroup?: pulumi.Input<string>;
    /**
     * Customize the metadata options of the instance. See Metadata Options below for more details.
     */
    readonly metadataOptions?: pulumi.Input<inputs.ec2.SpotInstanceRequestMetadataOptions>;
    /**
     * If true, the launched EC2 instance will have detailed monitoring enabled. (Available since v0.6.0)
     */
    readonly monitoring?: pulumi.Input<boolean>;
    /**
     * Customize network interfaces to be attached at instance boot time. See Network Interfaces below for more details.
     */
    readonly networkInterfaces?: pulumi.Input<pulumi.Input<inputs.ec2.SpotInstanceRequestNetworkInterface>[]>;
    readonly outpostArn?: pulumi.Input<string>;
    readonly passwordData?: pulumi.Input<string>;
    /**
     * Placement Group to start the instance in.
     */
    readonly placementGroup?: pulumi.Input<string>;
    readonly primaryNetworkInterfaceId?: pulumi.Input<string>;
    /**
     * The private DNS name assigned to the instance. Can only be
     * used inside the Amazon EC2, and only available if you've enabled DNS hostnames
     * for your VPC
     */
    readonly privateDns?: pulumi.Input<string>;
    /**
     * Private IP address to associate with the instance in a VPC.
     */
    readonly privateIp?: pulumi.Input<string>;
    /**
     * The public DNS name assigned to the instance. For EC2-VPC, this
     * is only available if you've enabled DNS hostnames for your VPC
     */
    readonly publicDns?: pulumi.Input<string>;
    /**
     * The public IP address assigned to the instance, if applicable.
     */
    readonly publicIp?: pulumi.Input<string>;
    /**
     * Configuration block to customize details about the root block device of the instance. See Block Devices below for details. When accessing this as an attribute reference, it is a list containing one object.
     */
    readonly rootBlockDevice?: pulumi.Input<inputs.ec2.SpotInstanceRequestRootBlockDevice>;
    /**
     * A list of secondary private IPv4 addresses to assign to the instance's primary network interface (eth0) in a VPC. Can only be assigned to the primary network interface (eth0) attached at instance creation, not a pre-existing network interface i.e. referenced in a `networkInterface` block. Refer to the [Elastic network interfaces documentation](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI) to see the maximum number of private IP addresses allowed per instance type.
     */
    readonly secondaryPrivateIps?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A list of security group names (EC2-Classic) or IDs (default VPC) to associate with.
     */
    readonly securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Controls if traffic is routed to the instance when the destination address does not match the instance. Used for NAT or VPNs. Defaults true.
     */
    readonly sourceDestCheck?: pulumi.Input<boolean>;
    /**
     * The current [bid
     * status](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-bid-status.html)
     * of the Spot Instance Request.
     * * `spotRequestState` The current [request
     * state](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-requests.html#creating-spot-request-status)
     * of the Spot Instance Request.
     */
    readonly spotBidStatus?: pulumi.Input<string>;
    /**
     * The Instance ID (if any) that is currently fulfilling
     * the Spot Instance request.
     */
    readonly spotInstanceId?: pulumi.Input<string>;
    /**
     * The maximum price to request on the spot market.
     */
    readonly spotPrice?: pulumi.Input<string>;
    readonly spotRequestState?: pulumi.Input<string>;
    /**
     * If set to `one-time`, after
     * the instance is terminated, the spot request will be closed.
     */
    readonly spotType?: pulumi.Input<string>;
    /**
     * VPC Subnet ID to launch in.
     */
    readonly subnetId?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource. Note that these tags apply to the instance and not block storage devices.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware. The host tenancy is not supported for the import-instance command.
     */
    readonly tenancy?: pulumi.Input<string>;
    /**
     * User data to provide when launching the instance. Do not pass gzip-compressed data via this argument; see `userDataBase64` instead.
     */
    readonly userData?: pulumi.Input<string>;
    /**
     * Can be used instead of `userData` to pass base64-encoded binary data directly. Use this instead of `userData` whenever the value is not a valid UTF-8 string. For example, gzip-encoded user data must be base64-encoded and passed via this argument to avoid corruption.
     */
    readonly userDataBase64?: pulumi.Input<string>;
    /**
     * The start date and time of the request, in UTC [RFC3339](https://tools.ietf.org/html/rfc3339#section-5.8) format(for example, YYYY-MM-DDTHH:MM:SSZ). The default is to start fulfilling the request immediately.
     */
    readonly validFrom?: pulumi.Input<string>;
    /**
     * The end date and time of the request, in UTC [RFC3339](https://tools.ietf.org/html/rfc3339#section-5.8) format(for example, YYYY-MM-DDTHH:MM:SSZ). At this point, no new Spot instance requests are placed or enabled to fulfill the request. The default end date is 7 days from the current date.
     */
    readonly validUntil?: pulumi.Input<string>;
    /**
     * A map of tags to assign, at instance-creation time, to root and EBS volumes.
     */
    readonly volumeTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A list of security group IDs to associate with.
     */
    readonly vpcSecurityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * If set, this provider will
     * wait for the Spot Request to be fulfilled, and will throw an error if the
     * timeout of 10m is reached.
     */
    readonly waitForFulfillment?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a SpotInstanceRequest resource.
 */
export interface SpotInstanceRequestArgs {
    /**
     * AMI to use for the instance.
     */
    readonly ami: pulumi.Input<string>;
    /**
     * Whether to associate a public IP address with an instance in a VPC.
     */
    readonly associatePublicIpAddress?: pulumi.Input<boolean>;
    /**
     * AZ to start the instance in.
     */
    readonly availabilityZone?: pulumi.Input<string>;
    /**
     * The required duration for the Spot instances, in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
     * The duration period starts as soon as your Spot instance receives its instance ID. At the end of the duration period, Amazon EC2 marks the Spot instance for termination and provides a Spot instance termination notice, which gives the instance a two-minute warning before it terminates.
     * Note that you can't specify an Availability Zone group or a launch group if you specify a duration.
     */
    readonly blockDurationMinutes?: pulumi.Input<number>;
    /**
     * Sets the number of CPU cores for an instance. This option is only supported on creation of instance type that support CPU Options [CPU Cores and Threads Per CPU Core Per Instance Type](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html#cpu-options-supported-instances-values) - specifying this option for unsupported instance types will return an error from the EC2 API.
     */
    readonly cpuCoreCount?: pulumi.Input<number>;
    /**
     * If set to to 1, hyperthreading is disabled on the launched instance. Defaults to 2 if not set. See [Optimizing CPU Options](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html) for more information.
     */
    readonly cpuThreadsPerCore?: pulumi.Input<number>;
    /**
     * Configuration block for customizing the credit specification of the instance. See Credit Specification below for more details. the provider will only perform drift detection of its value when present in a configuration. Removing this configuration on existing instances will only stop managing it. It will not change the configuration back to the default for the instance type.
     */
    readonly creditSpecification?: pulumi.Input<inputs.ec2.SpotInstanceRequestCreditSpecification>;
    /**
     * If true, enables [EC2 Instance Termination Protection](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#Using_ChangingDisableAPITermination).
     */
    readonly disableApiTermination?: pulumi.Input<boolean>;
    /**
     * One or more configuration blocks with additional EBS block devices to attach to the instance. Block device configurations only apply on resource creation. See Block Devices below for details on attributes and drift detection. When accessing this as an attribute reference, it is a set of objects.
     */
    readonly ebsBlockDevices?: pulumi.Input<pulumi.Input<inputs.ec2.SpotInstanceRequestEbsBlockDevice>[]>;
    /**
     * If true, the launched EC2 instance will be EBS-optimized. Note that if this is not set on an instance type that is optimized by default then this will show as disabled but if the instance type is optimized by default then there is no need to set this and there is no effect to disabling it. See the [EBS Optimized section](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSOptimized.html) of the AWS User Guide for more information.
     */
    readonly ebsOptimized?: pulumi.Input<boolean>;
    /**
     * Enable Nitro Enclaves on launched instances. See Enclave Options below for more details.
     */
    readonly enclaveOptions?: pulumi.Input<inputs.ec2.SpotInstanceRequestEnclaveOptions>;
    /**
     * One or more configuration blocks to customize Ephemeral (also known as "Instance Store") volumes on the instance. See Block Devices below for details. When accessing this as an attribute reference, it is a set of objects.
     */
    readonly ephemeralBlockDevices?: pulumi.Input<pulumi.Input<inputs.ec2.SpotInstanceRequestEphemeralBlockDevice>[]>;
    /**
     * If true, wait for password data to become available and retrieve it. Useful for getting the administrator password for instances running Microsoft Windows. The password data is exported to the `passwordData` attribute. See [GetPasswordData](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetPasswordData.html) for more information.
     */
    readonly getPasswordData?: pulumi.Input<boolean>;
    /**
     * If true, the launched EC2 instance will support hibernation.
     */
    readonly hibernation?: pulumi.Input<boolean>;
    /**
     * ID of a dedicated host that the instance will be assigned to. Use when an instance is to be launched on a specific dedicated host.
     */
    readonly hostId?: pulumi.Input<string>;
    /**
     * IAM Instance Profile to launch the instance with. Specified as the name of the Instance Profile. Ensure your credentials have the correct permission to assign the instance profile according to the [EC2 documentation](http://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2.html#roles-usingrole-ec2instance-permissions), notably `iam:PassRole`.
     */
    readonly iamInstanceProfile?: pulumi.Input<string>;
    /**
     * Shutdown behavior for the instance. Amazon defaults this to `stop` for EBS-backed instances and `terminate` for instance-store instances. Cannot be set on instance-store instances. See [Shutdown Behavior](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#Using_ChangingInstanceInitiatedShutdownBehavior) for more information.
     */
    readonly instanceInitiatedShutdownBehavior?: pulumi.Input<string>;
    /**
     * Indicates whether a Spot instance stops or terminates when it is interrupted. Default is `terminate` as this is the current AWS behaviour.
     */
    readonly instanceInterruptionBehaviour?: pulumi.Input<string>;
    /**
     * Type of instance to start. Updates to this field will trigger a stop/start of the EC2 instance.
     */
    readonly instanceType: pulumi.Input<string>;
    /**
     * A number of IPv6 addresses to associate with the primary network interface. Amazon EC2 chooses the IPv6 addresses from the range of your subnet.
     */
    readonly ipv6AddressCount?: pulumi.Input<number>;
    /**
     * Specify one or more IPv6 addresses from the range of the subnet to associate with the primary network interface
     */
    readonly ipv6Addresses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Key name of the Key Pair to use for the instance; which can be managed using the `aws.ec2.KeyPair` resource.
     */
    readonly keyName?: pulumi.Input<string>;
    /**
     * A launch group is a group of spot instances that launch together and terminate together.
     * If left empty instances are launched and terminated individually.
     */
    readonly launchGroup?: pulumi.Input<string>;
    /**
     * Customize the metadata options of the instance. See Metadata Options below for more details.
     */
    readonly metadataOptions?: pulumi.Input<inputs.ec2.SpotInstanceRequestMetadataOptions>;
    /**
     * If true, the launched EC2 instance will have detailed monitoring enabled. (Available since v0.6.0)
     */
    readonly monitoring?: pulumi.Input<boolean>;
    /**
     * Customize network interfaces to be attached at instance boot time. See Network Interfaces below for more details.
     */
    readonly networkInterfaces?: pulumi.Input<pulumi.Input<inputs.ec2.SpotInstanceRequestNetworkInterface>[]>;
    /**
     * Placement Group to start the instance in.
     */
    readonly placementGroup?: pulumi.Input<string>;
    /**
     * Private IP address to associate with the instance in a VPC.
     */
    readonly privateIp?: pulumi.Input<string>;
    /**
     * Configuration block to customize details about the root block device of the instance. See Block Devices below for details. When accessing this as an attribute reference, it is a list containing one object.
     */
    readonly rootBlockDevice?: pulumi.Input<inputs.ec2.SpotInstanceRequestRootBlockDevice>;
    /**
     * A list of secondary private IPv4 addresses to assign to the instance's primary network interface (eth0) in a VPC. Can only be assigned to the primary network interface (eth0) attached at instance creation, not a pre-existing network interface i.e. referenced in a `networkInterface` block. Refer to the [Elastic network interfaces documentation](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI) to see the maximum number of private IP addresses allowed per instance type.
     */
    readonly secondaryPrivateIps?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A list of security group names (EC2-Classic) or IDs (default VPC) to associate with.
     */
    readonly securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Controls if traffic is routed to the instance when the destination address does not match the instance. Used for NAT or VPNs. Defaults true.
     */
    readonly sourceDestCheck?: pulumi.Input<boolean>;
    /**
     * The maximum price to request on the spot market.
     */
    readonly spotPrice?: pulumi.Input<string>;
    /**
     * If set to `one-time`, after
     * the instance is terminated, the spot request will be closed.
     */
    readonly spotType?: pulumi.Input<string>;
    /**
     * VPC Subnet ID to launch in.
     */
    readonly subnetId?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource. Note that these tags apply to the instance and not block storage devices.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware. The host tenancy is not supported for the import-instance command.
     */
    readonly tenancy?: pulumi.Input<string>;
    /**
     * User data to provide when launching the instance. Do not pass gzip-compressed data via this argument; see `userDataBase64` instead.
     */
    readonly userData?: pulumi.Input<string>;
    /**
     * Can be used instead of `userData` to pass base64-encoded binary data directly. Use this instead of `userData` whenever the value is not a valid UTF-8 string. For example, gzip-encoded user data must be base64-encoded and passed via this argument to avoid corruption.
     */
    readonly userDataBase64?: pulumi.Input<string>;
    /**
     * The start date and time of the request, in UTC [RFC3339](https://tools.ietf.org/html/rfc3339#section-5.8) format(for example, YYYY-MM-DDTHH:MM:SSZ). The default is to start fulfilling the request immediately.
     */
    readonly validFrom?: pulumi.Input<string>;
    /**
     * The end date and time of the request, in UTC [RFC3339](https://tools.ietf.org/html/rfc3339#section-5.8) format(for example, YYYY-MM-DDTHH:MM:SSZ). At this point, no new Spot instance requests are placed or enabled to fulfill the request. The default end date is 7 days from the current date.
     */
    readonly validUntil?: pulumi.Input<string>;
    /**
     * A map of tags to assign, at instance-creation time, to root and EBS volumes.
     */
    readonly volumeTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A list of security group IDs to associate with.
     */
    readonly vpcSecurityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * If set, this provider will
     * wait for the Spot Request to be fulfilled, and will throw an error if the
     * timeout of 10m is reached.
     */
    readonly waitForFulfillment?: pulumi.Input<boolean>;
}
