import * as pulumi from "@pulumi/pulumi";
/**
 * Provides network associations for AWS Client VPN endpoints. For more information on usage, please see the
 * [AWS Client VPN Administrator's Guide](https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/what-is.html).
 *
 * ## Example Usage
 * ### Using default security group
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2clientvpn.NetworkAssociation("example", {
 *     clientVpnEndpointId: aws_ec2_client_vpn_endpoint.example.id,
 *     subnetId: aws_subnet.example.id,
 * });
 * ```
 * ### Using custom security groups
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2clientvpn.NetworkAssociation("example", {
 *     clientVpnEndpointId: aws_ec2_client_vpn_endpoint.example.id,
 *     subnetId: aws_subnet.example.id,
 *     securityGroups: [
 *         aws_security_group.example1.id,
 *         aws_security_group.example2.id,
 *     ],
 * });
 * ```
 *
 * ## Import
 *
 * AWS Client VPN network associations can be imported using the endpoint ID and the association ID. Values are separated by a `,`.
 *
 * ```sh
 *  $ pulumi import aws:ec2clientvpn/networkAssociation:NetworkAssociation example cvpn-endpoint-0ac3a1abbccddd666,vpn-assoc-0b8db902465d069ad
 * ```
 */
export declare class NetworkAssociation extends pulumi.CustomResource {
    /**
     * Get an existing NetworkAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: NetworkAssociationState, opts?: pulumi.CustomResourceOptions): NetworkAssociation;
    /**
     * Returns true if the given object is an instance of NetworkAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NetworkAssociation;
    /**
     * The unique ID of the target network association.
     */
    readonly associationId: pulumi.Output<string>;
    /**
     * The ID of the Client VPN endpoint.
     */
    readonly clientVpnEndpointId: pulumi.Output<string>;
    /**
     * A list of up to five custom security groups to apply to the target network. If not specified, the VPC's default security group is assigned.
     */
    readonly securityGroups: pulumi.Output<string[]>;
    /**
     * The current state of the target network association.
     */
    readonly status: pulumi.Output<string>;
    /**
     * The ID of the subnet to associate with the Client VPN endpoint.
     */
    readonly subnetId: pulumi.Output<string>;
    /**
     * The ID of the VPC in which the target subnet is located.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a NetworkAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NetworkAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering NetworkAssociation resources.
 */
export interface NetworkAssociationState {
    /**
     * The unique ID of the target network association.
     */
    readonly associationId?: pulumi.Input<string>;
    /**
     * The ID of the Client VPN endpoint.
     */
    readonly clientVpnEndpointId?: pulumi.Input<string>;
    /**
     * A list of up to five custom security groups to apply to the target network. If not specified, the VPC's default security group is assigned.
     */
    readonly securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The current state of the target network association.
     */
    readonly status?: pulumi.Input<string>;
    /**
     * The ID of the subnet to associate with the Client VPN endpoint.
     */
    readonly subnetId?: pulumi.Input<string>;
    /**
     * The ID of the VPC in which the target subnet is located.
     */
    readonly vpcId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a NetworkAssociation resource.
 */
export interface NetworkAssociationArgs {
    /**
     * The ID of the Client VPN endpoint.
     */
    readonly clientVpnEndpointId: pulumi.Input<string>;
    /**
     * A list of up to five custom security groups to apply to the target network. If not specified, the VPC's default security group is assigned.
     */
    readonly securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ID of the subnet to associate with the Client VPN endpoint.
     */
    readonly subnetId: pulumi.Input<string>;
}
