import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Get information on an EC2 Transit Gateway Route Table.
 *
 * ## Example Usage
 * ### By Filter
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.ec2transitgateway.getRouteTable({
 *     filters: [
 *         {
 *             name: "default-association-route-table",
 *             values: ["true"],
 *         },
 *         {
 *             name: "transit-gateway-id",
 *             values: ["tgw-12345678"],
 *         },
 *     ],
 * }, { async: true }));
 * ```
 * ### By Identifier
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.ec2transitgateway.getRouteTable({
 *     id: "tgw-rtb-12345678",
 * }, { async: true }));
 * ```
 */
export declare function getRouteTable(args?: GetRouteTableArgs, opts?: pulumi.InvokeOptions): Promise<GetRouteTableResult>;
/**
 * A collection of arguments for invoking getRouteTable.
 */
export interface GetRouteTableArgs {
    /**
     * One or more configuration blocks containing name-values filters. Detailed below.
     */
    readonly filters?: inputs.ec2transitgateway.GetRouteTableFilter[];
    /**
     * Identifier of the EC2 Transit Gateway Route Table.
     */
    readonly id?: string;
    /**
     * Key-value tags for the EC2 Transit Gateway Route Table
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getRouteTable.
 */
export interface GetRouteTableResult {
    /**
     * EC2 Transit Gateway Route Table Amazon Resource Name (ARN).
     */
    readonly arn: string;
    /**
     * Boolean whether this is the default association route table for the EC2 Transit Gateway
     */
    readonly defaultAssociationRouteTable: boolean;
    /**
     * Boolean whether this is the default propagation route table for the EC2 Transit Gateway
     */
    readonly defaultPropagationRouteTable: boolean;
    readonly filters?: outputs.ec2transitgateway.GetRouteTableFilter[];
    /**
     * EC2 Transit Gateway Route Table identifier
     */
    readonly id: string;
    /**
     * Key-value tags for the EC2 Transit Gateway Route Table
     */
    readonly tags: {
        [key: string]: string;
    };
    /**
     * EC2 Transit Gateway identifier
     */
    readonly transitGatewayId: string;
}
