import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an Elastic File System (EFS) access point.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.efs.AccessPoint("test", {fileSystemId: aws_efs_file_system.foo.id});
 * ```
 *
 * ## Import
 *
 * The EFS access points can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:efs/accessPoint:AccessPoint test fsap-52a643fb
 * ```
 */
export declare class AccessPoint extends pulumi.CustomResource {
    /**
     * Get an existing AccessPoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AccessPointState, opts?: pulumi.CustomResourceOptions): AccessPoint;
    /**
     * Returns true if the given object is an instance of AccessPoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessPoint;
    /**
     * Amazon Resource Name of the access point.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Amazon Resource Name of the file system.
     */
    readonly fileSystemArn: pulumi.Output<string>;
    /**
     * The ID of the file system for which the access point is intended.
     */
    readonly fileSystemId: pulumi.Output<string>;
    readonly ownerId: pulumi.Output<string>;
    /**
     * The operating system user and group applied to all file system requests made using the access point. See Posix User below.
     */
    readonly posixUser: pulumi.Output<outputs.efs.AccessPointPosixUser | undefined>;
    /**
     * Specifies the directory on the Amazon EFS file system that the access point provides access to. See Root Directory below.
     */
    readonly rootDirectory: pulumi.Output<outputs.efs.AccessPointRootDirectory>;
    /**
     * Key-value mapping of resource tags.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a AccessPoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccessPointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AccessPoint resources.
 */
export interface AccessPointState {
    /**
     * Amazon Resource Name of the access point.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Amazon Resource Name of the file system.
     */
    readonly fileSystemArn?: pulumi.Input<string>;
    /**
     * The ID of the file system for which the access point is intended.
     */
    readonly fileSystemId?: pulumi.Input<string>;
    readonly ownerId?: pulumi.Input<string>;
    /**
     * The operating system user and group applied to all file system requests made using the access point. See Posix User below.
     */
    readonly posixUser?: pulumi.Input<inputs.efs.AccessPointPosixUser>;
    /**
     * Specifies the directory on the Amazon EFS file system that the access point provides access to. See Root Directory below.
     */
    readonly rootDirectory?: pulumi.Input<inputs.efs.AccessPointRootDirectory>;
    /**
     * Key-value mapping of resource tags.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a AccessPoint resource.
 */
export interface AccessPointArgs {
    /**
     * The ID of the file system for which the access point is intended.
     */
    readonly fileSystemId: pulumi.Input<string>;
    /**
     * The operating system user and group applied to all file system requests made using the access point. See Posix User below.
     */
    readonly posixUser?: pulumi.Input<inputs.efs.AccessPointPosixUser>;
    /**
     * Specifies the directory on the Amazon EFS file system that the access point provides access to. See Root Directory below.
     */
    readonly rootDirectory?: pulumi.Input<inputs.efs.AccessPointRootDirectory>;
    /**
     * Key-value mapping of resource tags.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
