import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an Elastic File System (EFS) File System Policy resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const fs = new aws.efs.FileSystem("fs", {});
 * const policy = new aws.efs.FileSystemPolicy("policy", {
 *     fileSystemId: fs.id,
 *     policy: `{
 *     "Version": "2012-10-17",
 *     "Id": "ExamplePolicy01",
 *     "Statement": [
 *         {
 *             "Sid": "ExampleStatement01",
 *             "Effect": "Allow",
 *             "Principal": {
 *                 "AWS": "*"
 *             },
 *             "Resource": "${aws_efs_file_system.test.arn}",
 *             "Action": [
 *                 "elasticfilesystem:ClientMount",
 *                 "elasticfilesystem:ClientWrite"
 *             ],
 *             "Condition": {
 *                 "Bool": {
 *                     "aws:SecureTransport": "true"
 *                 }
 *             }
 *         }
 *     ]
 * }
 * `,
 * });
 * ```
 *
 * ## Import
 *
 * The EFS file system policies can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:efs/fileSystemPolicy:FileSystemPolicy foo fs-6fa144c6
 * ```
 */
export declare class FileSystemPolicy extends pulumi.CustomResource {
    /**
     * Get an existing FileSystemPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: FileSystemPolicyState, opts?: pulumi.CustomResourceOptions): FileSystemPolicy;
    /**
     * Returns true if the given object is an instance of FileSystemPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is FileSystemPolicy;
    /**
     * The ID of the EFS file system.
     */
    readonly fileSystemId: pulumi.Output<string>;
    /**
     * The JSON formatted file system policy for the EFS file system. see [Docs](https://docs.aws.amazon.com/efs/latest/ug/access-control-overview.html#access-control-manage-access-intro-resource-policies) for more info.
     */
    readonly policy: pulumi.Output<string>;
    /**
     * Create a FileSystemPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FileSystemPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering FileSystemPolicy resources.
 */
export interface FileSystemPolicyState {
    /**
     * The ID of the EFS file system.
     */
    readonly fileSystemId?: pulumi.Input<string>;
    /**
     * The JSON formatted file system policy for the EFS file system. see [Docs](https://docs.aws.amazon.com/efs/latest/ug/access-control-overview.html#access-control-manage-access-intro-resource-policies) for more info.
     */
    readonly policy?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a FileSystemPolicy resource.
 */
export interface FileSystemPolicyArgs {
    /**
     * The ID of the EFS file system.
     */
    readonly fileSystemId: pulumi.Input<string>;
    /**
     * The JSON formatted file system policy for the EFS file system. see [Docs](https://docs.aws.amazon.com/efs/latest/ug/access-control-overview.html#access-control-manage-access-intro-resource-policies) for more info.
     */
    readonly policy: pulumi.Input<string>;
}
