import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an Elastic File System (EFS) mount target.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const foo = new aws.ec2.Vpc("foo", {cidrBlock: "10.0.0.0/16"});
 * const alphaSubnet = new aws.ec2.Subnet("alphaSubnet", {
 *     vpcId: foo.id,
 *     availabilityZone: "us-west-2a",
 *     cidrBlock: "10.0.1.0/24",
 * });
 * const alphaMountTarget = new aws.efs.MountTarget("alphaMountTarget", {
 *     fileSystemId: aws_efs_file_system.foo.id,
 *     subnetId: alphaSubnet.id,
 * });
 * ```
 *
 * ## Import
 *
 * The EFS mount targets can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:efs/mountTarget:MountTarget alpha fsmt-52a643fb
 * ```
 */
export declare class MountTarget extends pulumi.CustomResource {
    /**
     * Get an existing MountTarget resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: MountTargetState, opts?: pulumi.CustomResourceOptions): MountTarget;
    /**
     * Returns true if the given object is an instance of MountTarget.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MountTarget;
    /**
     * The unique and consistent identifier of the Availability Zone (AZ) that the mount target resides in.
     */
    readonly availabilityZoneId: pulumi.Output<string>;
    /**
     * The name of the Availability Zone (AZ) that the mount target resides in.
     */
    readonly availabilityZoneName: pulumi.Output<string>;
    /**
     * The DNS name for the EFS file system.
     */
    readonly dnsName: pulumi.Output<string>;
    /**
     * Amazon Resource Name of the file system.
     */
    readonly fileSystemArn: pulumi.Output<string>;
    /**
     * The ID of the file system for which the mount target is intended.
     */
    readonly fileSystemId: pulumi.Output<string>;
    /**
     * The address (within the address range of the specified subnet) at
     * which the file system may be mounted via the mount target.
     */
    readonly ipAddress: pulumi.Output<string>;
    /**
     * The DNS name for the given subnet/AZ per [documented convention](http://docs.aws.amazon.com/efs/latest/ug/mounting-fs-mount-cmd-dns-name.html).
     */
    readonly mountTargetDnsName: pulumi.Output<string>;
    /**
     * The ID of the network interface that Amazon EFS created when it created the mount target.
     */
    readonly networkInterfaceId: pulumi.Output<string>;
    /**
     * AWS account ID that owns the resource.
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * A list of up to 5 VPC security group IDs (that must
     * be for the same VPC as subnet specified) in effect for the mount target.
     */
    readonly securityGroups: pulumi.Output<string[]>;
    /**
     * The ID of the subnet to add the mount target in.
     */
    readonly subnetId: pulumi.Output<string>;
    /**
     * Create a MountTarget resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MountTargetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering MountTarget resources.
 */
export interface MountTargetState {
    /**
     * The unique and consistent identifier of the Availability Zone (AZ) that the mount target resides in.
     */
    readonly availabilityZoneId?: pulumi.Input<string>;
    /**
     * The name of the Availability Zone (AZ) that the mount target resides in.
     */
    readonly availabilityZoneName?: pulumi.Input<string>;
    /**
     * The DNS name for the EFS file system.
     */
    readonly dnsName?: pulumi.Input<string>;
    /**
     * Amazon Resource Name of the file system.
     */
    readonly fileSystemArn?: pulumi.Input<string>;
    /**
     * The ID of the file system for which the mount target is intended.
     */
    readonly fileSystemId?: pulumi.Input<string>;
    /**
     * The address (within the address range of the specified subnet) at
     * which the file system may be mounted via the mount target.
     */
    readonly ipAddress?: pulumi.Input<string>;
    /**
     * The DNS name for the given subnet/AZ per [documented convention](http://docs.aws.amazon.com/efs/latest/ug/mounting-fs-mount-cmd-dns-name.html).
     */
    readonly mountTargetDnsName?: pulumi.Input<string>;
    /**
     * The ID of the network interface that Amazon EFS created when it created the mount target.
     */
    readonly networkInterfaceId?: pulumi.Input<string>;
    /**
     * AWS account ID that owns the resource.
     */
    readonly ownerId?: pulumi.Input<string>;
    /**
     * A list of up to 5 VPC security group IDs (that must
     * be for the same VPC as subnet specified) in effect for the mount target.
     */
    readonly securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ID of the subnet to add the mount target in.
     */
    readonly subnetId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a MountTarget resource.
 */
export interface MountTargetArgs {
    /**
     * The ID of the file system for which the mount target is intended.
     */
    readonly fileSystemId: pulumi.Input<string>;
    /**
     * The address (within the address range of the specified subnet) at
     * which the file system may be mounted via the mount target.
     */
    readonly ipAddress?: pulumi.Input<string>;
    /**
     * A list of up to 5 VPC security group IDs (that must
     * be for the same VPC as subnet specified) in effect for the mount target.
     */
    readonly securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ID of the subnet to add the mount target in.
     */
    readonly subnetId: pulumi.Input<string>;
}
