import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an ElastiCache Subnet Group resource.
 *
 * > **NOTE:** ElastiCache Subnet Groups are only for use when working with an
 * ElastiCache cluster **inside** of a VPC. If you are on EC2 Classic, see the
 * ElastiCache Security Group resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const fooVpc = new aws.ec2.Vpc("fooVpc", {
 *     cidrBlock: "10.0.0.0/16",
 *     tags: {
 *         Name: "tf-test",
 *     },
 * });
 * const fooSubnet = new aws.ec2.Subnet("fooSubnet", {
 *     vpcId: fooVpc.id,
 *     cidrBlock: "10.0.0.0/24",
 *     availabilityZone: "us-west-2a",
 *     tags: {
 *         Name: "tf-test",
 *     },
 * });
 * const bar = new aws.elasticache.SubnetGroup("bar", {subnetIds: [fooSubnet.id]});
 * ```
 *
 * ## Import
 *
 * ElastiCache Subnet Groups can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:elasticache/subnetGroup:SubnetGroup bar tf-test-cache-subnet
 * ```
 */
export declare class SubnetGroup extends pulumi.CustomResource {
    /**
     * Get an existing SubnetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SubnetGroupState, opts?: pulumi.CustomResourceOptions): SubnetGroup;
    /**
     * Returns true if the given object is an instance of SubnetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SubnetGroup;
    /**
     * Description for the cache subnet group. Defaults to "Managed by Pulumi".
     */
    readonly description: pulumi.Output<string>;
    /**
     * Name for the cache subnet group. Elasticache converts this name to lowercase.
     */
    readonly name: pulumi.Output<string>;
    /**
     * List of VPC Subnet IDs for the cache subnet group
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * Create a SubnetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SubnetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SubnetGroup resources.
 */
export interface SubnetGroupState {
    /**
     * Description for the cache subnet group. Defaults to "Managed by Pulumi".
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Name for the cache subnet group. Elasticache converts this name to lowercase.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * List of VPC Subnet IDs for the cache subnet group
     */
    readonly subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a SubnetGroup resource.
 */
export interface SubnetGroupArgs {
    /**
     * Description for the cache subnet group. Defaults to "Managed by Pulumi".
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Name for the cache subnet group. Elasticache converts this name to lowercase.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * List of VPC Subnet IDs for the cache subnet group
     */
    readonly subnetIds: pulumi.Input<pulumi.Input<string>[]>;
}
