import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
import { PolicyDocument } from "../iam";
/**
 * Manages an AWS Elasticsearch Domain.
 *
 * ## Example Usage
 * ### Basic Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.elasticsearch.Domain("example", {
 *     clusterConfig: {
 *         instanceType: "r4.large.elasticsearch",
 *     },
 *     elasticsearchVersion: "1.5",
 *     snapshotOptions: {
 *         automatedSnapshotStartHour: 23,
 *     },
 *     tags: {
 *         Domain: "TestDomain",
 *     },
 * });
 * ```
 * ### Access Policy
 *
 * > See also: `aws.elasticsearch.DomainPolicy` resource
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const config = new pulumi.Config();
 * const domain = config.get("domain") || "tf-test";
 * const currentRegion = aws.getRegion({});
 * const currentCallerIdentity = aws.getCallerIdentity({});
 * const example = new aws.elasticsearch.Domain("example", {accessPolicies: Promise.all([currentRegion, currentCallerIdentity]).then(([currentRegion, currentCallerIdentity]) => `{
 *   "Version": "2012-10-17",
 *   "Statement": [
 *     {
 *       "Action": "es:*",
 *       "Principal": "*",
 *       "Effect": "Allow",
 *       "Resource": "arn:aws:es:${currentRegion.name}:${currentCallerIdentity.accountId}:domain/${domain}/*",
 *       "Condition": {
 *         "IpAddress": {"aws:SourceIp": ["66.193.100.22/32"]}
 *       }
 *     }
 *   ]
 * }
 * `)});
 * ```
 * ### Log Publishing to CloudWatch Logs
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleLogGroup = new aws.cloudwatch.LogGroup("exampleLogGroup", {});
 * const exampleLogResourcePolicy = new aws.cloudwatch.LogResourcePolicy("exampleLogResourcePolicy", {
 *     policyName: "example",
 *     policyDocument: `{
 *   "Version": "2012-10-17",
 *   "Statement": [
 *     {
 *       "Effect": "Allow",
 *       "Principal": {
 *         "Service": "es.amazonaws.com"
 *       },
 *       "Action": [
 *         "logs:PutLogEvents",
 *         "logs:PutLogEventsBatch",
 *         "logs:CreateLogStream"
 *       ],
 *       "Resource": "arn:aws:logs:*"
 *     }
 *   ]
 * }
 * `,
 * });
 * // .. other configuration ...
 * const exampleDomain = new aws.elasticsearch.Domain("exampleDomain", {logPublishingOptions: [{
 *     cloudwatchLogGroupArn: exampleLogGroup.arn,
 *     logType: "INDEX_SLOW_LOGS",
 * }]});
 * ```
 * ### VPC based ES
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const config = new pulumi.Config();
 * const vpc = config.requireObject("vpc");
 * const domain = config.get("domain") || "tf-test";
 * const selectedVpc = aws.ec2.getVpc({
 *     tags: {
 *         Name: vpc,
 *     },
 * });
 * const selectedSubnetIds = selectedVpc.then(selectedVpc => aws.ec2.getSubnetIds({
 *     vpcId: selectedVpc.id,
 *     tags: {
 *         Tier: "private",
 *     },
 * }));
 * const currentRegion = aws.getRegion({});
 * const currentCallerIdentity = aws.getCallerIdentity({});
 * const esSecurityGroup = new aws.ec2.SecurityGroup("esSecurityGroup", {
 *     description: "Managed by Pulumi",
 *     vpcId: selectedVpc.then(selectedVpc => selectedVpc.id),
 *     ingress: [{
 *         fromPort: 443,
 *         toPort: 443,
 *         protocol: "tcp",
 *         cidrBlocks: [selectedVpc.then(selectedVpc => selectedVpc.cidrBlock)],
 *     }],
 * });
 * const esServiceLinkedRole = new aws.iam.ServiceLinkedRole("esServiceLinkedRole", {awsServiceName: "es.amazonaws.com"});
 * const esDomain = new aws.elasticsearch.Domain("esDomain", {
 *     elasticsearchVersion: "6.3",
 *     clusterConfig: {
 *         instanceType: "m4.large.elasticsearch",
 *     },
 *     vpcOptions: {
 *         subnetIds: [
 *             selectedSubnetIds.then(selectedSubnetIds => selectedSubnetIds.ids[0]),
 *             selectedSubnetIds.then(selectedSubnetIds => selectedSubnetIds.ids[1]),
 *         ],
 *         securityGroupIds: [esSecurityGroup.id],
 *     },
 *     advancedOptions: {
 *         "rest.action.multi.allow_explicit_index": "true",
 *     },
 *     accessPolicies: Promise.all([currentRegion, currentCallerIdentity]).then(([currentRegion, currentCallerIdentity]) => `{
 * 	"Version": "2012-10-17",
 * 	"Statement": [
 * 		{
 * 			"Action": "es:*",
 * 			"Principal": "*",
 * 			"Effect": "Allow",
 * 			"Resource": "arn:aws:es:${currentRegion.name}:${currentCallerIdentity.accountId}:domain/${domain}/*"
 * 		}
 * 	]
 * }
 * `),
 *     snapshotOptions: {
 *         automatedSnapshotStartHour: 23,
 *     },
 *     tags: {
 *         Domain: "TestDomain",
 *     },
 * }, {
 *     dependsOn: [esServiceLinkedRole],
 * });
 * ```
 *
 * ## Import
 *
 * Elasticsearch domains can be imported using the `domain_name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:elasticsearch/domain:Domain example domain_name
 * ```
 */
export declare class Domain extends pulumi.CustomResource {
    /**
     * Get an existing Domain resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DomainState, opts?: pulumi.CustomResourceOptions): Domain;
    /**
     * Returns true if the given object is an instance of Domain.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Domain;
    /**
     * IAM policy document specifying the access policies for the domain
     */
    readonly accessPolicies: pulumi.Output<string>;
    /**
     * Key-value string pairs to specify advanced configuration options.
     * Note that the values for these configuration options must be strings (wrapped in quotes) or they
     * may be wrong and cause a perpetual diff, causing this provider to want to recreate your Elasticsearch
     * domain on every apply.
     */
    readonly advancedOptions: pulumi.Output<{
        [key: string]: string;
    }>;
    /**
     * Options for [fine-grained access control](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/fgac.html). See below for more details.
     */
    readonly advancedSecurityOptions: pulumi.Output<outputs.elasticsearch.DomainAdvancedSecurityOptions>;
    /**
     * Amazon Resource Name (ARN) of the domain.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Cluster configuration of the domain, see below.
     */
    readonly clusterConfig: pulumi.Output<outputs.elasticsearch.DomainClusterConfig>;
    /**
     * Options for authenticating Kibana with Cognito. See below.
     */
    readonly cognitoOptions: pulumi.Output<outputs.elasticsearch.DomainCognitoOptions | undefined>;
    /**
     * Domain endpoint HTTP(S) related options. See below.
     */
    readonly domainEndpointOptions: pulumi.Output<outputs.elasticsearch.DomainDomainEndpointOptions>;
    /**
     * Unique identifier for the domain.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * Name of the domain.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * EBS related options, may be required based on chosen [instance size](https://aws.amazon.com/elasticsearch-service/pricing/). See below.
     */
    readonly ebsOptions: pulumi.Output<outputs.elasticsearch.DomainEbsOptions>;
    /**
     * The version of Elasticsearch to deploy. Defaults to `1.5`
     */
    readonly elasticsearchVersion: pulumi.Output<string | undefined>;
    /**
     * Encrypt at rest options. Only available for [certain instance types](http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html). See below.
     */
    readonly encryptAtRest: pulumi.Output<outputs.elasticsearch.DomainEncryptAtRest>;
    /**
     * Domain-specific endpoint used to submit index, search, and data upload requests.
     */
    readonly endpoint: pulumi.Output<string>;
    /**
     * Domain-specific endpoint for kibana without https scheme.
     * * `vpc_options.0.availability_zones` - If the domain was created inside a VPC, the names of the availability zones the configured `subnetIds` were created inside.
     * * `vpc_options.0.vpc_id` - If the domain was created inside a VPC, the ID of the VPC.
     */
    readonly kibanaEndpoint: pulumi.Output<string>;
    /**
     * Options for publishing slow  and application logs to CloudWatch Logs. This block can be declared multiple times, for each log_type, within the same resource.
     */
    readonly logPublishingOptions: pulumi.Output<outputs.elasticsearch.DomainLogPublishingOption[] | undefined>;
    /**
     * Node-to-node encryption options. See below.
     */
    readonly nodeToNodeEncryption: pulumi.Output<outputs.elasticsearch.DomainNodeToNodeEncryption>;
    /**
     * Snapshot related options, see below.
     */
    readonly snapshotOptions: pulumi.Output<outputs.elasticsearch.DomainSnapshotOptions | undefined>;
    /**
     * A map of tags to assign to the resource
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * VPC related options, see below. Adding or removing this configuration forces a new resource ([documentation](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-vpc-limitations)).
     */
    readonly vpcOptions: pulumi.Output<outputs.elasticsearch.DomainVpcOptions | undefined>;
    /**
     * Create a Domain resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DomainArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Domain resources.
 */
export interface DomainState {
    /**
     * IAM policy document specifying the access policies for the domain
     */
    readonly accessPolicies?: pulumi.Input<string | PolicyDocument>;
    /**
     * Key-value string pairs to specify advanced configuration options.
     * Note that the values for these configuration options must be strings (wrapped in quotes) or they
     * may be wrong and cause a perpetual diff, causing this provider to want to recreate your Elasticsearch
     * domain on every apply.
     */
    readonly advancedOptions?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Options for [fine-grained access control](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/fgac.html). See below for more details.
     */
    readonly advancedSecurityOptions?: pulumi.Input<inputs.elasticsearch.DomainAdvancedSecurityOptions>;
    /**
     * Amazon Resource Name (ARN) of the domain.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Cluster configuration of the domain, see below.
     */
    readonly clusterConfig?: pulumi.Input<inputs.elasticsearch.DomainClusterConfig>;
    /**
     * Options for authenticating Kibana with Cognito. See below.
     */
    readonly cognitoOptions?: pulumi.Input<inputs.elasticsearch.DomainCognitoOptions>;
    /**
     * Domain endpoint HTTP(S) related options. See below.
     */
    readonly domainEndpointOptions?: pulumi.Input<inputs.elasticsearch.DomainDomainEndpointOptions>;
    /**
     * Unique identifier for the domain.
     */
    readonly domainId?: pulumi.Input<string>;
    /**
     * Name of the domain.
     */
    readonly domainName?: pulumi.Input<string>;
    /**
     * EBS related options, may be required based on chosen [instance size](https://aws.amazon.com/elasticsearch-service/pricing/). See below.
     */
    readonly ebsOptions?: pulumi.Input<inputs.elasticsearch.DomainEbsOptions>;
    /**
     * The version of Elasticsearch to deploy. Defaults to `1.5`
     */
    readonly elasticsearchVersion?: pulumi.Input<string>;
    /**
     * Encrypt at rest options. Only available for [certain instance types](http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html). See below.
     */
    readonly encryptAtRest?: pulumi.Input<inputs.elasticsearch.DomainEncryptAtRest>;
    /**
     * Domain-specific endpoint used to submit index, search, and data upload requests.
     */
    readonly endpoint?: pulumi.Input<string>;
    /**
     * Domain-specific endpoint for kibana without https scheme.
     * * `vpc_options.0.availability_zones` - If the domain was created inside a VPC, the names of the availability zones the configured `subnetIds` were created inside.
     * * `vpc_options.0.vpc_id` - If the domain was created inside a VPC, the ID of the VPC.
     */
    readonly kibanaEndpoint?: pulumi.Input<string>;
    /**
     * Options for publishing slow  and application logs to CloudWatch Logs. This block can be declared multiple times, for each log_type, within the same resource.
     */
    readonly logPublishingOptions?: pulumi.Input<pulumi.Input<inputs.elasticsearch.DomainLogPublishingOption>[]>;
    /**
     * Node-to-node encryption options. See below.
     */
    readonly nodeToNodeEncryption?: pulumi.Input<inputs.elasticsearch.DomainNodeToNodeEncryption>;
    /**
     * Snapshot related options, see below.
     */
    readonly snapshotOptions?: pulumi.Input<inputs.elasticsearch.DomainSnapshotOptions>;
    /**
     * A map of tags to assign to the resource
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * VPC related options, see below. Adding or removing this configuration forces a new resource ([documentation](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-vpc-limitations)).
     */
    readonly vpcOptions?: pulumi.Input<inputs.elasticsearch.DomainVpcOptions>;
}
/**
 * The set of arguments for constructing a Domain resource.
 */
export interface DomainArgs {
    /**
     * IAM policy document specifying the access policies for the domain
     */
    readonly accessPolicies?: pulumi.Input<string | PolicyDocument>;
    /**
     * Key-value string pairs to specify advanced configuration options.
     * Note that the values for these configuration options must be strings (wrapped in quotes) or they
     * may be wrong and cause a perpetual diff, causing this provider to want to recreate your Elasticsearch
     * domain on every apply.
     */
    readonly advancedOptions?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Options for [fine-grained access control](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/fgac.html). See below for more details.
     */
    readonly advancedSecurityOptions?: pulumi.Input<inputs.elasticsearch.DomainAdvancedSecurityOptions>;
    /**
     * Cluster configuration of the domain, see below.
     */
    readonly clusterConfig?: pulumi.Input<inputs.elasticsearch.DomainClusterConfig>;
    /**
     * Options for authenticating Kibana with Cognito. See below.
     */
    readonly cognitoOptions?: pulumi.Input<inputs.elasticsearch.DomainCognitoOptions>;
    /**
     * Domain endpoint HTTP(S) related options. See below.
     */
    readonly domainEndpointOptions?: pulumi.Input<inputs.elasticsearch.DomainDomainEndpointOptions>;
    /**
     * Name of the domain.
     */
    readonly domainName?: pulumi.Input<string>;
    /**
     * EBS related options, may be required based on chosen [instance size](https://aws.amazon.com/elasticsearch-service/pricing/). See below.
     */
    readonly ebsOptions?: pulumi.Input<inputs.elasticsearch.DomainEbsOptions>;
    /**
     * The version of Elasticsearch to deploy. Defaults to `1.5`
     */
    readonly elasticsearchVersion?: pulumi.Input<string>;
    /**
     * Encrypt at rest options. Only available for [certain instance types](http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html). See below.
     */
    readonly encryptAtRest?: pulumi.Input<inputs.elasticsearch.DomainEncryptAtRest>;
    /**
     * Options for publishing slow  and application logs to CloudWatch Logs. This block can be declared multiple times, for each log_type, within the same resource.
     */
    readonly logPublishingOptions?: pulumi.Input<pulumi.Input<inputs.elasticsearch.DomainLogPublishingOption>[]>;
    /**
     * Node-to-node encryption options. See below.
     */
    readonly nodeToNodeEncryption?: pulumi.Input<inputs.elasticsearch.DomainNodeToNodeEncryption>;
    /**
     * Snapshot related options, see below.
     */
    readonly snapshotOptions?: pulumi.Input<inputs.elasticsearch.DomainSnapshotOptions>;
    /**
     * A map of tags to assign to the resource
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * VPC related options, see below. Adding or removing this configuration forces a new resource ([documentation](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-vpc-limitations)).
     */
    readonly vpcOptions?: pulumi.Input<inputs.elasticsearch.DomainVpcOptions>;
}
