import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a Global Accelerator endpoint group.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.globalaccelerator.EndpointGroup("example", {
 *     listenerArn: aws_globalaccelerator_listener.example.id,
 *     endpointConfigurations: [{
 *         endpointId: aws_lb.example.arn,
 *         weight: 100,
 *     }],
 * });
 * ```
 *
 * ## Import
 *
 * Global Accelerator endpoint groups can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:globalaccelerator/endpointGroup:EndpointGroup example arn:aws:globalaccelerator::111111111111:accelerator/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/listener/xxxxxxx/endpoint-group/xxxxxxxx
 * ```
 */
export declare class EndpointGroup extends pulumi.CustomResource {
    /**
     * Get an existing EndpointGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EndpointGroupState, opts?: pulumi.CustomResourceOptions): EndpointGroup;
    /**
     * Returns true if the given object is an instance of EndpointGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EndpointGroup;
    /**
     * The Amazon Resource Name (ARN) of the endpoint group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The list of endpoint objects. Fields documented below.
     */
    readonly endpointConfigurations: pulumi.Output<outputs.globalaccelerator.EndpointGroupEndpointConfiguration[] | undefined>;
    /**
     * The name of the AWS Region where the endpoint group is located.
     */
    readonly endpointGroupRegion: pulumi.Output<string>;
    /**
     * The time—10 seconds or 30 seconds—between each health check for an endpoint. The default value is 30.
     */
    readonly healthCheckIntervalSeconds: pulumi.Output<number | undefined>;
    /**
     * If the protocol is HTTP/S, then this specifies the path that is the destination for health check targets. The default value is slash (`/`). the provider will only perform drift detection of its value when present in a configuration.
     */
    readonly healthCheckPath: pulumi.Output<string>;
    /**
     * The port that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default port is the listener port that this endpoint group is associated with. If listener port is a list of ports, Global Accelerator uses the first port in the list.
     * the provider will only perform drift detection of its value when present in a configuration.
     */
    readonly healthCheckPort: pulumi.Output<number>;
    /**
     * The protocol that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default value is TCP.
     */
    readonly healthCheckProtocol: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the listener.
     */
    readonly listenerArn: pulumi.Output<string>;
    /**
     * Override specific listener ports used to route traffic to endpoints that are part of this endpoint group. Fields documented below.
     */
    readonly portOverrides: pulumi.Output<outputs.globalaccelerator.EndpointGroupPortOverride[] | undefined>;
    /**
     * The number of consecutive health checks required to set the state of a healthy endpoint to unhealthy, or to set an unhealthy endpoint to healthy. The default value is 3.
     */
    readonly thresholdCount: pulumi.Output<number | undefined>;
    /**
     * The percentage of traffic to send to an AWS Region. Additional traffic is distributed to other endpoint groups for this listener. The default value is 100.
     */
    readonly trafficDialPercentage: pulumi.Output<number | undefined>;
    /**
     * Create a EndpointGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EndpointGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EndpointGroup resources.
 */
export interface EndpointGroupState {
    /**
     * The Amazon Resource Name (ARN) of the endpoint group.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The list of endpoint objects. Fields documented below.
     */
    readonly endpointConfigurations?: pulumi.Input<pulumi.Input<inputs.globalaccelerator.EndpointGroupEndpointConfiguration>[]>;
    /**
     * The name of the AWS Region where the endpoint group is located.
     */
    readonly endpointGroupRegion?: pulumi.Input<string>;
    /**
     * The time—10 seconds or 30 seconds—between each health check for an endpoint. The default value is 30.
     */
    readonly healthCheckIntervalSeconds?: pulumi.Input<number>;
    /**
     * If the protocol is HTTP/S, then this specifies the path that is the destination for health check targets. The default value is slash (`/`). the provider will only perform drift detection of its value when present in a configuration.
     */
    readonly healthCheckPath?: pulumi.Input<string>;
    /**
     * The port that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default port is the listener port that this endpoint group is associated with. If listener port is a list of ports, Global Accelerator uses the first port in the list.
     * the provider will only perform drift detection of its value when present in a configuration.
     */
    readonly healthCheckPort?: pulumi.Input<number>;
    /**
     * The protocol that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default value is TCP.
     */
    readonly healthCheckProtocol?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the listener.
     */
    readonly listenerArn?: pulumi.Input<string>;
    /**
     * Override specific listener ports used to route traffic to endpoints that are part of this endpoint group. Fields documented below.
     */
    readonly portOverrides?: pulumi.Input<pulumi.Input<inputs.globalaccelerator.EndpointGroupPortOverride>[]>;
    /**
     * The number of consecutive health checks required to set the state of a healthy endpoint to unhealthy, or to set an unhealthy endpoint to healthy. The default value is 3.
     */
    readonly thresholdCount?: pulumi.Input<number>;
    /**
     * The percentage of traffic to send to an AWS Region. Additional traffic is distributed to other endpoint groups for this listener. The default value is 100.
     */
    readonly trafficDialPercentage?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a EndpointGroup resource.
 */
export interface EndpointGroupArgs {
    /**
     * The list of endpoint objects. Fields documented below.
     */
    readonly endpointConfigurations?: pulumi.Input<pulumi.Input<inputs.globalaccelerator.EndpointGroupEndpointConfiguration>[]>;
    /**
     * The name of the AWS Region where the endpoint group is located.
     */
    readonly endpointGroupRegion?: pulumi.Input<string>;
    /**
     * The time—10 seconds or 30 seconds—between each health check for an endpoint. The default value is 30.
     */
    readonly healthCheckIntervalSeconds?: pulumi.Input<number>;
    /**
     * If the protocol is HTTP/S, then this specifies the path that is the destination for health check targets. The default value is slash (`/`). the provider will only perform drift detection of its value when present in a configuration.
     */
    readonly healthCheckPath?: pulumi.Input<string>;
    /**
     * The port that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default port is the listener port that this endpoint group is associated with. If listener port is a list of ports, Global Accelerator uses the first port in the list.
     * the provider will only perform drift detection of its value when present in a configuration.
     */
    readonly healthCheckPort?: pulumi.Input<number>;
    /**
     * The protocol that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default value is TCP.
     */
    readonly healthCheckProtocol?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the listener.
     */
    readonly listenerArn: pulumi.Input<string>;
    /**
     * Override specific listener ports used to route traffic to endpoints that are part of this endpoint group. Fields documented below.
     */
    readonly portOverrides?: pulumi.Input<pulumi.Input<inputs.globalaccelerator.EndpointGroupPortOverride>[]>;
    /**
     * The number of consecutive health checks required to set the state of a healthy endpoint to unhealthy, or to set an unhealthy endpoint to healthy. The default value is 3.
     */
    readonly thresholdCount?: pulumi.Input<number>;
    /**
     * The percentage of traffic to send to an AWS Region. Additional traffic is distributed to other endpoint groups for this listener. The default value is 100.
     */
    readonly trafficDialPercentage?: pulumi.Input<number>;
}
