import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Manages a Glue Security Configuration.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.glue.SecurityConfiguration("example", {encryptionConfiguration: {
 *     cloudwatchEncryption: {
 *         cloudwatchEncryptionMode: "DISABLED",
 *     },
 *     jobBookmarksEncryption: {
 *         jobBookmarksEncryptionMode: "DISABLED",
 *     },
 *     s3Encryption: {
 *         kmsKeyArn: data.aws_kms_key.example.arn,
 *         s3EncryptionMode: "SSE-KMS",
 *     },
 * }});
 * ```
 *
 * ## Import
 *
 * Glue Security Configurations can be imported using `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:glue/securityConfiguration:SecurityConfiguration example example
 * ```
 */
export declare class SecurityConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing SecurityConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SecurityConfigurationState, opts?: pulumi.CustomResourceOptions): SecurityConfiguration;
    /**
     * Returns true if the given object is an instance of SecurityConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SecurityConfiguration;
    /**
     * Configuration block containing encryption configuration. Detailed below.
     */
    readonly encryptionConfiguration: pulumi.Output<outputs.glue.SecurityConfigurationEncryptionConfiguration>;
    /**
     * Name of the security configuration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a SecurityConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SecurityConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SecurityConfiguration resources.
 */
export interface SecurityConfigurationState {
    /**
     * Configuration block containing encryption configuration. Detailed below.
     */
    readonly encryptionConfiguration?: pulumi.Input<inputs.glue.SecurityConfigurationEncryptionConfiguration>;
    /**
     * Name of the security configuration.
     */
    readonly name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a SecurityConfiguration resource.
 */
export interface SecurityConfigurationArgs {
    /**
     * Configuration block containing encryption configuration. Detailed below.
     */
    readonly encryptionConfiguration: pulumi.Input<inputs.glue.SecurityConfigurationEncryptionConfiguration>;
    /**
     * Name of the security configuration.
     */
    readonly name?: pulumi.Input<string>;
}
