import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Manages an Image Builder Image Pipeline.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.imagebuilder.ImagePipeline("example", {
 *     imageRecipeArn: aws_imagebuilder_image_recipe.example.arn,
 *     infrastructureConfigurationArn: aws_imagebuilder_infrastructure_configuration.example.arn,
 *     schedule: {
 *         scheduleExpression: "cron(0 0 * * ? *)",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * `aws_imagebuilder_image_pipeline` resources can be imported using the Amazon Resource Name (ARN), e.g.
 *
 * ```sh
 *  $ pulumi import aws:imagebuilder/imagePipeline:ImagePipeline example arn:aws:imagebuilder:us-east-1:123456789012:image-pipeline/example
 * ```
 */
export declare class ImagePipeline extends pulumi.CustomResource {
    /**
     * Get an existing ImagePipeline resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ImagePipelineState, opts?: pulumi.CustomResourceOptions): ImagePipeline;
    /**
     * Returns true if the given object is an instance of ImagePipeline.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ImagePipeline;
    /**
     * Amazon Resource Name (ARN) of the image pipeline.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Date the image pipeline was created.
     */
    readonly dateCreated: pulumi.Output<string>;
    /**
     * Date the image pipeline was last run.
     */
    readonly dateLastRun: pulumi.Output<string>;
    /**
     * Date the image pipeline will run next.
     */
    readonly dateNextRun: pulumi.Output<string>;
    /**
     * Date the image pipeline was updated.
     */
    readonly dateUpdated: pulumi.Output<string>;
    /**
     * Description of the image pipeline.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Distribution Configuration.
     */
    readonly distributionConfigurationArn: pulumi.Output<string | undefined>;
    /**
     * Whether additional information about the image being created is collected. Defaults to `true`.
     */
    readonly enhancedImageMetadataEnabled: pulumi.Output<boolean | undefined>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Infrastructure Recipe.
     */
    readonly imageRecipeArn: pulumi.Output<string>;
    /**
     * Configuration block with image tests configuration. Detailed below.
     */
    readonly imageTestsConfiguration: pulumi.Output<outputs.imagebuilder.ImagePipelineImageTestsConfiguration>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Infrastructure Configuration.
     */
    readonly infrastructureConfigurationArn: pulumi.Output<string>;
    /**
     * Name of the image pipeline.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Platform of the image pipeline.
     */
    readonly platform: pulumi.Output<string>;
    /**
     * Configuration block with schedule settings. Detailed below.
     */
    readonly schedule: pulumi.Output<outputs.imagebuilder.ImagePipelineSchedule | undefined>;
    /**
     * Status of the image pipeline. Valid values are `DISABLED` and `ENABLED`. Defaults to `ENABLED`.
     */
    readonly status: pulumi.Output<string | undefined>;
    /**
     * Key-value map of resource tags for the image pipeline.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a ImagePipeline resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ImagePipelineArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ImagePipeline resources.
 */
export interface ImagePipelineState {
    /**
     * Amazon Resource Name (ARN) of the image pipeline.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Date the image pipeline was created.
     */
    readonly dateCreated?: pulumi.Input<string>;
    /**
     * Date the image pipeline was last run.
     */
    readonly dateLastRun?: pulumi.Input<string>;
    /**
     * Date the image pipeline will run next.
     */
    readonly dateNextRun?: pulumi.Input<string>;
    /**
     * Date the image pipeline was updated.
     */
    readonly dateUpdated?: pulumi.Input<string>;
    /**
     * Description of the image pipeline.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Distribution Configuration.
     */
    readonly distributionConfigurationArn?: pulumi.Input<string>;
    /**
     * Whether additional information about the image being created is collected. Defaults to `true`.
     */
    readonly enhancedImageMetadataEnabled?: pulumi.Input<boolean>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Infrastructure Recipe.
     */
    readonly imageRecipeArn?: pulumi.Input<string>;
    /**
     * Configuration block with image tests configuration. Detailed below.
     */
    readonly imageTestsConfiguration?: pulumi.Input<inputs.imagebuilder.ImagePipelineImageTestsConfiguration>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Infrastructure Configuration.
     */
    readonly infrastructureConfigurationArn?: pulumi.Input<string>;
    /**
     * Name of the image pipeline.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Platform of the image pipeline.
     */
    readonly platform?: pulumi.Input<string>;
    /**
     * Configuration block with schedule settings. Detailed below.
     */
    readonly schedule?: pulumi.Input<inputs.imagebuilder.ImagePipelineSchedule>;
    /**
     * Status of the image pipeline. Valid values are `DISABLED` and `ENABLED`. Defaults to `ENABLED`.
     */
    readonly status?: pulumi.Input<string>;
    /**
     * Key-value map of resource tags for the image pipeline.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a ImagePipeline resource.
 */
export interface ImagePipelineArgs {
    /**
     * Description of the image pipeline.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Distribution Configuration.
     */
    readonly distributionConfigurationArn?: pulumi.Input<string>;
    /**
     * Whether additional information about the image being created is collected. Defaults to `true`.
     */
    readonly enhancedImageMetadataEnabled?: pulumi.Input<boolean>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Infrastructure Recipe.
     */
    readonly imageRecipeArn: pulumi.Input<string>;
    /**
     * Configuration block with image tests configuration. Detailed below.
     */
    readonly imageTestsConfiguration?: pulumi.Input<inputs.imagebuilder.ImagePipelineImageTestsConfiguration>;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Infrastructure Configuration.
     */
    readonly infrastructureConfigurationArn: pulumi.Input<string>;
    /**
     * Name of the image pipeline.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Configuration block with schedule settings. Detailed below.
     */
    readonly schedule?: pulumi.Input<inputs.imagebuilder.ImagePipelineSchedule>;
    /**
     * Status of the image pipeline. Valid values are `DISABLED` and `ENABLED`. Defaults to `ENABLED`.
     */
    readonly status?: pulumi.Input<string>;
    /**
     * Key-value map of resource tags for the image pipeline.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
