import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Manages an Image Builder Image Recipe.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.imagebuilder.ImageRecipe("example", {
 *     blockDeviceMappings: [{
 *         deviceName: "/dev/xvdb",
 *         ebs: {
 *             deleteOnTermination: true,
 *             volumeSize: 100,
 *             volumeType: "gp2",
 *         },
 *     }],
 *     components: [{
 *         componentArn: aws_imagebuilder_component.example.arn,
 *     }],
 *     parentImage: `arn:${data.aws_partition.current.partition}:imagebuilder:${data.aws_region.current.name}:aws:image/amazon-linux-2-x86/x.x.x`,
 *     version: "1.0.0",
 * });
 * ```
 *
 * ## Import
 *
 * `aws_imagebuilder_image_recipe` resources can be imported by using the Amazon Resource Name (ARN), e.g.
 *
 * ```sh
 *  $ pulumi import aws:imagebuilder/imageRecipe:ImageRecipe example arn:aws:imagebuilder:us-east-1:123456789012:image-recipe/example/1.0.0
 * ```
 */
export declare class ImageRecipe extends pulumi.CustomResource {
    /**
     * Get an existing ImageRecipe resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ImageRecipeState, opts?: pulumi.CustomResourceOptions): ImageRecipe;
    /**
     * Returns true if the given object is an instance of ImageRecipe.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ImageRecipe;
    /**
     * (Required) Amazon Resource Name (ARN) of the image recipe.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Configuration block(s) with block device mappings for the the image recipe. Detailed below.
     */
    readonly blockDeviceMappings: pulumi.Output<outputs.imagebuilder.ImageRecipeBlockDeviceMapping[] | undefined>;
    /**
     * Ordered configuration block(s) with components for the image recipe. Detailed below.
     */
    readonly components: pulumi.Output<outputs.imagebuilder.ImageRecipeComponent[]>;
    /**
     * Date the image recipe was created.
     */
    readonly dateCreated: pulumi.Output<string>;
    /**
     * Description of the image recipe.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Name of the image recipe.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Owner of the image recipe.
     */
    readonly owner: pulumi.Output<string>;
    /**
     * Platform of the image recipe.
     */
    readonly parentImage: pulumi.Output<string>;
    /**
     * Platform of the image recipe.
     */
    readonly platform: pulumi.Output<string>;
    /**
     * Key-value map of resource tags for the image recipe.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Version of the image recipe.
     */
    readonly version: pulumi.Output<string>;
    /**
     * The working directory to be used during build and test workflows.
     */
    readonly workingDirectory: pulumi.Output<string | undefined>;
    /**
     * Create a ImageRecipe resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ImageRecipeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ImageRecipe resources.
 */
export interface ImageRecipeState {
    /**
     * (Required) Amazon Resource Name (ARN) of the image recipe.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Configuration block(s) with block device mappings for the the image recipe. Detailed below.
     */
    readonly blockDeviceMappings?: pulumi.Input<pulumi.Input<inputs.imagebuilder.ImageRecipeBlockDeviceMapping>[]>;
    /**
     * Ordered configuration block(s) with components for the image recipe. Detailed below.
     */
    readonly components?: pulumi.Input<pulumi.Input<inputs.imagebuilder.ImageRecipeComponent>[]>;
    /**
     * Date the image recipe was created.
     */
    readonly dateCreated?: pulumi.Input<string>;
    /**
     * Description of the image recipe.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Name of the image recipe.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Owner of the image recipe.
     */
    readonly owner?: pulumi.Input<string>;
    /**
     * Platform of the image recipe.
     */
    readonly parentImage?: pulumi.Input<string>;
    /**
     * Platform of the image recipe.
     */
    readonly platform?: pulumi.Input<string>;
    /**
     * Key-value map of resource tags for the image recipe.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Version of the image recipe.
     */
    readonly version?: pulumi.Input<string>;
    /**
     * The working directory to be used during build and test workflows.
     */
    readonly workingDirectory?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ImageRecipe resource.
 */
export interface ImageRecipeArgs {
    /**
     * Configuration block(s) with block device mappings for the the image recipe. Detailed below.
     */
    readonly blockDeviceMappings?: pulumi.Input<pulumi.Input<inputs.imagebuilder.ImageRecipeBlockDeviceMapping>[]>;
    /**
     * Ordered configuration block(s) with components for the image recipe. Detailed below.
     */
    readonly components: pulumi.Input<pulumi.Input<inputs.imagebuilder.ImageRecipeComponent>[]>;
    /**
     * Description of the image recipe.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Name of the image recipe.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Platform of the image recipe.
     */
    readonly parentImage: pulumi.Input<string>;
    /**
     * Key-value map of resource tags for the image recipe.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Version of the image recipe.
     */
    readonly version: pulumi.Input<string>;
    /**
     * The working directory to be used during build and test workflows.
     */
    readonly workingDirectory?: pulumi.Input<string>;
}
