import * as pulumi from "@pulumi/pulumi";
import { ARN } from "..";
import { Policy } from "./index";
/**
 * Provides an IoT policy attachment.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * import * from "fs";
 *
 * const pubsub = new aws.iot.Policy("pubsub", {policy: `{
 *   "Version": "2012-10-17",
 *   "Statement": [
 *     {
 *       "Action": [
 *         "iot:*"
 *       ],
 *       "Effect": "Allow",
 *       "Resource": "*"
 *     }
 *   ]
 * }
 * `});
 * const cert = new aws.iot.Certificate("cert", {
 *     csr: fs.readFileSync("csr.pem"),
 *     active: true,
 * });
 * const att = new aws.iot.PolicyAttachment("att", {
 *     policy: pubsub.name,
 *     target: cert.arn,
 * });
 * ```
 */
export declare class PolicyAttachment extends pulumi.CustomResource {
    /**
     * Get an existing PolicyAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: PolicyAttachmentState, opts?: pulumi.CustomResourceOptions): PolicyAttachment;
    /**
     * Returns true if the given object is an instance of PolicyAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PolicyAttachment;
    /**
     * The name of the policy to attach.
     */
    readonly policy: pulumi.Output<string>;
    /**
     * The identity to which the policy is attached.
     */
    readonly target: pulumi.Output<ARN>;
    /**
     * Create a PolicyAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PolicyAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering PolicyAttachment resources.
 */
export interface PolicyAttachmentState {
    /**
     * The name of the policy to attach.
     */
    readonly policy?: pulumi.Input<string | Policy>;
    /**
     * The identity to which the policy is attached.
     */
    readonly target?: pulumi.Input<ARN>;
}
/**
 * The set of arguments for constructing a PolicyAttachment resource.
 */
export interface PolicyAttachmentArgs {
    /**
     * The name of the policy to attach.
     */
    readonly policy: pulumi.Input<string | Policy>;
    /**
     * The identity to which the policy is attached.
     */
    readonly target: pulumi.Input<ARN>;
}
