import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Creates a Lambda function alias. Creates an alias that points to the specified Lambda function version.
 *
 * For information about Lambda and how to use it, see [What is AWS Lambda?](http://docs.aws.amazon.com/lambda/latest/dg/welcome.html)
 * For information about function aliases, see [CreateAlias](http://docs.aws.amazon.com/lambda/latest/dg/API_CreateAlias.html) and [AliasRoutingConfiguration](https://docs.aws.amazon.com/lambda/latest/dg/API_AliasRoutingConfiguration.html) in the API docs.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const testLambdaAlias = new aws.lambda.Alias("testLambdaAlias", {
 *     description: "a sample description",
 *     functionName: aws_lambda_function.lambda_function_test.arn,
 *     functionVersion: "1",
 *     routingConfig: {
 *         additionalVersionWeights: {
 *             "2": 0.5,
 *         },
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Lambda Function Aliases can be imported using the `function_name/alias`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:lambda/alias:Alias test_lambda_alias my_test_lambda_function/my_alias
 * ```
 */
export declare class Alias extends pulumi.CustomResource {
    /**
     * Get an existing Alias resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AliasState, opts?: pulumi.CustomResourceOptions): Alias;
    /**
     * Returns true if the given object is an instance of Alias.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Alias;
    /**
     * The Amazon Resource Name (ARN) identifying your Lambda function alias.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Description of the alias.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Lambda Function name or ARN.
     */
    readonly functionName: pulumi.Output<string>;
    /**
     * Lambda function version for which you are creating the alias. Pattern: `(\$LATEST|[0-9]+)`.
     */
    readonly functionVersion: pulumi.Output<string>;
    /**
     * The ARN to be used for invoking Lambda Function from API Gateway - to be used in `aws.apigateway.Integration`'s `uri`
     */
    readonly invokeArn: pulumi.Output<string>;
    /**
     * Name for the alias you are creating. Pattern: `(?!^[0-9]+$)([a-zA-Z0-9-_]+)`
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Lambda alias' route configuration settings. Fields documented below
     */
    readonly routingConfig: pulumi.Output<outputs.lambda.AliasRoutingConfig | undefined>;
    /**
     * Create a Alias resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AliasArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Alias resources.
 */
export interface AliasState {
    /**
     * The Amazon Resource Name (ARN) identifying your Lambda function alias.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Description of the alias.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Lambda Function name or ARN.
     */
    readonly functionName?: pulumi.Input<string>;
    /**
     * Lambda function version for which you are creating the alias. Pattern: `(\$LATEST|[0-9]+)`.
     */
    readonly functionVersion?: pulumi.Input<string>;
    /**
     * The ARN to be used for invoking Lambda Function from API Gateway - to be used in `aws.apigateway.Integration`'s `uri`
     */
    readonly invokeArn?: pulumi.Input<string>;
    /**
     * Name for the alias you are creating. Pattern: `(?!^[0-9]+$)([a-zA-Z0-9-_]+)`
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The Lambda alias' route configuration settings. Fields documented below
     */
    readonly routingConfig?: pulumi.Input<inputs.lambda.AliasRoutingConfig>;
}
/**
 * The set of arguments for constructing a Alias resource.
 */
export interface AliasArgs {
    /**
     * Description of the alias.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Lambda Function name or ARN.
     */
    readonly functionName: pulumi.Input<string>;
    /**
     * Lambda function version for which you are creating the alias. Pattern: `(\$LATEST|[0-9]+)`.
     */
    readonly functionVersion: pulumi.Input<string>;
    /**
     * Name for the alias you are creating. Pattern: `(?!^[0-9]+$)([a-zA-Z0-9-_]+)`
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The Lambda alias' route configuration settings. Fields documented below
     */
    readonly routingConfig?: pulumi.Input<inputs.lambda.AliasRoutingConfig>;
}
