import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * > **NOTE:** This resource interacts with [Amazon Macie Classic](https://docs.aws.amazon.com/macie/latest/userguide/what-is-macie.html). Macie Classic cannot be activated in new accounts. See the [FAQ](https://aws.amazon.com/macie/classic-faqs/) for more details.
 *
 * Associates an S3 resource with Amazon Macie for monitoring and data classification.
 *
 * > **NOTE:** Before using Amazon Macie for the first time it must be enabled manually. Instructions are [here](https://docs.aws.amazon.com/macie/latest/userguide/macie-setting-up.html#macie-setting-up-enable).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.macie.S3BucketAssociation("example", {
 *     bucketName: "tf-macie-example",
 *     classificationType: {
 *         oneTime: "FULL",
 *     },
 *     prefix: "data",
 * });
 * ```
 */
export declare class S3BucketAssociation extends pulumi.CustomResource {
    /**
     * Get an existing S3BucketAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: S3BucketAssociationState, opts?: pulumi.CustomResourceOptions): S3BucketAssociation;
    /**
     * Returns true if the given object is an instance of S3BucketAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is S3BucketAssociation;
    /**
     * The name of the S3 bucket that you want to associate with Amazon Macie.
     */
    readonly bucketName: pulumi.Output<string>;
    /**
     * The configuration of how Amazon Macie classifies the S3 objects.
     */
    readonly classificationType: pulumi.Output<outputs.macie.S3BucketAssociationClassificationType>;
    /**
     * The ID of the Amazon Macie member account whose S3 resources you want to associate with Macie. If `memberAccountId` isn't specified, the action associates specified S3 resources with Macie for the current master account.
     */
    readonly memberAccountId: pulumi.Output<string | undefined>;
    /**
     * Object key prefix identifying one or more S3 objects to which the association applies.
     */
    readonly prefix: pulumi.Output<string | undefined>;
    /**
     * Create a S3BucketAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: S3BucketAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering S3BucketAssociation resources.
 */
export interface S3BucketAssociationState {
    /**
     * The name of the S3 bucket that you want to associate with Amazon Macie.
     */
    readonly bucketName?: pulumi.Input<string>;
    /**
     * The configuration of how Amazon Macie classifies the S3 objects.
     */
    readonly classificationType?: pulumi.Input<inputs.macie.S3BucketAssociationClassificationType>;
    /**
     * The ID of the Amazon Macie member account whose S3 resources you want to associate with Macie. If `memberAccountId` isn't specified, the action associates specified S3 resources with Macie for the current master account.
     */
    readonly memberAccountId?: pulumi.Input<string>;
    /**
     * Object key prefix identifying one or more S3 objects to which the association applies.
     */
    readonly prefix?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a S3BucketAssociation resource.
 */
export interface S3BucketAssociationArgs {
    /**
     * The name of the S3 bucket that you want to associate with Amazon Macie.
     */
    readonly bucketName: pulumi.Input<string>;
    /**
     * The configuration of how Amazon Macie classifies the S3 objects.
     */
    readonly classificationType?: pulumi.Input<inputs.macie.S3BucketAssociationClassificationType>;
    /**
     * The ID of the Amazon Macie member account whose S3 resources you want to associate with Macie. If `memberAccountId` isn't specified, the action associates specified S3 resources with Macie for the current master account.
     */
    readonly memberAccountId?: pulumi.Input<string>;
    /**
     * Object key prefix identifying one or more S3 objects to which the association applies.
     */
    readonly prefix?: pulumi.Input<string>;
}
