import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an MQ Configuration Resource.
 *
 * For more information on Amazon MQ, see [Amazon MQ documentation](https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/welcome.html).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.mq.Configuration("example", {
 *     data: `<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 * <broker xmlns="http://activemq.apache.org/schema/core">
 *   <plugins>
 *     <forcePersistencyModeBrokerPlugin persistenceFlag="true"/>
 *     <statisticsBrokerPlugin/>
 *     <timeStampingBrokerPlugin ttlCeiling="86400000" zeroExpirationOverride="86400000"/>
 *   </plugins>
 * </broker>
 * `,
 *     description: "Example Configuration",
 *     engineType: "ActiveMQ",
 *     engineVersion: "5.15.0",
 * });
 * ```
 *
 * ## Import
 *
 * MQ Configurations can be imported using the configuration ID, e.g.
 *
 * ```sh
 *  $ pulumi import aws:mq/configuration:Configuration example c-0187d1eb-88c8-475a-9b79-16ef5a10c94f
 * ```
 */
export declare class Configuration extends pulumi.CustomResource {
    /**
     * Get an existing Configuration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ConfigurationState, opts?: pulumi.CustomResourceOptions): Configuration;
    /**
     * Returns true if the given object is an instance of Configuration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Configuration;
    /**
     * The ARN of the configuration.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The broker configuration in XML format.
     * See [official docs](https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/amazon-mq-broker-configuration-parameters.html)
     * for supported parameters and format of the XML.
     */
    readonly data: pulumi.Output<string>;
    /**
     * The description of the configuration.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The type of broker engine.
     */
    readonly engineType: pulumi.Output<string>;
    /**
     * The version of the broker engine.
     */
    readonly engineVersion: pulumi.Output<string>;
    /**
     * The latest revision of the configuration.
     */
    readonly latestRevision: pulumi.Output<number>;
    /**
     * The name of the configuration
     */
    readonly name: pulumi.Output<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Configuration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Configuration resources.
 */
export interface ConfigurationState {
    /**
     * The ARN of the configuration.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The broker configuration in XML format.
     * See [official docs](https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/amazon-mq-broker-configuration-parameters.html)
     * for supported parameters and format of the XML.
     */
    readonly data?: pulumi.Input<string>;
    /**
     * The description of the configuration.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The type of broker engine.
     */
    readonly engineType?: pulumi.Input<string>;
    /**
     * The version of the broker engine.
     */
    readonly engineVersion?: pulumi.Input<string>;
    /**
     * The latest revision of the configuration.
     */
    readonly latestRevision?: pulumi.Input<number>;
    /**
     * The name of the configuration
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a Configuration resource.
 */
export interface ConfigurationArgs {
    /**
     * The broker configuration in XML format.
     * See [official docs](https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/amazon-mq-broker-configuration-parameters.html)
     * for supported parameters and format of the XML.
     */
    readonly data: pulumi.Input<string>;
    /**
     * The description of the configuration.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The type of broker engine.
     */
    readonly engineType: pulumi.Input<string>;
    /**
     * The version of the broker engine.
     */
    readonly engineVersion: pulumi.Input<string>;
    /**
     * The name of the configuration
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
