import * as pulumi from "@pulumi/pulumi";
/**
 * Manages an Amazon Managed Streaming for Kafka configuration. More information can be found on the [MSK Developer Guide](https://docs.aws.amazon.com/msk/latest/developerguide/msk-configuration.html).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.msk.Configuration("example", {
 *     kafkaVersions: ["2.1.0"],
 *     serverProperties: `auto.create.topics.enable = true
 * delete.topic.enable = true
 * `,
 * });
 * ```
 *
 * ## Import
 *
 * MSK configurations can be imported using the configuration ARN, e.g.
 *
 * ```sh
 *  $ pulumi import aws:msk/configuration:Configuration example arn:aws:kafka:us-west-2:123456789012:configuration/example/279c0212-d057-4dba-9aa9-1c4e5a25bfc7-3
 * ```
 */
export declare class Configuration extends pulumi.CustomResource {
    /**
     * Get an existing Configuration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ConfigurationState, opts?: pulumi.CustomResourceOptions): Configuration;
    /**
     * Returns true if the given object is an instance of Configuration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Configuration;
    /**
     * Amazon Resource Name (ARN) of the configuration.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Description of the configuration.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * List of Apache Kafka versions which can use this configuration.
     */
    readonly kafkaVersions: pulumi.Output<string[]>;
    /**
     * Latest revision of the configuration.
     */
    readonly latestRevision: pulumi.Output<number>;
    /**
     * Name of the configuration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Contents of the server.properties file. Supported properties are documented in the [MSK Developer Guide](https://docs.aws.amazon.com/msk/latest/developerguide/msk-configuration-properties.html).
     */
    readonly serverProperties: pulumi.Output<string>;
    /**
     * Create a Configuration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Configuration resources.
 */
export interface ConfigurationState {
    /**
     * Amazon Resource Name (ARN) of the configuration.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Description of the configuration.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * List of Apache Kafka versions which can use this configuration.
     */
    readonly kafkaVersions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Latest revision of the configuration.
     */
    readonly latestRevision?: pulumi.Input<number>;
    /**
     * Name of the configuration.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Contents of the server.properties file. Supported properties are documented in the [MSK Developer Guide](https://docs.aws.amazon.com/msk/latest/developerguide/msk-configuration-properties.html).
     */
    readonly serverProperties?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Configuration resource.
 */
export interface ConfigurationArgs {
    /**
     * Description of the configuration.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * List of Apache Kafka versions which can use this configuration.
     */
    readonly kafkaVersions: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Name of the configuration.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Contents of the server.properties file. Supported properties are documented in the [MSK Developer Guide](https://docs.aws.amazon.com/msk/latest/developerguide/msk-configuration-properties.html).
     */
    readonly serverProperties: pulumi.Input<string>;
}
