import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Manages a Neptune Parameter Group
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.neptune.ParameterGroup("example", {
 *     family: "neptune1",
 *     parameters: [{
 *         name: "neptune_query_timeout",
 *         value: "25",
 *     }],
 * });
 * ```
 *
 * ## Import
 *
 * Neptune Parameter Groups can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:neptune/parameterGroup:ParameterGroup some_pg some-pg
 * ```
 */
export declare class ParameterGroup extends pulumi.CustomResource {
    /**
     * Get an existing ParameterGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ParameterGroupState, opts?: pulumi.CustomResourceOptions): ParameterGroup;
    /**
     * Returns true if the given object is an instance of ParameterGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ParameterGroup;
    /**
     * The Neptune parameter group Amazon Resource Name (ARN).
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description of the Neptune parameter group. Defaults to "Managed by Pulumi".
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The family of the Neptune parameter group.
     */
    readonly family: pulumi.Output<string>;
    /**
     * The name of the Neptune parameter.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of Neptune parameters to apply.
     */
    readonly parameters: pulumi.Output<outputs.neptune.ParameterGroupParameter[] | undefined>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a ParameterGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ParameterGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ParameterGroup resources.
 */
export interface ParameterGroupState {
    /**
     * The Neptune parameter group Amazon Resource Name (ARN).
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The description of the Neptune parameter group. Defaults to "Managed by Pulumi".
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The family of the Neptune parameter group.
     */
    readonly family?: pulumi.Input<string>;
    /**
     * The name of the Neptune parameter.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A list of Neptune parameters to apply.
     */
    readonly parameters?: pulumi.Input<pulumi.Input<inputs.neptune.ParameterGroupParameter>[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a ParameterGroup resource.
 */
export interface ParameterGroupArgs {
    /**
     * The description of the Neptune parameter group. Defaults to "Managed by Pulumi".
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The family of the Neptune parameter group.
     */
    readonly family: pulumi.Input<string>;
    /**
     * The name of the Neptune parameter.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A list of Neptune parameters to apply.
     */
    readonly parameters?: pulumi.Input<pulumi.Input<inputs.neptune.ParameterGroupParameter>[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
