import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an AWS Network Firewall Firewall Resource
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.networkfirewall.Firewall("example", {
 *     firewallPolicyArn: aws_networkfirewall_firewall_policy.example.arn,
 *     vpcId: aws_vpc.example.id,
 *     subnetMappings: [{
 *         subnetId: aws_subnet.example.id,
 *     }],
 *     tags: {
 *         Tag1: "Value1",
 *         Tag2: "Value2",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Network Firewall Firewalls can be imported using their `ARN`.
 *
 * ```sh
 *  $ pulumi import aws:networkfirewall/firewall:Firewall example arn:aws:network-firewall:us-west-1:123456789012:firewall/example
 * ```
 */
export declare class Firewall extends pulumi.CustomResource {
    /**
     * Get an existing Firewall resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: FirewallState, opts?: pulumi.CustomResourceOptions): Firewall;
    /**
     * Returns true if the given object is an instance of Firewall.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Firewall;
    /**
     * The Amazon Resource Name (ARN) that identifies the firewall.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A boolean flag indicating whether it is possible to delete the firewall. Defaults to `false`.
     */
    readonly deleteProtection: pulumi.Output<boolean | undefined>;
    /**
     * A friendly description of the firewall.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the VPC Firewall policy.
     */
    readonly firewallPolicyArn: pulumi.Output<string>;
    /**
     * A boolean flag indicating whether it is possible to change the associated firewall policy. Defaults to `false`.
     */
    readonly firewallPolicyChangeProtection: pulumi.Output<boolean | undefined>;
    /**
     * Nested list of information about the current status of the firewall.
     */
    readonly firewallStatuses: pulumi.Output<outputs.networkfirewall.FirewallFirewallStatus[]>;
    /**
     * A friendly name of the firewall.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A boolean flag indicating whether it is possible to change the associated subnet(s). Defaults to `false`.
     */
    readonly subnetChangeProtection: pulumi.Output<boolean | undefined>;
    /**
     * Set of configuration blocks describing the public subnets. Each subnet must belong to a different Availability Zone in the VPC. AWS Network Firewall creates a firewall endpoint in each subnet. See Subnet Mapping below for details.
     */
    readonly subnetMappings: pulumi.Output<outputs.networkfirewall.FirewallSubnetMapping[]>;
    /**
     * The key:value pairs to associate with the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A string token used when updating a firewall.
     */
    readonly updateToken: pulumi.Output<string>;
    /**
     * The unique identifier of the VPC where AWS Network Firewall should create the firewall.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a Firewall resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FirewallArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Firewall resources.
 */
export interface FirewallState {
    /**
     * The Amazon Resource Name (ARN) that identifies the firewall.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * A boolean flag indicating whether it is possible to delete the firewall. Defaults to `false`.
     */
    readonly deleteProtection?: pulumi.Input<boolean>;
    /**
     * A friendly description of the firewall.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the VPC Firewall policy.
     */
    readonly firewallPolicyArn?: pulumi.Input<string>;
    /**
     * A boolean flag indicating whether it is possible to change the associated firewall policy. Defaults to `false`.
     */
    readonly firewallPolicyChangeProtection?: pulumi.Input<boolean>;
    /**
     * Nested list of information about the current status of the firewall.
     */
    readonly firewallStatuses?: pulumi.Input<pulumi.Input<inputs.networkfirewall.FirewallFirewallStatus>[]>;
    /**
     * A friendly name of the firewall.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A boolean flag indicating whether it is possible to change the associated subnet(s). Defaults to `false`.
     */
    readonly subnetChangeProtection?: pulumi.Input<boolean>;
    /**
     * Set of configuration blocks describing the public subnets. Each subnet must belong to a different Availability Zone in the VPC. AWS Network Firewall creates a firewall endpoint in each subnet. See Subnet Mapping below for details.
     */
    readonly subnetMappings?: pulumi.Input<pulumi.Input<inputs.networkfirewall.FirewallSubnetMapping>[]>;
    /**
     * The key:value pairs to associate with the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A string token used when updating a firewall.
     */
    readonly updateToken?: pulumi.Input<string>;
    /**
     * The unique identifier of the VPC where AWS Network Firewall should create the firewall.
     */
    readonly vpcId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Firewall resource.
 */
export interface FirewallArgs {
    /**
     * A boolean flag indicating whether it is possible to delete the firewall. Defaults to `false`.
     */
    readonly deleteProtection?: pulumi.Input<boolean>;
    /**
     * A friendly description of the firewall.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the VPC Firewall policy.
     */
    readonly firewallPolicyArn: pulumi.Input<string>;
    /**
     * A boolean flag indicating whether it is possible to change the associated firewall policy. Defaults to `false`.
     */
    readonly firewallPolicyChangeProtection?: pulumi.Input<boolean>;
    /**
     * A friendly name of the firewall.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A boolean flag indicating whether it is possible to change the associated subnet(s). Defaults to `false`.
     */
    readonly subnetChangeProtection?: pulumi.Input<boolean>;
    /**
     * Set of configuration blocks describing the public subnets. Each subnet must belong to a different Availability Zone in the VPC. AWS Network Firewall creates a firewall endpoint in each subnet. See Subnet Mapping below for details.
     */
    readonly subnetMappings: pulumi.Input<pulumi.Input<inputs.networkfirewall.FirewallSubnetMapping>[]>;
    /**
     * The key:value pairs to associate with the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The unique identifier of the VPC where AWS Network Firewall should create the firewall.
     */
    readonly vpcId: pulumi.Input<string>;
}
