import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs, enums } from "../types";
/**
 * Provides an RDS instance resource.  A DB instance is an isolated database
 * environment in the cloud.  A DB instance can contain multiple user-created
 * databases.
 *
 * Changes to a DB instance can occur when you manually change a parameter, such as
 * `allocatedStorage`, and are reflected in the next maintenance window. Because
 * of this, this provider may report a difference in its planning phase because a
 * modification has not yet taken place. You can use the `applyImmediately` flag
 * to instruct the service to apply the change immediately (see documentation
 * below).
 *
 * When upgrading the major version of an engine, `allowMajorVersionUpgrade`
 * must be set to `true`.
 *
 * > **Note:** using `applyImmediately` can result in a brief downtime as the
 * server reboots. See the AWS Docs on [RDS Maintenance][2] for more information.
 *
 * ## RDS Instance Class Types
 *
 * Amazon RDS supports three types of instance classes: Standard, Memory Optimized,
 * and Burstable Performance. For more information please read the AWS RDS documentation
 * about [DB Instance Class Types](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.DBInstanceClass.html)
 *
 * ## Example Usage
 * ### Basic Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const defaultInstance = new aws.rds.Instance("default", {
 *     allocatedStorage: 10,
 *     engine: "mysql",
 *     engineVersion: "5.7",
 *     instanceClass: "db.t3.micro",
 *     name: "mydb",
 *     parameterGroupName: "default.mysql5.7",
 *     password: "foobarbaz",
 *     skipFinalSnapshot: true,
 *     username: "foo",
 * });
 * ```
 * ### Storage Autoscaling
 *
 * To enable Storage Autoscaling with instances that support the feature, define the `maxAllocatedStorage` argument higher than the `allocatedStorage` argument. This provider will automatically hide differences with the `allocatedStorage` argument value if autoscaling occurs.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.rds.Instance("example", {
 *     allocatedStorage: 50,
 *     maxAllocatedStorage: 100,
 * });
 * ```
 *
 * ## Import
 *
 * DB Instances can be imported using the `identifier`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:rds/instance:Instance default mydb-rds-instance
 * ```
 */
export declare class Instance extends pulumi.CustomResource {
    /**
     * Get an existing Instance resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: InstanceState, opts?: pulumi.CustomResourceOptions): Instance;
    /**
     * Returns true if the given object is an instance of Instance.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Instance;
    /**
     * The hostname of the RDS instance. See also `endpoint` and `port`.
     */
    readonly address: pulumi.Output<string>;
    /**
     * The allocated storage in gibibytes. If `maxAllocatedStorage` is configured, this argument represents the initial storage allocation and differences from the configuration will be ignored automatically when Storage Autoscaling occurs.
     */
    readonly allocatedStorage: pulumi.Output<number>;
    /**
     * Indicates that major version
     * upgrades are allowed. Changing this parameter does not result in an outage and
     * the change is asynchronously applied as soon as possible.
     */
    readonly allowMajorVersionUpgrade: pulumi.Output<boolean | undefined>;
    /**
     * Specifies whether any database modifications
     * are applied immediately, or during the next maintenance window. Default is
     * `false`. See [Amazon RDS Documentation for more
     * information.](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBInstance.Modifying.html)
     */
    readonly applyImmediately: pulumi.Output<boolean>;
    /**
     * The ARN of the RDS instance.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Indicates that minor engine upgrades
     * will be applied automatically to the DB instance during the maintenance window.
     * Defaults to true.
     */
    readonly autoMinorVersionUpgrade: pulumi.Output<boolean | undefined>;
    /**
     * The AZ for the RDS instance.
     */
    readonly availabilityZone: pulumi.Output<string>;
    /**
     * The days to retain backups for. Must be
     * between `0` and `35`. Must be greater than `0` if the database is used as a source for a Read Replica. [See Read Replica][1].
     */
    readonly backupRetentionPeriod: pulumi.Output<number>;
    /**
     * The daily time range (in UTC) during which
     * automated backups are created if they are enabled. Example: "09:46-10:16". Must
     * not overlap with `maintenanceWindow`.
     */
    readonly backupWindow: pulumi.Output<string>;
    /**
     * The identifier of the CA certificate for the DB instance.
     */
    readonly caCertIdentifier: pulumi.Output<string>;
    /**
     * The character set name to use for DB
     * encoding in Oracle and Microsoft SQL instances (collation). This can't be changed. See [Oracle Character Sets
     * Supported in Amazon RDS](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Appendix.OracleCharacterSets.html)
     * or [Server-Level Collation for Microsoft SQL Server](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Appendix.SQLServer.CommonDBATasks.Collation.html) for more information.
     */
    readonly characterSetName: pulumi.Output<string>;
    /**
     * Copy all Instance `tags` to snapshots. Default is `false`.
     */
    readonly copyTagsToSnapshot: pulumi.Output<boolean | undefined>;
    /**
     * Name of `DB subnet group`. DB instance will
     * be created in the VPC associated with the DB subnet group. If unspecified, will
     * be created in the `default` VPC, or in EC2 Classic, if available. When working
     * with read replicas, it should be specified only if the source database
     * specifies an instance in another AWS Region. See [DBSubnetGroupName in API
     * action CreateDBInstanceReadReplica](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstanceReadReplica.html)
     * for additional read replica contraints.
     */
    readonly dbSubnetGroupName: pulumi.Output<string>;
    /**
     * Specifies whether to remove automated backups immediately after the DB instance is deleted. Default is `true`.
     */
    readonly deleteAutomatedBackups: pulumi.Output<boolean | undefined>;
    /**
     * If the DB instance should have deletion protection enabled. The database can't be deleted when this value is set to `true`. The default is `false`.
     */
    readonly deletionProtection: pulumi.Output<boolean | undefined>;
    /**
     * The ID of the Directory Service Active Directory domain to create the instance in.
     */
    readonly domain: pulumi.Output<string | undefined>;
    /**
     * The name of the IAM role to be used when making API calls to the Directory Service.
     */
    readonly domainIamRoleName: pulumi.Output<string | undefined>;
    /**
     * Set of log types to enable for exporting to CloudWatch logs. If omitted, no logs will be exported. Valid values (depending on `engine`). MySQL and MariaDB: `audit`, `error`, `general`, `slowquery`. PostgreSQL: `postgresql`, `upgrade`. MSSQL: `agent` , `error`. Oracle: `alert`, `audit`, `listener`, `trace`.
     */
    readonly enabledCloudwatchLogsExports: pulumi.Output<string[] | undefined>;
    /**
     * The connection endpoint in `address:port` format.
     */
    readonly endpoint: pulumi.Output<string>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) The database engine to use.  For supported values, see the Engine parameter in [API action CreateDBInstance](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html).
     * Note that for Amazon Aurora instances the engine must match the `DB cluster`'s engine'.
     * For information on the difference between the available Aurora MySQL engines
     * see [Comparison between Aurora MySQL 1 and Aurora MySQL 2](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/AuroraMySQL.Updates.20180206.html)
     * in the Amazon RDS User Guide.
     */
    readonly engine: pulumi.Output<string>;
    /**
     * The engine version to use. If `autoMinorVersionUpgrade`
     * is enabled, you can provide a prefix of the version such as `5.7` (for `5.7.10`) and
     * this attribute will ignore differences in the patch version automatically (e.g. `5.7.17`).
     * For supported values, see the EngineVersion parameter in [API action CreateDBInstance](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html).
     * Note that for Amazon Aurora instances the engine version must match the `DB cluster`'s engine version'.
     */
    readonly engineVersion: pulumi.Output<string>;
    /**
     * The name of your final DB snapshot
     * when this DB instance is deleted. Must be provided if `skipFinalSnapshot` is
     * set to `false`. The value must begin with a letter, only contain alphanumeric characters and hyphens, and not end with a hyphen or contain two consecutive hyphens. Must not be provided when deleting a read replica.
     */
    readonly finalSnapshotIdentifier: pulumi.Output<string | undefined>;
    /**
     * The canonical hosted zone ID of the DB instance (to be used
     * in a Route 53 Alias record).
     */
    readonly hostedZoneId: pulumi.Output<string>;
    /**
     * Specifies whether or
     * mappings of AWS Identity and Access Management (IAM) accounts to database
     * accounts is enabled.
     */
    readonly iamDatabaseAuthenticationEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The name of the RDS instance,
     * if omitted, this provider will assign a random, unique identifier.
     */
    readonly identifier: pulumi.Output<string>;
    /**
     * Creates a unique
     * identifier beginning with the specified prefix. Conflicts with `identifier`.
     */
    readonly identifierPrefix: pulumi.Output<string>;
    /**
     * The instance type of the RDS instance.
     */
    readonly instanceClass: pulumi.Output<string>;
    /**
     * The amount of provisioned IOPS. Setting this implies a
     * storageType of "io1".
     */
    readonly iops: pulumi.Output<number | undefined>;
    /**
     * The ARN for the KMS encryption key. If creating an
     * encrypted replica, set this to the destination KMS ARN.
     */
    readonly kmsKeyId: pulumi.Output<string>;
    /**
     * The latest time, in UTC [RFC3339 format](https://tools.ietf.org/html/rfc3339#section-5.8), to which a database can be restored with point-in-time restore.
     */
    readonly latestRestorableTime: pulumi.Output<string>;
    /**
     * (Optional, but required for some DB engines, i.e. Oracle
     * SE1) License model information for this DB instance.
     */
    readonly licenseModel: pulumi.Output<string>;
    /**
     * The window to perform maintenance in.
     * Syntax: "ddd:hh24:mi-ddd:hh24:mi". Eg: "Mon:00:00-Mon:03:00". See [RDS
     * Maintenance Window
     * docs](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_UpgradeDBInstance.Maintenance.html#AdjustingTheMaintenanceWindow)
     * for more information.
     */
    readonly maintenanceWindow: pulumi.Output<string>;
    /**
     * When configured, the upper limit to which Amazon RDS can automatically scale the storage of the DB instance. Configuring this will automatically ignore differences to `allocatedStorage`. Must be greater than or equal to `allocatedStorage` or `0` to disable Storage Autoscaling.
     */
    readonly maxAllocatedStorage: pulumi.Output<number | undefined>;
    /**
     * The interval, in seconds, between points
     * when Enhanced Monitoring metrics are collected for the DB instance. To disable
     * collecting Enhanced Monitoring metrics, specify 0. The default is 0. Valid
     * Values: 0, 1, 5, 10, 15, 30, 60.
     */
    readonly monitoringInterval: pulumi.Output<number | undefined>;
    /**
     * The ARN for the IAM role that permits RDS
     * to send enhanced monitoring metrics to CloudWatch Logs. You can find more
     * information on the [AWS
     * Documentation](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Monitoring.html)
     * what IAM permissions are needed to allow Enhanced Monitoring for RDS Instances.
     */
    readonly monitoringRoleArn: pulumi.Output<string>;
    /**
     * Specifies if the RDS instance is multi-AZ
     */
    readonly multiAz: pulumi.Output<boolean>;
    /**
     * The name of the database to create when the DB instance is created. If this parameter is not specified, no database is created in the DB instance. Note that this does not apply for Oracle or SQL Server engines. See the [AWS documentation](http://docs.aws.amazon.com/cli/latest/reference/rds/create-db-instance.html) for more details on what applies for those engines.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Name of the DB option group to associate.
     */
    readonly optionGroupName: pulumi.Output<string>;
    /**
     * Name of the DB parameter group to
     * associate.
     */
    readonly parameterGroupName: pulumi.Output<string>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) Password for the master DB user. Note that this may show up in
     * logs, and it will be stored in the state file.
     */
    readonly password: pulumi.Output<string | undefined>;
    /**
     * Specifies whether Performance Insights are enabled. Defaults to false.
     */
    readonly performanceInsightsEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The ARN for the KMS key to encrypt Performance Insights data. When specifying `performanceInsightsKmsKeyId`, `performanceInsightsEnabled` needs to be set to true. Once KMS key is set, it can never be changed.
     */
    readonly performanceInsightsKmsKeyId: pulumi.Output<string>;
    /**
     * The amount of time in days to retain Performance Insights data. Either 7 (7 days) or 731 (2 years). When specifying `performanceInsightsRetentionPeriod`, `performanceInsightsEnabled` needs to be set to true. Defaults to '7'.
     */
    readonly performanceInsightsRetentionPeriod: pulumi.Output<number>;
    /**
     * The port on which the DB accepts connections.
     */
    readonly port: pulumi.Output<number>;
    /**
     * Bool to control if instance is publicly
     * accessible. Default is `false`.
     */
    readonly publiclyAccessible: pulumi.Output<boolean | undefined>;
    readonly replicas: pulumi.Output<string[]>;
    /**
     * Specifies that this resource is a Replicate
     * database, and to use this value as the source database. This correlates to the
     * `identifier` of another Amazon RDS Database to replicate (if replicating within
     * a single region) or ARN of the Amazon RDS Database to replicate (if replicating
     * cross-region). Note that if you are
     * creating a cross-region replica of an encrypted database you will also need to
     * specify a `kmsKeyId`. See [DB Instance Replication][1] and [Working with
     * PostgreSQL and MySQL Read Replicas](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ReadRepl.html)
     * for more information on using Replication.
     */
    readonly replicateSourceDb: pulumi.Output<string | undefined>;
    /**
     * The RDS Resource ID of this instance.
     */
    readonly resourceId: pulumi.Output<string>;
    /**
     * A configuration block for restoring a DB instance to an arbitrary point in time. Requires the `identifier` argument to be set with the name of the new DB instance to be created. See Restore To Point In Time below for details.
     */
    readonly restoreToPointInTime: pulumi.Output<outputs.rds.InstanceRestoreToPointInTime | undefined>;
    /**
     * Restore from a Percona Xtrabackup in S3.  See [Importing Data into an Amazon RDS MySQL DB Instance](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/MySQL.Procedural.Importing.html)
     */
    readonly s3Import: pulumi.Output<outputs.rds.InstanceS3Import | undefined>;
    /**
     * List of DB Security Groups to
     * associate. Only used for [DB Instances on the _EC2-Classic_
     * Platform](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.html#USER_VPC.FindDefaultVPC).
     */
    readonly securityGroupNames: pulumi.Output<string[] | undefined>;
    /**
     * Determines whether a final DB snapshot is
     * created before the DB instance is deleted. If true is specified, no DBSnapshot
     * is created. If false is specified, a DB snapshot is created before the DB
     * instance is deleted, using the value from `finalSnapshotIdentifier`. Default
     * is `false`.
     */
    readonly skipFinalSnapshot: pulumi.Output<boolean | undefined>;
    /**
     * Specifies whether or not to create this
     * database from a snapshot. This correlates to the snapshot ID you'd find in the
     * RDS console, e.g: rds:production-2015-06-26-06-05.
     */
    readonly snapshotIdentifier: pulumi.Output<string>;
    /**
     * The RDS instance status.
     */
    readonly status: pulumi.Output<string>;
    /**
     * Specifies whether the DB instance is
     * encrypted. Note that if you are creating a cross-region read replica this field
     * is ignored and you should instead declare `kmsKeyId` with a valid ARN. The
     * default is `false` if not specified.
     */
    readonly storageEncrypted: pulumi.Output<boolean | undefined>;
    /**
     * One of "standard" (magnetic), "gp2" (general
     * purpose SSD), or "io1" (provisioned IOPS SSD). The default is "io1" if `iops` is
     * specified, "gp2" if not.
     */
    readonly storageType: pulumi.Output<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Time zone of the DB instance. `timezone` is currently
     * only supported by Microsoft SQL Server. The `timezone` can only be set on
     * creation. See [MSSQL User
     * Guide](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_SQLServer.html#SQLServer.Concepts.General.TimeZone)
     * for more information.
     */
    readonly timezone: pulumi.Output<string>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) Username for the master DB user.
     */
    readonly username: pulumi.Output<string>;
    /**
     * List of VPC security groups to
     * associate.
     */
    readonly vpcSecurityGroupIds: pulumi.Output<string[]>;
    /**
     * Create a Instance resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: InstanceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Instance resources.
 */
export interface InstanceState {
    /**
     * The hostname of the RDS instance. See also `endpoint` and `port`.
     */
    readonly address?: pulumi.Input<string>;
    /**
     * The allocated storage in gibibytes. If `maxAllocatedStorage` is configured, this argument represents the initial storage allocation and differences from the configuration will be ignored automatically when Storage Autoscaling occurs.
     */
    readonly allocatedStorage?: pulumi.Input<number>;
    /**
     * Indicates that major version
     * upgrades are allowed. Changing this parameter does not result in an outage and
     * the change is asynchronously applied as soon as possible.
     */
    readonly allowMajorVersionUpgrade?: pulumi.Input<boolean>;
    /**
     * Specifies whether any database modifications
     * are applied immediately, or during the next maintenance window. Default is
     * `false`. See [Amazon RDS Documentation for more
     * information.](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBInstance.Modifying.html)
     */
    readonly applyImmediately?: pulumi.Input<boolean>;
    /**
     * The ARN of the RDS instance.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Indicates that minor engine upgrades
     * will be applied automatically to the DB instance during the maintenance window.
     * Defaults to true.
     */
    readonly autoMinorVersionUpgrade?: pulumi.Input<boolean>;
    /**
     * The AZ for the RDS instance.
     */
    readonly availabilityZone?: pulumi.Input<string>;
    /**
     * The days to retain backups for. Must be
     * between `0` and `35`. Must be greater than `0` if the database is used as a source for a Read Replica. [See Read Replica][1].
     */
    readonly backupRetentionPeriod?: pulumi.Input<number>;
    /**
     * The daily time range (in UTC) during which
     * automated backups are created if they are enabled. Example: "09:46-10:16". Must
     * not overlap with `maintenanceWindow`.
     */
    readonly backupWindow?: pulumi.Input<string>;
    /**
     * The identifier of the CA certificate for the DB instance.
     */
    readonly caCertIdentifier?: pulumi.Input<string>;
    /**
     * The character set name to use for DB
     * encoding in Oracle and Microsoft SQL instances (collation). This can't be changed. See [Oracle Character Sets
     * Supported in Amazon RDS](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Appendix.OracleCharacterSets.html)
     * or [Server-Level Collation for Microsoft SQL Server](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Appendix.SQLServer.CommonDBATasks.Collation.html) for more information.
     */
    readonly characterSetName?: pulumi.Input<string>;
    /**
     * Copy all Instance `tags` to snapshots. Default is `false`.
     */
    readonly copyTagsToSnapshot?: pulumi.Input<boolean>;
    /**
     * Name of `DB subnet group`. DB instance will
     * be created in the VPC associated with the DB subnet group. If unspecified, will
     * be created in the `default` VPC, or in EC2 Classic, if available. When working
     * with read replicas, it should be specified only if the source database
     * specifies an instance in another AWS Region. See [DBSubnetGroupName in API
     * action CreateDBInstanceReadReplica](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstanceReadReplica.html)
     * for additional read replica contraints.
     */
    readonly dbSubnetGroupName?: pulumi.Input<string>;
    /**
     * Specifies whether to remove automated backups immediately after the DB instance is deleted. Default is `true`.
     */
    readonly deleteAutomatedBackups?: pulumi.Input<boolean>;
    /**
     * If the DB instance should have deletion protection enabled. The database can't be deleted when this value is set to `true`. The default is `false`.
     */
    readonly deletionProtection?: pulumi.Input<boolean>;
    /**
     * The ID of the Directory Service Active Directory domain to create the instance in.
     */
    readonly domain?: pulumi.Input<string>;
    /**
     * The name of the IAM role to be used when making API calls to the Directory Service.
     */
    readonly domainIamRoleName?: pulumi.Input<string>;
    /**
     * Set of log types to enable for exporting to CloudWatch logs. If omitted, no logs will be exported. Valid values (depending on `engine`). MySQL and MariaDB: `audit`, `error`, `general`, `slowquery`. PostgreSQL: `postgresql`, `upgrade`. MSSQL: `agent` , `error`. Oracle: `alert`, `audit`, `listener`, `trace`.
     */
    readonly enabledCloudwatchLogsExports?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The connection endpoint in `address:port` format.
     */
    readonly endpoint?: pulumi.Input<string>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) The database engine to use.  For supported values, see the Engine parameter in [API action CreateDBInstance](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html).
     * Note that for Amazon Aurora instances the engine must match the `DB cluster`'s engine'.
     * For information on the difference between the available Aurora MySQL engines
     * see [Comparison between Aurora MySQL 1 and Aurora MySQL 2](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/AuroraMySQL.Updates.20180206.html)
     * in the Amazon RDS User Guide.
     */
    readonly engine?: pulumi.Input<string>;
    /**
     * The engine version to use. If `autoMinorVersionUpgrade`
     * is enabled, you can provide a prefix of the version such as `5.7` (for `5.7.10`) and
     * this attribute will ignore differences in the patch version automatically (e.g. `5.7.17`).
     * For supported values, see the EngineVersion parameter in [API action CreateDBInstance](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html).
     * Note that for Amazon Aurora instances the engine version must match the `DB cluster`'s engine version'.
     */
    readonly engineVersion?: pulumi.Input<string>;
    /**
     * The name of your final DB snapshot
     * when this DB instance is deleted. Must be provided if `skipFinalSnapshot` is
     * set to `false`. The value must begin with a letter, only contain alphanumeric characters and hyphens, and not end with a hyphen or contain two consecutive hyphens. Must not be provided when deleting a read replica.
     */
    readonly finalSnapshotIdentifier?: pulumi.Input<string>;
    /**
     * The canonical hosted zone ID of the DB instance (to be used
     * in a Route 53 Alias record).
     */
    readonly hostedZoneId?: pulumi.Input<string>;
    /**
     * Specifies whether or
     * mappings of AWS Identity and Access Management (IAM) accounts to database
     * accounts is enabled.
     */
    readonly iamDatabaseAuthenticationEnabled?: pulumi.Input<boolean>;
    /**
     * The name of the RDS instance,
     * if omitted, this provider will assign a random, unique identifier.
     */
    readonly identifier?: pulumi.Input<string>;
    /**
     * Creates a unique
     * identifier beginning with the specified prefix. Conflicts with `identifier`.
     */
    readonly identifierPrefix?: pulumi.Input<string>;
    /**
     * The instance type of the RDS instance.
     */
    readonly instanceClass?: pulumi.Input<string | enums.rds.InstanceType>;
    /**
     * The amount of provisioned IOPS. Setting this implies a
     * storageType of "io1".
     */
    readonly iops?: pulumi.Input<number>;
    /**
     * The ARN for the KMS encryption key. If creating an
     * encrypted replica, set this to the destination KMS ARN.
     */
    readonly kmsKeyId?: pulumi.Input<string>;
    /**
     * The latest time, in UTC [RFC3339 format](https://tools.ietf.org/html/rfc3339#section-5.8), to which a database can be restored with point-in-time restore.
     */
    readonly latestRestorableTime?: pulumi.Input<string>;
    /**
     * (Optional, but required for some DB engines, i.e. Oracle
     * SE1) License model information for this DB instance.
     */
    readonly licenseModel?: pulumi.Input<string>;
    /**
     * The window to perform maintenance in.
     * Syntax: "ddd:hh24:mi-ddd:hh24:mi". Eg: "Mon:00:00-Mon:03:00". See [RDS
     * Maintenance Window
     * docs](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_UpgradeDBInstance.Maintenance.html#AdjustingTheMaintenanceWindow)
     * for more information.
     */
    readonly maintenanceWindow?: pulumi.Input<string>;
    /**
     * When configured, the upper limit to which Amazon RDS can automatically scale the storage of the DB instance. Configuring this will automatically ignore differences to `allocatedStorage`. Must be greater than or equal to `allocatedStorage` or `0` to disable Storage Autoscaling.
     */
    readonly maxAllocatedStorage?: pulumi.Input<number>;
    /**
     * The interval, in seconds, between points
     * when Enhanced Monitoring metrics are collected for the DB instance. To disable
     * collecting Enhanced Monitoring metrics, specify 0. The default is 0. Valid
     * Values: 0, 1, 5, 10, 15, 30, 60.
     */
    readonly monitoringInterval?: pulumi.Input<number>;
    /**
     * The ARN for the IAM role that permits RDS
     * to send enhanced monitoring metrics to CloudWatch Logs. You can find more
     * information on the [AWS
     * Documentation](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Monitoring.html)
     * what IAM permissions are needed to allow Enhanced Monitoring for RDS Instances.
     */
    readonly monitoringRoleArn?: pulumi.Input<string>;
    /**
     * Specifies if the RDS instance is multi-AZ
     */
    readonly multiAz?: pulumi.Input<boolean>;
    /**
     * The name of the database to create when the DB instance is created. If this parameter is not specified, no database is created in the DB instance. Note that this does not apply for Oracle or SQL Server engines. See the [AWS documentation](http://docs.aws.amazon.com/cli/latest/reference/rds/create-db-instance.html) for more details on what applies for those engines.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Name of the DB option group to associate.
     */
    readonly optionGroupName?: pulumi.Input<string>;
    /**
     * Name of the DB parameter group to
     * associate.
     */
    readonly parameterGroupName?: pulumi.Input<string>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) Password for the master DB user. Note that this may show up in
     * logs, and it will be stored in the state file.
     */
    readonly password?: pulumi.Input<string>;
    /**
     * Specifies whether Performance Insights are enabled. Defaults to false.
     */
    readonly performanceInsightsEnabled?: pulumi.Input<boolean>;
    /**
     * The ARN for the KMS key to encrypt Performance Insights data. When specifying `performanceInsightsKmsKeyId`, `performanceInsightsEnabled` needs to be set to true. Once KMS key is set, it can never be changed.
     */
    readonly performanceInsightsKmsKeyId?: pulumi.Input<string>;
    /**
     * The amount of time in days to retain Performance Insights data. Either 7 (7 days) or 731 (2 years). When specifying `performanceInsightsRetentionPeriod`, `performanceInsightsEnabled` needs to be set to true. Defaults to '7'.
     */
    readonly performanceInsightsRetentionPeriod?: pulumi.Input<number>;
    /**
     * The port on which the DB accepts connections.
     */
    readonly port?: pulumi.Input<number>;
    /**
     * Bool to control if instance is publicly
     * accessible. Default is `false`.
     */
    readonly publiclyAccessible?: pulumi.Input<boolean>;
    readonly replicas?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Specifies that this resource is a Replicate
     * database, and to use this value as the source database. This correlates to the
     * `identifier` of another Amazon RDS Database to replicate (if replicating within
     * a single region) or ARN of the Amazon RDS Database to replicate (if replicating
     * cross-region). Note that if you are
     * creating a cross-region replica of an encrypted database you will also need to
     * specify a `kmsKeyId`. See [DB Instance Replication][1] and [Working with
     * PostgreSQL and MySQL Read Replicas](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ReadRepl.html)
     * for more information on using Replication.
     */
    readonly replicateSourceDb?: pulumi.Input<string>;
    /**
     * The RDS Resource ID of this instance.
     */
    readonly resourceId?: pulumi.Input<string>;
    /**
     * A configuration block for restoring a DB instance to an arbitrary point in time. Requires the `identifier` argument to be set with the name of the new DB instance to be created. See Restore To Point In Time below for details.
     */
    readonly restoreToPointInTime?: pulumi.Input<inputs.rds.InstanceRestoreToPointInTime>;
    /**
     * Restore from a Percona Xtrabackup in S3.  See [Importing Data into an Amazon RDS MySQL DB Instance](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/MySQL.Procedural.Importing.html)
     */
    readonly s3Import?: pulumi.Input<inputs.rds.InstanceS3Import>;
    /**
     * List of DB Security Groups to
     * associate. Only used for [DB Instances on the _EC2-Classic_
     * Platform](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.html#USER_VPC.FindDefaultVPC).
     */
    readonly securityGroupNames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Determines whether a final DB snapshot is
     * created before the DB instance is deleted. If true is specified, no DBSnapshot
     * is created. If false is specified, a DB snapshot is created before the DB
     * instance is deleted, using the value from `finalSnapshotIdentifier`. Default
     * is `false`.
     */
    readonly skipFinalSnapshot?: pulumi.Input<boolean>;
    /**
     * Specifies whether or not to create this
     * database from a snapshot. This correlates to the snapshot ID you'd find in the
     * RDS console, e.g: rds:production-2015-06-26-06-05.
     */
    readonly snapshotIdentifier?: pulumi.Input<string>;
    /**
     * The RDS instance status.
     */
    readonly status?: pulumi.Input<string>;
    /**
     * Specifies whether the DB instance is
     * encrypted. Note that if you are creating a cross-region read replica this field
     * is ignored and you should instead declare `kmsKeyId` with a valid ARN. The
     * default is `false` if not specified.
     */
    readonly storageEncrypted?: pulumi.Input<boolean>;
    /**
     * One of "standard" (magnetic), "gp2" (general
     * purpose SSD), or "io1" (provisioned IOPS SSD). The default is "io1" if `iops` is
     * specified, "gp2" if not.
     */
    readonly storageType?: pulumi.Input<string | enums.rds.StorageType>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Time zone of the DB instance. `timezone` is currently
     * only supported by Microsoft SQL Server. The `timezone` can only be set on
     * creation. See [MSSQL User
     * Guide](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_SQLServer.html#SQLServer.Concepts.General.TimeZone)
     * for more information.
     */
    readonly timezone?: pulumi.Input<string>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) Username for the master DB user.
     */
    readonly username?: pulumi.Input<string>;
    /**
     * List of VPC security groups to
     * associate.
     */
    readonly vpcSecurityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a Instance resource.
 */
export interface InstanceArgs {
    /**
     * The allocated storage in gibibytes. If `maxAllocatedStorage` is configured, this argument represents the initial storage allocation and differences from the configuration will be ignored automatically when Storage Autoscaling occurs.
     */
    readonly allocatedStorage?: pulumi.Input<number>;
    /**
     * Indicates that major version
     * upgrades are allowed. Changing this parameter does not result in an outage and
     * the change is asynchronously applied as soon as possible.
     */
    readonly allowMajorVersionUpgrade?: pulumi.Input<boolean>;
    /**
     * Specifies whether any database modifications
     * are applied immediately, or during the next maintenance window. Default is
     * `false`. See [Amazon RDS Documentation for more
     * information.](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBInstance.Modifying.html)
     */
    readonly applyImmediately?: pulumi.Input<boolean>;
    /**
     * Indicates that minor engine upgrades
     * will be applied automatically to the DB instance during the maintenance window.
     * Defaults to true.
     */
    readonly autoMinorVersionUpgrade?: pulumi.Input<boolean>;
    /**
     * The AZ for the RDS instance.
     */
    readonly availabilityZone?: pulumi.Input<string>;
    /**
     * The days to retain backups for. Must be
     * between `0` and `35`. Must be greater than `0` if the database is used as a source for a Read Replica. [See Read Replica][1].
     */
    readonly backupRetentionPeriod?: pulumi.Input<number>;
    /**
     * The daily time range (in UTC) during which
     * automated backups are created if they are enabled. Example: "09:46-10:16". Must
     * not overlap with `maintenanceWindow`.
     */
    readonly backupWindow?: pulumi.Input<string>;
    /**
     * The identifier of the CA certificate for the DB instance.
     */
    readonly caCertIdentifier?: pulumi.Input<string>;
    /**
     * The character set name to use for DB
     * encoding in Oracle and Microsoft SQL instances (collation). This can't be changed. See [Oracle Character Sets
     * Supported in Amazon RDS](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Appendix.OracleCharacterSets.html)
     * or [Server-Level Collation for Microsoft SQL Server](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Appendix.SQLServer.CommonDBATasks.Collation.html) for more information.
     */
    readonly characterSetName?: pulumi.Input<string>;
    /**
     * Copy all Instance `tags` to snapshots. Default is `false`.
     */
    readonly copyTagsToSnapshot?: pulumi.Input<boolean>;
    /**
     * Name of `DB subnet group`. DB instance will
     * be created in the VPC associated with the DB subnet group. If unspecified, will
     * be created in the `default` VPC, or in EC2 Classic, if available. When working
     * with read replicas, it should be specified only if the source database
     * specifies an instance in another AWS Region. See [DBSubnetGroupName in API
     * action CreateDBInstanceReadReplica](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstanceReadReplica.html)
     * for additional read replica contraints.
     */
    readonly dbSubnetGroupName?: pulumi.Input<string>;
    /**
     * Specifies whether to remove automated backups immediately after the DB instance is deleted. Default is `true`.
     */
    readonly deleteAutomatedBackups?: pulumi.Input<boolean>;
    /**
     * If the DB instance should have deletion protection enabled. The database can't be deleted when this value is set to `true`. The default is `false`.
     */
    readonly deletionProtection?: pulumi.Input<boolean>;
    /**
     * The ID of the Directory Service Active Directory domain to create the instance in.
     */
    readonly domain?: pulumi.Input<string>;
    /**
     * The name of the IAM role to be used when making API calls to the Directory Service.
     */
    readonly domainIamRoleName?: pulumi.Input<string>;
    /**
     * Set of log types to enable for exporting to CloudWatch logs. If omitted, no logs will be exported. Valid values (depending on `engine`). MySQL and MariaDB: `audit`, `error`, `general`, `slowquery`. PostgreSQL: `postgresql`, `upgrade`. MSSQL: `agent` , `error`. Oracle: `alert`, `audit`, `listener`, `trace`.
     */
    readonly enabledCloudwatchLogsExports?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) The database engine to use.  For supported values, see the Engine parameter in [API action CreateDBInstance](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html).
     * Note that for Amazon Aurora instances the engine must match the `DB cluster`'s engine'.
     * For information on the difference between the available Aurora MySQL engines
     * see [Comparison between Aurora MySQL 1 and Aurora MySQL 2](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/AuroraMySQL.Updates.20180206.html)
     * in the Amazon RDS User Guide.
     */
    readonly engine?: pulumi.Input<string>;
    /**
     * The engine version to use. If `autoMinorVersionUpgrade`
     * is enabled, you can provide a prefix of the version such as `5.7` (for `5.7.10`) and
     * this attribute will ignore differences in the patch version automatically (e.g. `5.7.17`).
     * For supported values, see the EngineVersion parameter in [API action CreateDBInstance](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html).
     * Note that for Amazon Aurora instances the engine version must match the `DB cluster`'s engine version'.
     */
    readonly engineVersion?: pulumi.Input<string>;
    /**
     * The name of your final DB snapshot
     * when this DB instance is deleted. Must be provided if `skipFinalSnapshot` is
     * set to `false`. The value must begin with a letter, only contain alphanumeric characters and hyphens, and not end with a hyphen or contain two consecutive hyphens. Must not be provided when deleting a read replica.
     */
    readonly finalSnapshotIdentifier?: pulumi.Input<string>;
    /**
     * Specifies whether or
     * mappings of AWS Identity and Access Management (IAM) accounts to database
     * accounts is enabled.
     */
    readonly iamDatabaseAuthenticationEnabled?: pulumi.Input<boolean>;
    /**
     * The name of the RDS instance,
     * if omitted, this provider will assign a random, unique identifier.
     */
    readonly identifier?: pulumi.Input<string>;
    /**
     * Creates a unique
     * identifier beginning with the specified prefix. Conflicts with `identifier`.
     */
    readonly identifierPrefix?: pulumi.Input<string>;
    /**
     * The instance type of the RDS instance.
     */
    readonly instanceClass: pulumi.Input<string | enums.rds.InstanceType>;
    /**
     * The amount of provisioned IOPS. Setting this implies a
     * storageType of "io1".
     */
    readonly iops?: pulumi.Input<number>;
    /**
     * The ARN for the KMS encryption key. If creating an
     * encrypted replica, set this to the destination KMS ARN.
     */
    readonly kmsKeyId?: pulumi.Input<string>;
    /**
     * (Optional, but required for some DB engines, i.e. Oracle
     * SE1) License model information for this DB instance.
     */
    readonly licenseModel?: pulumi.Input<string>;
    /**
     * The window to perform maintenance in.
     * Syntax: "ddd:hh24:mi-ddd:hh24:mi". Eg: "Mon:00:00-Mon:03:00". See [RDS
     * Maintenance Window
     * docs](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_UpgradeDBInstance.Maintenance.html#AdjustingTheMaintenanceWindow)
     * for more information.
     */
    readonly maintenanceWindow?: pulumi.Input<string>;
    /**
     * When configured, the upper limit to which Amazon RDS can automatically scale the storage of the DB instance. Configuring this will automatically ignore differences to `allocatedStorage`. Must be greater than or equal to `allocatedStorage` or `0` to disable Storage Autoscaling.
     */
    readonly maxAllocatedStorage?: pulumi.Input<number>;
    /**
     * The interval, in seconds, between points
     * when Enhanced Monitoring metrics are collected for the DB instance. To disable
     * collecting Enhanced Monitoring metrics, specify 0. The default is 0. Valid
     * Values: 0, 1, 5, 10, 15, 30, 60.
     */
    readonly monitoringInterval?: pulumi.Input<number>;
    /**
     * The ARN for the IAM role that permits RDS
     * to send enhanced monitoring metrics to CloudWatch Logs. You can find more
     * information on the [AWS
     * Documentation](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Monitoring.html)
     * what IAM permissions are needed to allow Enhanced Monitoring for RDS Instances.
     */
    readonly monitoringRoleArn?: pulumi.Input<string>;
    /**
     * Specifies if the RDS instance is multi-AZ
     */
    readonly multiAz?: pulumi.Input<boolean>;
    /**
     * The name of the database to create when the DB instance is created. If this parameter is not specified, no database is created in the DB instance. Note that this does not apply for Oracle or SQL Server engines. See the [AWS documentation](http://docs.aws.amazon.com/cli/latest/reference/rds/create-db-instance.html) for more details on what applies for those engines.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Name of the DB option group to associate.
     */
    readonly optionGroupName?: pulumi.Input<string>;
    /**
     * Name of the DB parameter group to
     * associate.
     */
    readonly parameterGroupName?: pulumi.Input<string>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) Password for the master DB user. Note that this may show up in
     * logs, and it will be stored in the state file.
     */
    readonly password?: pulumi.Input<string>;
    /**
     * Specifies whether Performance Insights are enabled. Defaults to false.
     */
    readonly performanceInsightsEnabled?: pulumi.Input<boolean>;
    /**
     * The ARN for the KMS key to encrypt Performance Insights data. When specifying `performanceInsightsKmsKeyId`, `performanceInsightsEnabled` needs to be set to true. Once KMS key is set, it can never be changed.
     */
    readonly performanceInsightsKmsKeyId?: pulumi.Input<string>;
    /**
     * The amount of time in days to retain Performance Insights data. Either 7 (7 days) or 731 (2 years). When specifying `performanceInsightsRetentionPeriod`, `performanceInsightsEnabled` needs to be set to true. Defaults to '7'.
     */
    readonly performanceInsightsRetentionPeriod?: pulumi.Input<number>;
    /**
     * The port on which the DB accepts connections.
     */
    readonly port?: pulumi.Input<number>;
    /**
     * Bool to control if instance is publicly
     * accessible. Default is `false`.
     */
    readonly publiclyAccessible?: pulumi.Input<boolean>;
    /**
     * Specifies that this resource is a Replicate
     * database, and to use this value as the source database. This correlates to the
     * `identifier` of another Amazon RDS Database to replicate (if replicating within
     * a single region) or ARN of the Amazon RDS Database to replicate (if replicating
     * cross-region). Note that if you are
     * creating a cross-region replica of an encrypted database you will also need to
     * specify a `kmsKeyId`. See [DB Instance Replication][1] and [Working with
     * PostgreSQL and MySQL Read Replicas](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ReadRepl.html)
     * for more information on using Replication.
     */
    readonly replicateSourceDb?: pulumi.Input<string>;
    /**
     * A configuration block for restoring a DB instance to an arbitrary point in time. Requires the `identifier` argument to be set with the name of the new DB instance to be created. See Restore To Point In Time below for details.
     */
    readonly restoreToPointInTime?: pulumi.Input<inputs.rds.InstanceRestoreToPointInTime>;
    /**
     * Restore from a Percona Xtrabackup in S3.  See [Importing Data into an Amazon RDS MySQL DB Instance](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/MySQL.Procedural.Importing.html)
     */
    readonly s3Import?: pulumi.Input<inputs.rds.InstanceS3Import>;
    /**
     * List of DB Security Groups to
     * associate. Only used for [DB Instances on the _EC2-Classic_
     * Platform](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.html#USER_VPC.FindDefaultVPC).
     */
    readonly securityGroupNames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Determines whether a final DB snapshot is
     * created before the DB instance is deleted. If true is specified, no DBSnapshot
     * is created. If false is specified, a DB snapshot is created before the DB
     * instance is deleted, using the value from `finalSnapshotIdentifier`. Default
     * is `false`.
     */
    readonly skipFinalSnapshot?: pulumi.Input<boolean>;
    /**
     * Specifies whether or not to create this
     * database from a snapshot. This correlates to the snapshot ID you'd find in the
     * RDS console, e.g: rds:production-2015-06-26-06-05.
     */
    readonly snapshotIdentifier?: pulumi.Input<string>;
    /**
     * Specifies whether the DB instance is
     * encrypted. Note that if you are creating a cross-region read replica this field
     * is ignored and you should instead declare `kmsKeyId` with a valid ARN. The
     * default is `false` if not specified.
     */
    readonly storageEncrypted?: pulumi.Input<boolean>;
    /**
     * One of "standard" (magnetic), "gp2" (general
     * purpose SSD), or "io1" (provisioned IOPS SSD). The default is "io1" if `iops` is
     * specified, "gp2" if not.
     */
    readonly storageType?: pulumi.Input<string | enums.rds.StorageType>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Time zone of the DB instance. `timezone` is currently
     * only supported by Microsoft SQL Server. The `timezone` can only be set on
     * creation. See [MSSQL User
     * Guide](http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_SQLServer.html#SQLServer.Concepts.General.TimeZone)
     * for more information.
     */
    readonly timezone?: pulumi.Input<string>;
    /**
     * (Required unless a `snapshotIdentifier` or `replicateSourceDb`
     * is provided) Username for the master DB user.
     */
    readonly username?: pulumi.Input<string>;
    /**
     * List of VPC security groups to
     * associate.
     */
    readonly vpcSecurityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
}
