import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an RDS security group resource. This is only for DB instances in the
 * EC2-Classic Platform. For instances inside a VPC, use the
 * `aws_db_instance.vpc_security_group_ids`
 * attribute instead.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const defaultSecurityGroup = new aws.rds.SecurityGroup("default", {
 *     ingress: [{
 *         cidr: "10.0.0.0/24",
 *     }],
 * });
 * ```
 *
 * ## Import
 *
 * DB Security groups can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:rds/securityGroup:SecurityGroup default aws_rds_sg-1
 * ```
 */
export declare class SecurityGroup extends pulumi.CustomResource {
    /**
     * Get an existing SecurityGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SecurityGroupState, opts?: pulumi.CustomResourceOptions): SecurityGroup;
    /**
     * Returns true if the given object is an instance of SecurityGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SecurityGroup;
    /**
     * The arn of the DB security group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description of the DB security group. Defaults to "Managed by Pulumi".
     */
    readonly description: pulumi.Output<string>;
    /**
     * A list of ingress rules.
     */
    readonly ingress: pulumi.Output<outputs.rds.SecurityGroupIngress[]>;
    /**
     * The name of the DB security group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a SecurityGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SecurityGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SecurityGroup resources.
 */
export interface SecurityGroupState {
    /**
     * The arn of the DB security group.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The description of the DB security group. Defaults to "Managed by Pulumi".
     */
    readonly description?: pulumi.Input<string>;
    /**
     * A list of ingress rules.
     */
    readonly ingress?: pulumi.Input<pulumi.Input<inputs.rds.SecurityGroupIngress>[]>;
    /**
     * The name of the DB security group.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a SecurityGroup resource.
 */
export interface SecurityGroupArgs {
    /**
     * The description of the DB security group. Defaults to "Managed by Pulumi".
     */
    readonly description?: pulumi.Input<string>;
    /**
     * A list of ingress rules.
     */
    readonly ingress: pulumi.Input<pulumi.Input<inputs.rds.SecurityGroupIngress>[]>;
    /**
     * The name of the DB security group.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
