import * as pulumi from "@pulumi/pulumi";
/**
 * Authorizes a VPC in a peer account to be associated with a local Route53 Hosted Zone.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const alternate = new aws.Provider("alternate", {});
 * const exampleVpc = new aws.ec2.Vpc("exampleVpc", {
 *     cidrBlock: "10.6.0.0/16",
 *     enableDnsHostnames: true,
 *     enableDnsSupport: true,
 * });
 * const exampleZone = new aws.route53.Zone("exampleZone", {vpcs: [{
 *     vpcId: exampleVpc.id,
 * }]});
 * const alternateVpc = new aws.ec2.Vpc("alternateVpc", {
 *     cidrBlock: "10.7.0.0/16",
 *     enableDnsHostnames: true,
 *     enableDnsSupport: true,
 * }, {
 *     provider: "aws.alternate",
 * });
 * const exampleVpcAssociationAuthorization = new aws.route53.VpcAssociationAuthorization("exampleVpcAssociationAuthorization", {
 *     vpcId: alternateVpc.id,
 *     zoneId: exampleZone.id,
 * });
 * const exampleZoneAssociation = new aws.route53.ZoneAssociation("exampleZoneAssociation", {
 *     vpcId: exampleVpcAssociationAuthorization.vpcId,
 *     zoneId: exampleVpcAssociationAuthorization.zoneId,
 * }, {
 *     provider: "aws.alternate",
 * });
 * ```
 *
 * ## Import
 *
 * Route 53 VPC Association Authorizations can be imported via the Hosted Zone ID and VPC ID, separated by a colon (`:`), e.g.
 *
 * ```sh
 *  $ pulumi import aws:route53/vpcAssociationAuthorization:VpcAssociationAuthorization example Z123456ABCDEFG:vpc-12345678
 * ```
 */
export declare class VpcAssociationAuthorization extends pulumi.CustomResource {
    /**
     * Get an existing VpcAssociationAuthorization resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: VpcAssociationAuthorizationState, opts?: pulumi.CustomResourceOptions): VpcAssociationAuthorization;
    /**
     * Returns true if the given object is an instance of VpcAssociationAuthorization.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcAssociationAuthorization;
    /**
     * The VPC to authorize for association with the private hosted zone.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * The VPC's region. Defaults to the region of the AWS provider.
     */
    readonly vpcRegion: pulumi.Output<string>;
    /**
     * The ID of the private hosted zone that you want to authorize associating a VPC with.
     */
    readonly zoneId: pulumi.Output<string>;
    /**
     * Create a VpcAssociationAuthorization resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcAssociationAuthorizationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering VpcAssociationAuthorization resources.
 */
export interface VpcAssociationAuthorizationState {
    /**
     * The VPC to authorize for association with the private hosted zone.
     */
    readonly vpcId?: pulumi.Input<string>;
    /**
     * The VPC's region. Defaults to the region of the AWS provider.
     */
    readonly vpcRegion?: pulumi.Input<string>;
    /**
     * The ID of the private hosted zone that you want to authorize associating a VPC with.
     */
    readonly zoneId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a VpcAssociationAuthorization resource.
 */
export interface VpcAssociationAuthorizationArgs {
    /**
     * The VPC to authorize for association with the private hosted zone.
     */
    readonly vpcId: pulumi.Input<string>;
    /**
     * The VPC's region. Defaults to the region of the AWS provider.
     */
    readonly vpcRegion?: pulumi.Input<string>;
    /**
     * The ID of the private hosted zone that you want to authorize associating a VPC with.
     */
    readonly zoneId: pulumi.Input<string>;
}
