import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a S3 bucket [metrics configuration](http://docs.aws.amazon.com/AmazonS3/latest/dev/metrics-configurations.html) resource.
 *
 * ## Example Usage
 * ### Add metrics configuration for entire S3 bucket
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.s3.Bucket("example", {});
 * const example_entire_bucket = new aws.s3.BucketMetric("example-entire-bucket", {bucket: example.bucket});
 * ```
 * ### Add metrics configuration with S3 bucket object filter
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.s3.Bucket("example", {});
 * const example_filtered = new aws.s3.BucketMetric("example-filtered", {
 *     bucket: example.bucket,
 *     filter: {
 *         prefix: "documents/",
 *         tags: {
 *             priority: "high",
 *             "class": "blue",
 *         },
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * S3 bucket metric configurations can be imported using `bucket:metric`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:s3/bucketMetric:BucketMetric my-bucket-entire-bucket my-bucket:EntireBucket
 * ```
 */
export declare class BucketMetric extends pulumi.CustomResource {
    /**
     * Get an existing BucketMetric resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: BucketMetricState, opts?: pulumi.CustomResourceOptions): BucketMetric;
    /**
     * Returns true if the given object is an instance of BucketMetric.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BucketMetric;
    /**
     * The name of the bucket to put metric configuration.
     */
    readonly bucket: pulumi.Output<string>;
    /**
     * [Object filtering](http://docs.aws.amazon.com/AmazonS3/latest/dev/metrics-configurations.html#metrics-configurations-filter) that accepts a prefix, tags, or a logical AND of prefix and tags (documented below).
     */
    readonly filter: pulumi.Output<outputs.s3.BucketMetricFilter | undefined>;
    /**
     * Unique identifier of the metrics configuration for the bucket.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a BucketMetric resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BucketMetricArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering BucketMetric resources.
 */
export interface BucketMetricState {
    /**
     * The name of the bucket to put metric configuration.
     */
    readonly bucket?: pulumi.Input<string>;
    /**
     * [Object filtering](http://docs.aws.amazon.com/AmazonS3/latest/dev/metrics-configurations.html#metrics-configurations-filter) that accepts a prefix, tags, or a logical AND of prefix and tags (documented below).
     */
    readonly filter?: pulumi.Input<inputs.s3.BucketMetricFilter>;
    /**
     * Unique identifier of the metrics configuration for the bucket.
     */
    readonly name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a BucketMetric resource.
 */
export interface BucketMetricArgs {
    /**
     * The name of the bucket to put metric configuration.
     */
    readonly bucket: pulumi.Input<string>;
    /**
     * [Object filtering](http://docs.aws.amazon.com/AmazonS3/latest/dev/metrics-configurations.html#metrics-configurations-filter) that accepts a prefix, tags, or a logical AND of prefix and tags (documented below).
     */
    readonly filter?: pulumi.Input<inputs.s3.BucketMetricFilter>;
    /**
     * Unique identifier of the metrics configuration for the bucket.
     */
    readonly name?: pulumi.Input<string>;
}
