import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a resource to manage S3 Bucket Ownership Controls. For more information, see the [S3 Developer Guide](https://docs.aws.amazon.com/AmazonS3/latest/dev/about-object-ownership.html).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleBucket = new aws.s3.Bucket("exampleBucket", {});
 * const exampleBucketOwnershipControls = new aws.s3.BucketOwnershipControls("exampleBucketOwnershipControls", {
 *     bucket: exampleBucket.id,
 *     rule: {
 *         objectOwnership: "BucketOwnerPreferred",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * S3 Bucket Ownership Controls can be imported using S3 Bucket name, e.g.
 *
 * ```sh
 *  $ pulumi import aws:s3/bucketOwnershipControls:BucketOwnershipControls example my-bucket
 * ```
 */
export declare class BucketOwnershipControls extends pulumi.CustomResource {
    /**
     * Get an existing BucketOwnershipControls resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: BucketOwnershipControlsState, opts?: pulumi.CustomResourceOptions): BucketOwnershipControls;
    /**
     * Returns true if the given object is an instance of BucketOwnershipControls.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BucketOwnershipControls;
    /**
     * The name of the bucket that you want to associate this access point with.
     */
    readonly bucket: pulumi.Output<string>;
    /**
     * Configuration block(s) with Ownership Controls rules. Detailed below.
     */
    readonly rule: pulumi.Output<outputs.s3.BucketOwnershipControlsRule>;
    /**
     * Create a BucketOwnershipControls resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BucketOwnershipControlsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering BucketOwnershipControls resources.
 */
export interface BucketOwnershipControlsState {
    /**
     * The name of the bucket that you want to associate this access point with.
     */
    readonly bucket?: pulumi.Input<string>;
    /**
     * Configuration block(s) with Ownership Controls rules. Detailed below.
     */
    readonly rule?: pulumi.Input<inputs.s3.BucketOwnershipControlsRule>;
}
/**
 * The set of arguments for constructing a BucketOwnershipControls resource.
 */
export interface BucketOwnershipControlsArgs {
    /**
     * The name of the bucket that you want to associate this access point with.
     */
    readonly bucket: pulumi.Input<string>;
    /**
     * Configuration block(s) with Ownership Controls rules. Detailed below.
     */
    readonly rule: pulumi.Input<inputs.s3.BucketOwnershipControlsRule>;
}
