import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a Sagemaker App Image Config resource.
 *
 * ## Example Usage
 * ### Basic usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.sagemaker.AppImageConfig("test", {
 *     appImageConfigName: "example",
 *     kernelGatewayImageConfig: {
 *         kernelSpec: {
 *             name: "example",
 *         },
 *     },
 * });
 * ```
 * ### Default File System Config
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.sagemaker.AppImageConfig("test", {
 *     appImageConfigName: "example",
 *     kernelGatewayImageConfig: {
 *         fileSystemConfig: {},
 *         kernelSpec: {
 *             name: "example",
 *         },
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Sagemaker App Image Configs can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:sagemaker/appImageConfig:AppImageConfig example example
 * ```
 */
export declare class AppImageConfig extends pulumi.CustomResource {
    /**
     * Get an existing AppImageConfig resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AppImageConfigState, opts?: pulumi.CustomResourceOptions): AppImageConfig;
    /**
     * Returns true if the given object is an instance of AppImageConfig.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AppImageConfig;
    /**
     * The name of the App Image Config.
     */
    readonly appImageConfigName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) assigned by AWS to this App Image Config.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The configuration for the file system and kernels in a SageMaker image running as a KernelGateway app. See Kernel Gateway Image Config details below.
     */
    readonly kernelGatewayImageConfig: pulumi.Output<outputs.sagemaker.AppImageConfigKernelGatewayImageConfig | undefined>;
    /**
     * Create a AppImageConfig resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AppImageConfigArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AppImageConfig resources.
 */
export interface AppImageConfigState {
    /**
     * The name of the App Image Config.
     */
    readonly appImageConfigName?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) assigned by AWS to this App Image Config.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The configuration for the file system and kernels in a SageMaker image running as a KernelGateway app. See Kernel Gateway Image Config details below.
     */
    readonly kernelGatewayImageConfig?: pulumi.Input<inputs.sagemaker.AppImageConfigKernelGatewayImageConfig>;
}
/**
 * The set of arguments for constructing a AppImageConfig resource.
 */
export interface AppImageConfigArgs {
    /**
     * The name of the App Image Config.
     */
    readonly appImageConfigName: pulumi.Input<string>;
    /**
     * The configuration for the file system and kernels in a SageMaker image running as a KernelGateway app. See Kernel Gateway Image Config details below.
     */
    readonly kernelGatewayImageConfig?: pulumi.Input<inputs.sagemaker.AppImageConfigKernelGatewayImageConfig>;
}
