import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a SageMaker endpoint configuration resource.
 *
 * ## Example Usage
 *
 * Basic usage:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const ec = new aws.sagemaker.EndpointConfiguration("ec", {
 *     productionVariants: [{
 *         variantName: "variant-1",
 *         modelName: aws_sagemaker_model.m.name,
 *         initialInstanceCount: 1,
 *         instanceType: "ml.t2.medium",
 *     }],
 *     tags: {
 *         Name: "foo",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Endpoint configurations can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:sagemaker/endpointConfiguration:EndpointConfiguration test_endpoint_config endpoint-config-foo
 * ```
 */
export declare class EndpointConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing EndpointConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EndpointConfigurationState, opts?: pulumi.CustomResourceOptions): EndpointConfiguration;
    /**
     * Returns true if the given object is an instance of EndpointConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EndpointConfiguration;
    /**
     * The Amazon Resource Name (ARN) assigned by AWS to this endpoint configuration.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Specifies the parameters to capture input/output of Sagemaker models endpoints. Fields are documented below.
     */
    readonly dataCaptureConfig: pulumi.Output<outputs.sagemaker.EndpointConfigurationDataCaptureConfig | undefined>;
    /**
     * Amazon Resource Name (ARN) of a AWS Key Management Service key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint.
     */
    readonly kmsKeyArn: pulumi.Output<string | undefined>;
    /**
     * The name of the endpoint configuration. If omitted, this provider will assign a random, unique name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Fields are documented below.
     */
    readonly productionVariants: pulumi.Output<outputs.sagemaker.EndpointConfigurationProductionVariant[]>;
    /**
     * A mapping of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a EndpointConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EndpointConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EndpointConfiguration resources.
 */
export interface EndpointConfigurationState {
    /**
     * The Amazon Resource Name (ARN) assigned by AWS to this endpoint configuration.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Specifies the parameters to capture input/output of Sagemaker models endpoints. Fields are documented below.
     */
    readonly dataCaptureConfig?: pulumi.Input<inputs.sagemaker.EndpointConfigurationDataCaptureConfig>;
    /**
     * Amazon Resource Name (ARN) of a AWS Key Management Service key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint.
     */
    readonly kmsKeyArn?: pulumi.Input<string>;
    /**
     * The name of the endpoint configuration. If omitted, this provider will assign a random, unique name.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Fields are documented below.
     */
    readonly productionVariants?: pulumi.Input<pulumi.Input<inputs.sagemaker.EndpointConfigurationProductionVariant>[]>;
    /**
     * A mapping of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a EndpointConfiguration resource.
 */
export interface EndpointConfigurationArgs {
    /**
     * Specifies the parameters to capture input/output of Sagemaker models endpoints. Fields are documented below.
     */
    readonly dataCaptureConfig?: pulumi.Input<inputs.sagemaker.EndpointConfigurationDataCaptureConfig>;
    /**
     * Amazon Resource Name (ARN) of a AWS Key Management Service key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint.
     */
    readonly kmsKeyArn?: pulumi.Input<string>;
    /**
     * The name of the endpoint configuration. If omitted, this provider will assign a random, unique name.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Fields are documented below.
     */
    readonly productionVariants: pulumi.Input<pulumi.Input<inputs.sagemaker.EndpointConfigurationProductionVariant>[]>;
    /**
     * A mapping of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
