import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a Sagemaker User Profile resource.
 *
 * ## Example Usage
 * ### Basic usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.sagemaker.UserProfile("example", {
 *     domainId: aws_sagemaker_domain.test.id,
 *     userProfileName: "example",
 * });
 * ```
 *
 * ## Import
 *
 * Sagemaker Code User Profiles can be imported using the `arn`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:sagemaker/userProfile:UserProfile test_user_profile arn:aws:sagemaker:us-west-2:123456789012:user-profile/domain-id/profile-name
 * ```
 */
export declare class UserProfile extends pulumi.CustomResource {
    /**
     * Get an existing UserProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UserProfileState, opts?: pulumi.CustomResourceOptions): UserProfile;
    /**
     * Returns true if the given object is an instance of UserProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UserProfile;
    /**
     * The user profile Amazon Resource Name (ARN).
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the associated Domain.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The ID of the user's profile in the Amazon Elastic File System (EFS) volume.
     */
    readonly homeEfsFileSystemUid: pulumi.Output<string>;
    /**
     * A specifier for the type of value specified in `singleSignOnUserValue`. Currently, the only supported value is `UserName`. If the Domain's AuthMode is SSO, this field is required. If the Domain's AuthMode is not SSO, this field cannot be specified.
     */
    readonly singleSignOnUserIdentifier: pulumi.Output<string | undefined>;
    /**
     * The username of the associated AWS Single Sign-On User for this User Profile. If the Domain's AuthMode is SSO, this field is required, and must match a valid username of a user in your directory. If the Domain's AuthMode is not SSO, this field cannot be specified.
     */
    readonly singleSignOnUserValue: pulumi.Output<string | undefined>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The name for the User Profile.
     */
    readonly userProfileName: pulumi.Output<string>;
    /**
     * The user settings. See User Settings below.
     */
    readonly userSettings: pulumi.Output<outputs.sagemaker.UserProfileUserSettings | undefined>;
    /**
     * Create a UserProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UserProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UserProfile resources.
 */
export interface UserProfileState {
    /**
     * The user profile Amazon Resource Name (ARN).
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The ID of the associated Domain.
     */
    readonly domainId?: pulumi.Input<string>;
    /**
     * The ID of the user's profile in the Amazon Elastic File System (EFS) volume.
     */
    readonly homeEfsFileSystemUid?: pulumi.Input<string>;
    /**
     * A specifier for the type of value specified in `singleSignOnUserValue`. Currently, the only supported value is `UserName`. If the Domain's AuthMode is SSO, this field is required. If the Domain's AuthMode is not SSO, this field cannot be specified.
     */
    readonly singleSignOnUserIdentifier?: pulumi.Input<string>;
    /**
     * The username of the associated AWS Single Sign-On User for this User Profile. If the Domain's AuthMode is SSO, this field is required, and must match a valid username of a user in your directory. If the Domain's AuthMode is not SSO, this field cannot be specified.
     */
    readonly singleSignOnUserValue?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The name for the User Profile.
     */
    readonly userProfileName?: pulumi.Input<string>;
    /**
     * The user settings. See User Settings below.
     */
    readonly userSettings?: pulumi.Input<inputs.sagemaker.UserProfileUserSettings>;
}
/**
 * The set of arguments for constructing a UserProfile resource.
 */
export interface UserProfileArgs {
    /**
     * The ID of the associated Domain.
     */
    readonly domainId: pulumi.Input<string>;
    /**
     * A specifier for the type of value specified in `singleSignOnUserValue`. Currently, the only supported value is `UserName`. If the Domain's AuthMode is SSO, this field is required. If the Domain's AuthMode is not SSO, this field cannot be specified.
     */
    readonly singleSignOnUserIdentifier?: pulumi.Input<string>;
    /**
     * The username of the associated AWS Single Sign-On User for this User Profile. If the Domain's AuthMode is SSO, this field is required, and must match a valid username of a user in your directory. If the Domain's AuthMode is not SSO, this field cannot be specified.
     */
    readonly singleSignOnUserValue?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The name for the User Profile.
     */
    readonly userProfileName: pulumi.Input<string>;
    /**
     * The user settings. See User Settings below.
     */
    readonly userSettings?: pulumi.Input<inputs.sagemaker.UserProfileUserSettings>;
}
