import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an SES domain MAIL FROM resource.
 *
 * > **NOTE:** For the MAIL FROM domain to be fully usable, this resource should be paired with the `aws.ses.DomainIdentity` resource. To validate the MAIL FROM domain, a DNS MX record is required. To pass SPF checks, a DNS TXT record may also be required. See the [Amazon SES MAIL FROM documentation](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/mail-from-set.html) for more information.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // Example SES Domain Identity
 * const exampleDomainIdentity = new aws.ses.DomainIdentity("exampleDomainIdentity", {domain: "example.com"});
 * const exampleMailFrom = new aws.ses.MailFrom("exampleMailFrom", {
 *     domain: exampleDomainIdentity.domain,
 *     mailFromDomain: pulumi.interpolate`bounce.${exampleDomainIdentity.domain}`,
 * });
 * // Example Route53 MX record
 * const exampleSesDomainMailFromMx = new aws.route53.Record("exampleSesDomainMailFromMx", {
 *     zoneId: aws_route53_zone.example.id,
 *     name: exampleMailFrom.mailFromDomain,
 *     type: "MX",
 *     ttl: "600",
 *     records: ["10 feedback-smtp.us-east-1.amazonses.com"],
 * });
 * // Change to the region in which `aws_ses_domain_identity.example` is created
 * // Example Route53 TXT record for SPF
 * const exampleSesDomainMailFromTxt = new aws.route53.Record("exampleSesDomainMailFromTxt", {
 *     zoneId: aws_route53_zone.example.id,
 *     name: exampleMailFrom.mailFromDomain,
 *     type: "TXT",
 *     ttl: "600",
 *     records: ["v=spf1 include:amazonses.com -all"],
 * });
 * ```
 *
 * ## Import
 *
 * MAIL FROM domain can be imported using the `domain` attribute, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ses/mailFrom:MailFrom example example.com
 * ```
 */
export declare class MailFrom extends pulumi.CustomResource {
    /**
     * Get an existing MailFrom resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: MailFromState, opts?: pulumi.CustomResourceOptions): MailFrom;
    /**
     * Returns true if the given object is an instance of MailFrom.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MailFrom;
    /**
     * The action that you want Amazon SES to take if it cannot successfully read the required MX record when you send an email. Defaults to `UseDefaultValue`. See the [SES API documentation](https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityMailFromDomain.html) for more information.
     */
    readonly behaviorOnMxFailure: pulumi.Output<string | undefined>;
    /**
     * Verified domain name to generate DKIM tokens for.
     */
    readonly domain: pulumi.Output<string>;
    /**
     * Subdomain (of above domain) which is to be used as MAIL FROM address (Required for DMARC validation)
     */
    readonly mailFromDomain: pulumi.Output<string>;
    /**
     * Create a MailFrom resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MailFromArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering MailFrom resources.
 */
export interface MailFromState {
    /**
     * The action that you want Amazon SES to take if it cannot successfully read the required MX record when you send an email. Defaults to `UseDefaultValue`. See the [SES API documentation](https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityMailFromDomain.html) for more information.
     */
    readonly behaviorOnMxFailure?: pulumi.Input<string>;
    /**
     * Verified domain name to generate DKIM tokens for.
     */
    readonly domain?: pulumi.Input<string>;
    /**
     * Subdomain (of above domain) which is to be used as MAIL FROM address (Required for DMARC validation)
     */
    readonly mailFromDomain?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a MailFrom resource.
 */
export interface MailFromArgs {
    /**
     * The action that you want Amazon SES to take if it cannot successfully read the required MX record when you send an email. Defaults to `UseDefaultValue`. See the [SES API documentation](https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityMailFromDomain.html) for more information.
     */
    readonly behaviorOnMxFailure?: pulumi.Input<string>;
    /**
     * Verified domain name to generate DKIM tokens for.
     */
    readonly domain: pulumi.Input<string>;
    /**
     * Subdomain (of above domain) which is to be used as MAIL FROM address (Required for DMARC validation)
     */
    readonly mailFromDomain: pulumi.Input<string>;
}
