import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a WAF Regional Regex Match Set Resource
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleRegexPatternSet = new aws.wafregional.RegexPatternSet("exampleRegexPatternSet", {regexPatternStrings: [
 *     "one",
 *     "two",
 * ]});
 * const exampleRegexMatchSet = new aws.wafregional.RegexMatchSet("exampleRegexMatchSet", {regexMatchTuples: [{
 *     fieldToMatch: {
 *         data: "User-Agent",
 *         type: "HEADER",
 *     },
 *     regexPatternSetId: exampleRegexPatternSet.id,
 *     textTransformation: "NONE",
 * }]});
 * ```
 *
 * ## Import
 *
 * WAF Regional Regex Match Set can be imported using the id, e.g.
 *
 * ```sh
 *  $ pulumi import aws:wafregional/regexMatchSet:RegexMatchSet example a1b2c3d4-d5f6-7777-8888-9999aaaabbbbcccc
 * ```
 */
export declare class RegexMatchSet extends pulumi.CustomResource {
    /**
     * Get an existing RegexMatchSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RegexMatchSetState, opts?: pulumi.CustomResourceOptions): RegexMatchSet;
    /**
     * Returns true if the given object is an instance of RegexMatchSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RegexMatchSet;
    /**
     * The name or description of the Regex Match Set.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The regular expression pattern that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings. See below.
     */
    readonly regexMatchTuples: pulumi.Output<outputs.wafregional.RegexMatchSetRegexMatchTuple[] | undefined>;
    /**
     * Create a RegexMatchSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: RegexMatchSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RegexMatchSet resources.
 */
export interface RegexMatchSetState {
    /**
     * The name or description of the Regex Match Set.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The regular expression pattern that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings. See below.
     */
    readonly regexMatchTuples?: pulumi.Input<pulumi.Input<inputs.wafregional.RegexMatchSetRegexMatchTuple>[]>;
}
/**
 * The set of arguments for constructing a RegexMatchSet resource.
 */
export interface RegexMatchSetArgs {
    /**
     * The name or description of the Regex Match Set.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The regular expression pattern that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings. See below.
     */
    readonly regexMatchTuples?: pulumi.Input<pulumi.Input<inputs.wafregional.RegexMatchSetRegexMatchTuple>[]>;
}
