import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a WAFv2 IP Set Resource
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.wafv2.IpSet("example", {
 *     addresses: [
 *         "1.2.3.4/32",
 *         "5.6.7.8/32",
 *     ],
 *     description: "Example IP set",
 *     ipAddressVersion: "IPV4",
 *     scope: "REGIONAL",
 *     tags: {
 *         Tag1: "Value1",
 *         Tag2: "Value2",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * WAFv2 IP Sets can be imported using `ID/name/scope`
 *
 * ```sh
 *  $ pulumi import aws:wafv2/ipSet:IpSet example a1b2c3d4-d5f6-7777-8888-9999aaaabbbbcccc/example/REGIONAL
 * ```
 */
export declare class IpSet extends pulumi.CustomResource {
    /**
     * Get an existing IpSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IpSetState, opts?: pulumi.CustomResourceOptions): IpSet;
    /**
     * Returns true if the given object is an instance of IpSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IpSet;
    /**
     * Contains an array of strings that specify one or more IP addresses or blocks of IP addresses in Classless Inter-Domain Routing (CIDR) notation. AWS WAF supports all address ranges for IP versions IPv4 and IPv6.
     */
    readonly addresses: pulumi.Output<string[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) that identifies the cluster.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A friendly description of the IP set.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Specify IPV4 or IPV6. Valid values are `IPV4` or `IPV6`.
     */
    readonly ipAddressVersion: pulumi.Output<string>;
    readonly lockToken: pulumi.Output<string>;
    /**
     * A friendly name of the IP set.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Specifies whether this is for an AWS CloudFront distribution or for a regional application. Valid values are `CLOUDFRONT` or `REGIONAL`. To work with CloudFront, you must also specify the Region US East (N. Virginia).
     */
    readonly scope: pulumi.Output<string>;
    /**
     * An array of key:value pairs to associate with the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a IpSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IpSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IpSet resources.
 */
export interface IpSetState {
    /**
     * Contains an array of strings that specify one or more IP addresses or blocks of IP addresses in Classless Inter-Domain Routing (CIDR) notation. AWS WAF supports all address ranges for IP versions IPv4 and IPv6.
     */
    readonly addresses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Amazon Resource Name (ARN) that identifies the cluster.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * A friendly description of the IP set.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Specify IPV4 or IPV6. Valid values are `IPV4` or `IPV6`.
     */
    readonly ipAddressVersion?: pulumi.Input<string>;
    readonly lockToken?: pulumi.Input<string>;
    /**
     * A friendly name of the IP set.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Specifies whether this is for an AWS CloudFront distribution or for a regional application. Valid values are `CLOUDFRONT` or `REGIONAL`. To work with CloudFront, you must also specify the Region US East (N. Virginia).
     */
    readonly scope?: pulumi.Input<string>;
    /**
     * An array of key:value pairs to associate with the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a IpSet resource.
 */
export interface IpSetArgs {
    /**
     * Contains an array of strings that specify one or more IP addresses or blocks of IP addresses in Classless Inter-Domain Routing (CIDR) notation. AWS WAF supports all address ranges for IP versions IPv4 and IPv6.
     */
    readonly addresses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A friendly description of the IP set.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Specify IPV4 or IPV6. Valid values are `IPV4` or `IPV6`.
     */
    readonly ipAddressVersion: pulumi.Input<string>;
    /**
     * A friendly name of the IP set.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Specifies whether this is for an AWS CloudFront distribution or for a regional application. Valid values are `CLOUDFRONT` or `REGIONAL`. To work with CloudFront, you must also specify the Region US East (N. Virginia).
     */
    readonly scope: pulumi.Input<string>;
    /**
     * An array of key:value pairs to associate with the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
