import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Creates a WAFv2 Web ACL Logging Configuration resource.
 *
 * > **Note:** To start logging from a WAFv2 Web ACL, an Amazon Kinesis Data Firehose (e.g. `aws.kinesis.FirehoseDeliveryStream` resourc must also be created with a PUT source (not a stream) and in the region that you are operating.
 * If you are capturing logs for Amazon CloudFront, always create the firehose in US East (N. Virginia).
 * Be sure to give the data firehose a name that starts with the prefix `aws-waf-logs-`.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.wafv2.WebAclLoggingConfiguration("example", {
 *     logDestinationConfigs: [aws_kinesis_firehose_delivery_stream.example.arn],
 *     resourceArn: aws_wafv2_web_acl.example.arn,
 *     redactedFields: [{
 *         singleHeader: {
 *             name: "user-agent",
 *         },
 *     }],
 * });
 * ```
 *
 * ## Import
 *
 * WAFv2 Web ACL Logging Configurations can be imported using the WAFv2 Web ACL ARN e.g.
 *
 * ```sh
 *  $ pulumi import aws:wafv2/webAclLoggingConfiguration:WebAclLoggingConfiguration example arn:aws:wafv2:us-west-2:123456789012:regional/webacl/test-logs/a1b2c3d4-5678-90ab-cdef
 * ```
 */
export declare class WebAclLoggingConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing WebAclLoggingConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: WebAclLoggingConfigurationState, opts?: pulumi.CustomResourceOptions): WebAclLoggingConfiguration;
    /**
     * Returns true if the given object is an instance of WebAclLoggingConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WebAclLoggingConfiguration;
    /**
     * The Amazon Kinesis Data Firehose Amazon Resource Name (ARNs) that you want to associate with the web ACL. Currently, only 1 ARN is supported.
     */
    readonly logDestinationConfigs: pulumi.Output<string[]>;
    /**
     * The parts of the request that you want to keep out of the logs. Up to 100 `redactedFields` blocks are supported.
     */
    readonly redactedFields: pulumi.Output<outputs.wafv2.WebAclLoggingConfigurationRedactedField[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the web ACL that you want to associate with `logDestinationConfigs`.
     */
    readonly resourceArn: pulumi.Output<string>;
    /**
     * Create a WebAclLoggingConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WebAclLoggingConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering WebAclLoggingConfiguration resources.
 */
export interface WebAclLoggingConfigurationState {
    /**
     * The Amazon Kinesis Data Firehose Amazon Resource Name (ARNs) that you want to associate with the web ACL. Currently, only 1 ARN is supported.
     */
    readonly logDestinationConfigs?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The parts of the request that you want to keep out of the logs. Up to 100 `redactedFields` blocks are supported.
     */
    readonly redactedFields?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclLoggingConfigurationRedactedField>[]>;
    /**
     * The Amazon Resource Name (ARN) of the web ACL that you want to associate with `logDestinationConfigs`.
     */
    readonly resourceArn?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a WebAclLoggingConfiguration resource.
 */
export interface WebAclLoggingConfigurationArgs {
    /**
     * The Amazon Kinesis Data Firehose Amazon Resource Name (ARNs) that you want to associate with the web ACL. Currently, only 1 ARN is supported.
     */
    readonly logDestinationConfigs: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The parts of the request that you want to keep out of the logs. Up to 100 `redactedFields` blocks are supported.
     */
    readonly redactedFields?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclLoggingConfigurationRedactedField>[]>;
    /**
     * The Amazon Resource Name (ARN) of the web ACL that you want to associate with `logDestinationConfigs`.
     */
    readonly resourceArn: pulumi.Input<string>;
}
