import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * ## Example Usage
 *
 * Basic usage:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.worklink.Fleet("example", {});
 * ```
 *
 * Network Configuration Usage:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.worklink.Fleet("example", {network: {
 *     vpcId: aws_vpc.test.id,
 *     subnetIds: [aws_subnet.test.map(__item => __item.id)],
 *     securityGroupIds: [aws_security_group.test.id],
 * }});
 * ```
 *
 * Identity Provider Configuration Usage:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * import * from "fs";
 *
 * const test = new aws.worklink.Fleet("test", {identityProvider: {
 *     type: "SAML",
 *     samlMetadata: fs.readFileSync("saml-metadata.xml"),
 * }});
 * ```
 *
 * ## Import
 *
 * WorkLink can be imported using the ARN, e.g.
 *
 * ```sh
 *  $ pulumi import aws:worklink/fleet:Fleet test arn:aws:worklink::123456789012:fleet/example
 * ```
 */
export declare class Fleet extends pulumi.CustomResource {
    /**
     * Get an existing Fleet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: FleetState, opts?: pulumi.CustomResourceOptions): Fleet;
    /**
     * Returns true if the given object is an instance of Fleet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Fleet;
    /**
     * The ARN of the created WorkLink Fleet.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ARN of the Amazon Kinesis data stream that receives the audit events. Kinesis data stream name must begin with `"AmazonWorkLink-"`.
     */
    readonly auditStreamArn: pulumi.Output<string | undefined>;
    /**
     * The identifier used by users to sign in to the Amazon WorkLink app.
     */
    readonly companyCode: pulumi.Output<string>;
    /**
     * The time that the fleet was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.
     */
    readonly deviceCaCertificate: pulumi.Output<string | undefined>;
    /**
     * The name of the fleet.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * Provide this to allow manage the identity provider configuration for the fleet. Fields documented below.
     */
    readonly identityProvider: pulumi.Output<outputs.worklink.FleetIdentityProvider | undefined>;
    /**
     * The time that the fleet was last updated.
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * A region-unique name for the AMI.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Provide this to allow manage the company network configuration for the fleet. Fields documented below.
     */
    readonly network: pulumi.Output<outputs.worklink.FleetNetwork | undefined>;
    /**
     * The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region. Defaults to `true`.
     */
    readonly optimizeForEndUserLocation: pulumi.Output<boolean | undefined>;
    /**
     * Create a Fleet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: FleetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Fleet resources.
 */
export interface FleetState {
    /**
     * The ARN of the created WorkLink Fleet.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The ARN of the Amazon Kinesis data stream that receives the audit events. Kinesis data stream name must begin with `"AmazonWorkLink-"`.
     */
    readonly auditStreamArn?: pulumi.Input<string>;
    /**
     * The identifier used by users to sign in to the Amazon WorkLink app.
     */
    readonly companyCode?: pulumi.Input<string>;
    /**
     * The time that the fleet was created.
     */
    readonly createdTime?: pulumi.Input<string>;
    /**
     * The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.
     */
    readonly deviceCaCertificate?: pulumi.Input<string>;
    /**
     * The name of the fleet.
     */
    readonly displayName?: pulumi.Input<string>;
    /**
     * Provide this to allow manage the identity provider configuration for the fleet. Fields documented below.
     */
    readonly identityProvider?: pulumi.Input<inputs.worklink.FleetIdentityProvider>;
    /**
     * The time that the fleet was last updated.
     */
    readonly lastUpdatedTime?: pulumi.Input<string>;
    /**
     * A region-unique name for the AMI.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Provide this to allow manage the company network configuration for the fleet. Fields documented below.
     */
    readonly network?: pulumi.Input<inputs.worklink.FleetNetwork>;
    /**
     * The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region. Defaults to `true`.
     */
    readonly optimizeForEndUserLocation?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a Fleet resource.
 */
export interface FleetArgs {
    /**
     * The ARN of the Amazon Kinesis data stream that receives the audit events. Kinesis data stream name must begin with `"AmazonWorkLink-"`.
     */
    readonly auditStreamArn?: pulumi.Input<string>;
    /**
     * The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.
     */
    readonly deviceCaCertificate?: pulumi.Input<string>;
    /**
     * The name of the fleet.
     */
    readonly displayName?: pulumi.Input<string>;
    /**
     * Provide this to allow manage the identity provider configuration for the fleet. Fields documented below.
     */
    readonly identityProvider?: pulumi.Input<inputs.worklink.FleetIdentityProvider>;
    /**
     * A region-unique name for the AMI.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Provide this to allow manage the company network configuration for the fleet. Fields documented below.
     */
    readonly network?: pulumi.Input<inputs.worklink.FleetNetwork>;
    /**
     * The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region. Defaults to `true`.
     */
    readonly optimizeForEndUserLocation?: pulumi.Input<boolean>;
}
