import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a WorkSpaces directory in AWS WorkSpaces Service.
 *
 * > **NOTE:** AWS WorkSpaces service requires [`workspaces_DefaultRole`](https://docs.aws.amazon.com/workspaces/latest/adminguide/workspaces-access-control.html#create-default-role) IAM role to operate normally.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const workspaces = aws.iam.getPolicyDocument({
 *     statements: [{
 *         actions: ["sts:AssumeRole"],
 *         principals: [{
 *             type: "Service",
 *             identifiers: ["workspaces.amazonaws.com"],
 *         }],
 *     }],
 * });
 * const workspacesDefault = new aws.iam.Role("workspacesDefault", {assumeRolePolicy: workspaces.then(workspaces => workspaces.json)});
 * const workspacesDefaultServiceAccess = new aws.iam.RolePolicyAttachment("workspacesDefaultServiceAccess", {
 *     role: workspacesDefault.name,
 *     policyArn: "arn:aws:iam::aws:policy/AmazonWorkSpacesServiceAccess",
 * });
 * const workspacesDefaultSelfServiceAccess = new aws.iam.RolePolicyAttachment("workspacesDefaultSelfServiceAccess", {
 *     role: workspacesDefault.name,
 *     policyArn: "arn:aws:iam::aws:policy/AmazonWorkSpacesSelfServiceAccess",
 * });
 * const exampleVpc = new aws.ec2.Vpc("exampleVpc", {cidrBlock: "10.0.0.0/16"});
 * const exampleC = new aws.ec2.Subnet("exampleC", {
 *     vpcId: exampleVpc.id,
 *     availabilityZone: "us-east-1c",
 *     cidrBlock: "10.0.2.0/24",
 * });
 * const exampleD = new aws.ec2.Subnet("exampleD", {
 *     vpcId: exampleVpc.id,
 *     availabilityZone: "us-east-1d",
 *     cidrBlock: "10.0.3.0/24",
 * });
 * const exampleDirectory = new aws.workspaces.Directory("exampleDirectory", {
 *     directoryId: exampleDirectoryservice / directoryDirectory.id,
 *     subnetIds: [
 *         exampleC.id,
 *         exampleD.id,
 *     ],
 *     tags: {
 *         Example: true,
 *     },
 *     selfServicePermissions: {
 *         changeComputeType: true,
 *         increaseVolumeSize: true,
 *         rebuildWorkspace: true,
 *         restartWorkspace: true,
 *         switchRunningMode: true,
 *     },
 *     workspaceAccessProperties: {
 *         deviceTypeAndroid: "ALLOW",
 *         deviceTypeChromeos: "ALLOW",
 *         deviceTypeIos: "ALLOW",
 *         deviceTypeOsx: "ALLOW",
 *         deviceTypeWeb: "DENY",
 *         deviceTypeWindows: "DENY",
 *         deviceTypeZeroclient: "DENY",
 *     },
 *     workspaceCreationProperties: {
 *         customSecurityGroupId: aws_security_group.example.id,
 *         defaultOu: "OU=AWS,DC=Workgroup,DC=Example,DC=com",
 *         enableInternetAccess: true,
 *         enableMaintenanceMode: true,
 *         userEnabledAsLocalAdministrator: true,
 *     },
 * }, {
 *     dependsOn: [
 *         workspacesDefaultServiceAccess,
 *         workspacesDefaultSelfServiceAccess,
 *     ],
 * });
 * const exampleA = new aws.ec2.Subnet("exampleA", {
 *     vpcId: exampleVpc.id,
 *     availabilityZone: "us-east-1a",
 *     cidrBlock: "10.0.0.0/24",
 * });
 * const exampleB = new aws.ec2.Subnet("exampleB", {
 *     vpcId: exampleVpc.id,
 *     availabilityZone: "us-east-1b",
 *     cidrBlock: "10.0.1.0/24",
 * });
 * const exampleDirectoryservice_directoryDirectory = new aws.directoryservice.Directory("exampleDirectoryservice/directoryDirectory", {
 *     name: "corp.example.com",
 *     password: "#S1ncerely",
 *     size: "Small",
 *     vpcSettings: {
 *         vpcId: exampleVpc.id,
 *         subnetIds: [
 *             exampleA.id,
 *             exampleB.id,
 *         ],
 *     },
 * });
 * ```
 * ### IP Groups
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleIpGroup = new aws.workspaces.IpGroup("exampleIpGroup", {});
 * const exampleDirectory = new aws.workspaces.Directory("exampleDirectory", {
 *     directoryId: aws_directory_service_directory.example.id,
 *     ipGroupIds: [exampleIpGroup.id],
 * });
 * ```
 *
 * ## Import
 *
 * Workspaces directory can be imported using the directory ID, e.g.
 *
 * ```sh
 *  $ pulumi import aws:workspaces/directory:Directory main d-4444444444
 * ```
 */
export declare class Directory extends pulumi.CustomResource {
    /**
     * Get an existing Directory resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DirectoryState, opts?: pulumi.CustomResourceOptions): Directory;
    /**
     * Returns true if the given object is an instance of Directory.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Directory;
    /**
     * The directory alias.
     */
    readonly alias: pulumi.Output<string>;
    /**
     * The user name for the service account.
     */
    readonly customerUserName: pulumi.Output<string>;
    /**
     * The directory identifier for registration in WorkSpaces service.
     */
    readonly directoryId: pulumi.Output<string>;
    /**
     * The name of the directory.
     */
    readonly directoryName: pulumi.Output<string>;
    /**
     * The directory type.
     */
    readonly directoryType: pulumi.Output<string>;
    /**
     * The IP addresses of the DNS servers for the directory.
     */
    readonly dnsIpAddresses: pulumi.Output<string[]>;
    /**
     * The identifier of the IAM role. This is the role that allows Amazon WorkSpaces to make calls to other services, such as Amazon EC2, on your behalf.
     */
    readonly iamRoleId: pulumi.Output<string>;
    /**
     * The identifiers of the IP access control groups associated with the directory.
     */
    readonly ipGroupIds: pulumi.Output<string[]>;
    /**
     * The registration code for the directory. This is the code that users enter in their Amazon WorkSpaces client application to connect to the directory.
     */
    readonly registrationCode: pulumi.Output<string>;
    /**
     * Permissions to enable or disable self-service capabilities. Defined below.
     */
    readonly selfServicePermissions: pulumi.Output<outputs.workspaces.DirectorySelfServicePermissions>;
    /**
     * The identifiers of the subnets where the directory resides.
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * A map of tags assigned to the WorkSpaces directory.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Specifies which devices and operating systems users can use to access their WorkSpaces. Defined below.
     */
    readonly workspaceAccessProperties: pulumi.Output<outputs.workspaces.DirectoryWorkspaceAccessProperties>;
    /**
     * Default properties that are used for creating WorkSpaces. Defined below.
     */
    readonly workspaceCreationProperties: pulumi.Output<outputs.workspaces.DirectoryWorkspaceCreationProperties>;
    /**
     * The identifier of the security group that is assigned to new WorkSpaces.
     */
    readonly workspaceSecurityGroupId: pulumi.Output<string>;
    /**
     * Create a Directory resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DirectoryArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Directory resources.
 */
export interface DirectoryState {
    /**
     * The directory alias.
     */
    readonly alias?: pulumi.Input<string>;
    /**
     * The user name for the service account.
     */
    readonly customerUserName?: pulumi.Input<string>;
    /**
     * The directory identifier for registration in WorkSpaces service.
     */
    readonly directoryId?: pulumi.Input<string>;
    /**
     * The name of the directory.
     */
    readonly directoryName?: pulumi.Input<string>;
    /**
     * The directory type.
     */
    readonly directoryType?: pulumi.Input<string>;
    /**
     * The IP addresses of the DNS servers for the directory.
     */
    readonly dnsIpAddresses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The identifier of the IAM role. This is the role that allows Amazon WorkSpaces to make calls to other services, such as Amazon EC2, on your behalf.
     */
    readonly iamRoleId?: pulumi.Input<string>;
    /**
     * The identifiers of the IP access control groups associated with the directory.
     */
    readonly ipGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The registration code for the directory. This is the code that users enter in their Amazon WorkSpaces client application to connect to the directory.
     */
    readonly registrationCode?: pulumi.Input<string>;
    /**
     * Permissions to enable or disable self-service capabilities. Defined below.
     */
    readonly selfServicePermissions?: pulumi.Input<inputs.workspaces.DirectorySelfServicePermissions>;
    /**
     * The identifiers of the subnets where the directory resides.
     */
    readonly subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of tags assigned to the WorkSpaces directory.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Specifies which devices and operating systems users can use to access their WorkSpaces. Defined below.
     */
    readonly workspaceAccessProperties?: pulumi.Input<inputs.workspaces.DirectoryWorkspaceAccessProperties>;
    /**
     * Default properties that are used for creating WorkSpaces. Defined below.
     */
    readonly workspaceCreationProperties?: pulumi.Input<inputs.workspaces.DirectoryWorkspaceCreationProperties>;
    /**
     * The identifier of the security group that is assigned to new WorkSpaces.
     */
    readonly workspaceSecurityGroupId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Directory resource.
 */
export interface DirectoryArgs {
    /**
     * The directory identifier for registration in WorkSpaces service.
     */
    readonly directoryId: pulumi.Input<string>;
    /**
     * The identifiers of the IP access control groups associated with the directory.
     */
    readonly ipGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Permissions to enable or disable self-service capabilities. Defined below.
     */
    readonly selfServicePermissions?: pulumi.Input<inputs.workspaces.DirectorySelfServicePermissions>;
    /**
     * The identifiers of the subnets where the directory resides.
     */
    readonly subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of tags assigned to the WorkSpaces directory.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Specifies which devices and operating systems users can use to access their WorkSpaces. Defined below.
     */
    readonly workspaceAccessProperties?: pulumi.Input<inputs.workspaces.DirectoryWorkspaceAccessProperties>;
    /**
     * Default properties that are used for creating WorkSpaces. Defined below.
     */
    readonly workspaceCreationProperties?: pulumi.Input<inputs.workspaces.DirectoryWorkspaceCreationProperties>;
}
